@@ -13,14 +13,15 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from ironic import api
+import pecan
+from wsme import types as wtypes
+
 from ironic.api.controllers import base
-from ironic.api import types as atypes
 
 
 def build_url(resource, resource_args, bookmark=False, base_url=None):
     if base_url is None:
-        base_url = api.request.public_url
+        base_url = pecan.request.host_url
 
     template = '%(url)s/%(res)s' if bookmark else '%(url)s/v1/%(res)s'
     # FIXME(lucasagomes): I'm getting a 404 when doing a GET on
@@ -30,21 +31,21 @@ def build_url(resource, resource_args, bookmark=False, base_url=None):
     return template % {'url': base_url, 'res': resource, 'args': resource_args}
 
 
-class Link(base.Base):
+class Link(base.APIBase):
     """A link representation."""
 
-    href = str
-    """The url of a link."""
+    href = wtypes.text
+    "The url of a link."
 
-    rel = str
-    """The name of a link."""
+    rel = wtypes.text
+    "The name of a link."
 
-    type = str
-    """Indicates the type of document/link."""
+    type = wtypes.text
+    "Indicates the type of document/link."
 
-    @staticmethod
-    def make_link(rel_name, url, resource, resource_args,
-                  bookmark=False, type=atypes.Unset):
+    @classmethod
+    def make_link(cls, rel_name, url, resource, resource_args,
+                  bookmark=False, type=wtypes.Unset):
         href = build_url(resource, resource_args,
                          bookmark=bookmark, base_url=url)
         return Link(href=href, rel=rel_name, type=type)
