@@ -2,6 +2,8 @@
 #
 # Copyright © 2012 New Dream Network, LLC (DreamHost)
 #
+# Author: Doug Hellmann <doug.hellmann@dreamhost.com>
+#
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
@@ -21,16 +23,19 @@ Based on pecan.middleware.errordocument
 """
 
 import json
-
-from oslo_log import log
+import webob
+from xml import etree as et
 
 from ironic.common.i18n import _
+from ironic.common.i18n import _LE
+from ironic.openstack.common import log
 
 LOG = log.getLogger(__name__)
 
 
 class ParsableErrorMiddleware(object):
-    """Replace error body with something the client can parse."""
+    """Replace error body with something the client can parse.
+    """
     def __init__(self, app):
         self.app = app
 
@@ -40,7 +45,8 @@ class ParsableErrorMiddleware(object):
         state = {}
 
         def replacement_start_response(status, headers, exc_info=None):
-            """Overrides the default response to make errors parsable."""
+            """Overrides the default response to make errors parsable.
+            """
             try:
                 status_code = int(status.split(' ')[0])
                 state['status_code'] = status_code
@@ -61,18 +67,26 @@ class ParsableErrorMiddleware(object):
                 state['headers'] = headers
                 return start_response(status, headers, exc_info)
 
-        # The default for ironic is application/json. However, Pecan will try
-        # to output HTML errors if no Accept header is provided.
-        if 'HTTP_ACCEPT' not in environ or environ['HTTP_ACCEPT'] == '*/*':
-            environ['HTTP_ACCEPT'] = 'application/json'
-
         app_iter = self.app(environ, replacement_start_response)
         if (state['status_code'] // 100) not in (2, 3):
-            app_iter = [i.decode('utf-8') for i in app_iter]
-            body = [json.dumps({'error_message': '\n'.join(app_iter)})]
-            body = [item.encode('utf-8') for item in body]
-            state['headers'].append(('Content-Type', 'application/json'))
-            state['headers'].append(('Content-Length', str(len(body[0]))))
+            req = webob.Request(environ)
+            if (req.accept.best_match(['application/json', 'application/xml'])
+                == 'application/xml'):
+                try:
+                    # simple check xml is valid
+                    body = [et.ElementTree.tostring(
+                            et.ElementTree.fromstring('<error_message>'
+                                                      + '\n'.join(app_iter)
+                                                      + '</error_message>'))]
+                except et.ElementTree.ParseError as err:
+                    LOG.error(_LE('Error parsing HTTP response: %s'), err)
+                    body = ['<error_message>%s' % state['status_code']
+                            + '</error_message>']
+                state['headers'].append(('Content-Type', 'application/xml'))
+            else:
+                body = [json.dumps({'error_message': '\n'.join(app_iter)})]
+                state['headers'].append(('Content-Type', 'application/json'))
+            state['headers'].append(('Content-Length', len(body[0])))
         else:
             body = app_iter
         return body
