@@ -12,11 +12,24 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from oslo_concurrency import lockutils
 import stevedore
 
+from oslo.config import cfg
+
 from ironic.common import exception
-from ironic.conf import CONF
+from ironic.openstack.common import lockutils
+
+
+dhcp_provider_opts = [
+    cfg.StrOpt('dhcp_provider',
+               default='neutron',
+               help='DHCP provider to use. "neutron" uses Neutron, and '
+               '"none" uses a no-op provider.'
+               ),
+]
+
+CONF = cfg.CONF
+CONF.register_opts(dhcp_provider_opts, group='dhcp')
 
 _dhcp_provider = None
 
@@ -34,12 +47,14 @@ class DHCPFactory(object):
         if not DHCPFactory._dhcp_provider:
             DHCPFactory._set_dhcp_provider(**kwargs)
 
+    # NOTE(lucasagomes): Use lockutils to avoid a potential race in eventlet
+    #                    that might try to create two dhcp factories.
     @classmethod
-    @lockutils.synchronized(EM_SEMAPHORE)
+    @lockutils.synchronized(EM_SEMAPHORE, 'ironic-')
     def _set_dhcp_provider(cls, **kwargs):
         """Initialize the dhcp provider
 
-        :raises: DHCPLoadError if the dhcp_provider cannot be loaded.
+        :raises: DHCPNotFound if the dhcp_provider cannot be loaded.
         """
 
         # NOTE(lucasagomes): In case multiple greenthreads queue up on
@@ -55,46 +70,24 @@ class DHCPFactory(object):
                 dhcp_provider_name,
                 invoke_kwds=kwargs,
                 invoke_on_load=True)
-        except Exception as e:
-            raise exception.DHCPLoadError(
-                dhcp_provider_name=dhcp_provider_name, reason=e
-            )
+        except RuntimeError:
+            raise exception.DHCPNotFound(dhcp_provider_name=dhcp_provider_name)
 
         cls._dhcp_provider = _extension_manager.driver
 
-    def update_dhcp(self, task, dhcp_opts, ports=None):
+    def update_dhcp(self, task, dhcp_opts):
         """Send or update the DHCP BOOT options for this node.
 
         :param task: A TaskManager instance.
         :param dhcp_opts: this will be a list of dicts, e.g.
-
-                          ::
-
-                           [{'opt_name': '67',
-                             'opt_value': 'pxelinux.0'},
-                            {'opt_name': '66',
-                             'opt_value': '123.123.123.456'}]
-
-        :param ports: A dict with keys 'ports' and 'portgroups' and
-            dicts as values. Each dict has key/value pairs of the form
-            <ironic UUID>:<neutron port UUID>. e.g.
-
-                          ::
-
-                           {'ports': {'port.uuid': vif.id},
-                            'portgroups': {'portgroup.uuid': vif.id}}
-
-            If the value is None, will get the list of ports/portgroups
-            from the Ironic port/portgroup objects.
+                        [{'opt_name': 'bootfile-name',
+                          'opt_value': 'pxelinux.0'},
+                         {'opt_name': 'server-ip-address',
+                          'opt_value': '123.123.123.456'},
+                         {'opt_name': 'tftp-server',
+                          'opt_value': '123.123.123.123'}]
         """
-        self.provider.update_dhcp_opts(task, dhcp_opts, ports)
-
-    def clean_dhcp(self, task):
-        """Clean up the DHCP BOOT options for this node.
-
-        :param task: A TaskManager instance.
-        """
-        self.provider.clean_dhcp_opts(task)
+        self.provider.update_dhcp_opts(task, dhcp_opts)
 
     @property
     def provider(self):
