@@ -15,29 +15,29 @@
 
 import re
 
-from oslo_concurrency import processutils
-from oslo_config import cfg
-from oslo_log import log as logging
-from oslo_service import loopingcall
+from oslo.config import cfg
 
 from ironic.common import exception
 from ironic.common.i18n import _
 from ironic.common.i18n import _LW
 from ironic.common import utils
+from ironic.openstack.common import log as logging
+from ironic.openstack.common import loopingcall
+from ironic.openstack.common import processutils
 
 opts = [
     cfg.IntOpt('check_device_interval',
                default=1,
-               help=_('After Ironic has completed creating the partition '
-                      'table, it continues to check for activity on the '
-                      'attached iSCSI device status at this interval prior '
-                      'to copying the image to the node, in seconds')),
+               help='After Ironic has completed creating the partition table, '
+                    'it continues to check for activity on the attached iSCSI '
+                    'device status at this interval prior to copying the image'
+                    ' to the node, in seconds'),
     cfg.IntOpt('check_device_max_retries',
                default=20,
-               help=_('The maximum number of times to check that the device '
-                      'is not accessed by another process. If the device is '
-                      'still busy after that, the disk partitioning will be '
-                      'treated as having failed.')),
+               help='The maximum number of times to check that the device is '
+                    'not accessed by another process. If the device is still '
+                    'busy after that, the disk partitioning will be treated as'
+                    ' having failed.'),
 ]
 
 CONF = cfg.CONF
@@ -76,7 +76,7 @@ class DiskPartitioner(object):
         #                    need to log it again here.
         utils.execute('parted', '-a', self._alignment, '-s', self._device,
                       '--', 'unit', 'MiB', *args, check_exit_code=[0],
-                      use_standard_locale=True, run_as_root=True)
+                      run_as_root=True)
 
     def add_partition(self, size, part_type='primary', fs_type='',
                       bootable=False):
@@ -94,9 +94,6 @@ class DiskPartitioner(object):
         :returns: The partition number.
 
         """
-        # NOTE(jlvillal): This function has been moved to ironic-lib. And is
-        # planned to be deleted here. If need to modify this function, please
-        # also do the same modification in ironic-lib
         self._partitions.append({'size': size,
                                  'type': part_type,
                                  'fs_type': fs_type,
@@ -110,16 +107,10 @@ class DiskPartitioner(object):
                   partition layout.
 
         """
-        # NOTE(jlvillal): This function has been moved to ironic-lib. And is
-        # planned to be deleted here. If need to modify this function, please
-        # also do the same modification in ironic-lib
         return enumerate(self._partitions, 1)
 
     def _wait_for_disk_to_become_available(self, retries, max_retries, pids,
                                            stderr):
-        # NOTE(jlvillal): This function has been moved to ironic-lib. And is
-        # planned to be deleted here. If need to modify this function, please
-        # also do the same modification in ironic-lib
         retries[0] += 1
         if retries[0] > max_retries:
             raise loopingcall.LoopingCallDone()
@@ -144,10 +135,6 @@ class DiskPartitioner(object):
 
     def commit(self):
         """Write to the disk."""
-        # NOTE(jlvillal): This function has been moved to ironic-lib. And is
-        # planned to be deleted here. If need to modify this function, please
-        # also do the same modification in ironic-lib
-        LOG.debug("Committing partitions to disk.")
         cmd_args = ['mklabel', self._disk_label]
         # NOTE(lucasagomes): Lead in with 1MiB to allow room for the
         #                    partition table itself.
@@ -169,8 +156,8 @@ class DiskPartitioner(object):
         max_retries = CONF.disk_partitioner.check_device_max_retries
 
         timer = loopingcall.FixedIntervalLoopingCall(
-            self._wait_for_disk_to_become_available,
-            retries, max_retries, pids, fuser_err)
+                    self._wait_for_disk_to_become_available,
+                    retries, max_retries, pids, fuser_err)
         timer.start(interval=interval).wait()
 
         if retries[0] > max_retries:
@@ -188,7 +175,7 @@ class DiskPartitioner(object):
                     % {'device': self._device, 'fuser_err': fuser_err[0]})
 
 
-_PARTED_PRINT_RE = re.compile(r"^(\d+):([\d\.]+)MiB:"
+_PARTED_PRINT_RE = re.compile(r"^\d+:([\d\.]+)MiB:"
                               "([\d\.]+)MiB:([\d\.]+)MiB:(\w*)::(\w*)")
 
 
@@ -197,30 +184,25 @@ def list_partitions(device):
 
     :param device: The device path.
     :returns: list of dictionaries (one per partition) with keys:
-              number, start, end, size (in MiB), filesystem, flags
+              start, end, size (in MiB), filesystem, flags
     """
-    # NOTE(jlvillal): This function has been moved to ironic-lib. And is
-    # planned to be deleted here. If need to modify this function, please also
-    # do the same modification in ironic-lib
     output = utils.execute(
         'parted', '-s', '-m', device, 'unit', 'MiB', 'print',
-        use_standard_locale=True, run_as_root=True)[0]
-    if isinstance(output, bytes):
-        output = output.decode("utf-8")
+        use_standard_locale=True)[0]
     lines = [line for line in output.split('\n') if line.strip()][2:]
     # Example of line: 1:1.00MiB:501MiB:500MiB:ext4::boot
-    fields = ('number', 'start', 'end', 'size', 'filesystem', 'flags')
+    fields = ('start', 'end', 'size', 'filesystem', 'flags')
     result = []
     for line in lines:
         match = _PARTED_PRINT_RE.match(line)
         if match is None:
-            LOG.warning(_LW("Partition information from parted for device "
-                            "%(device)s does not match "
-                            "expected format: %(line)s"),
-                        dict(device=device, line=line))
+            LOG.warn(_LW("Partition information from parted for device "
+                         "%(device)s does not match "
+                         "expected format: %(line)s"),
+                     dict(device=device, line=line))
             continue
         # Cast int fields to ints (some are floats and we round them down)
-        groups = [int(float(x)) if i < 4 else x
+        groups = [int(float(x)) if i < 3 else x
                   for i, x in enumerate(match.groups())]
         result.append(dict(zip(fields, groups)))
     return result
