@@ -18,13 +18,13 @@ Create Date: 2014-09-26 16:16:30.988900
 
 """
 
-from alembic import op
-import sqlalchemy as sa
-
 # revision identifiers, used by Alembic.
 revision = '487deb87cc9d'
 down_revision = '3bea56f25597'
 
+from alembic import op
+import sqlalchemy as sa
+
 
 def upgrade():
     op.add_column(
@@ -34,5 +34,12 @@ def upgrade():
         'nodes',
         sa.Column('conductor_affinity', sa.Integer(),
                   sa.ForeignKey('conductors.id',
-                                name='nodes_conductor_affinity_fk'),
+                      name='nodes_conductor_affinity_fk'),
                   nullable=True))
+
+
+def downgrade():
+    op.drop_constraint('nodes_conductor_affinity_fk', 'nodes',
+            type_='foreignkey')
+    op.drop_column('nodes', 'conductor_affinity')
+    op.drop_column('conductors', 'online')
