@@ -19,9 +19,9 @@ import os
 import alembic
 from alembic import config as alembic_config
 import alembic.migration as alembic_migration
-from oslo_db import exception as db_exc
-from oslo_db.sqlalchemy import enginefacade
+from oslo.db import exception as db_exc
 
+from ironic.db.sqlalchemy import api as sqla_api
 from ironic.db.sqlalchemy import models
 
 
@@ -38,7 +38,7 @@ def version(config=None, engine=None):
     :rtype: string
     """
     if engine is None:
-        engine = enginefacade.writer.get_engine()
+        engine = sqla_api.get_engine()
     with engine.connect() as conn:
         context = alembic_migration.MigrationContext.configure(conn)
         return context.get_current_revision()
@@ -62,7 +62,7 @@ def create_schema(config=None, engine=None):
     Can be used for initial installation instead of upgrade('head').
     """
     if engine is None:
-        engine = enginefacade.writer.get_engine()
+        engine = sqla_api.get_engine()
 
     # NOTE(viktors): If we will use metadata.create_all() for non empty db
     #                schema, it will only add the new tables, but leave
@@ -88,8 +88,7 @@ def downgrade(revision, config=None):
 
 def stamp(revision, config=None):
     """Stamps database with provided revision.
-
-    Don't run any migrations.
+    Dont run any migrations.
 
     :param revision: Should match one from repository or head - to stamp
                      database with most recent revision
