@@ -15,20 +15,16 @@
 Common functionalities shared between different DRAC modules.
 """
 
-from oslo_log import log as logging
-from oslo_utils import importutils
+from oslo.utils import importutils
 
 from ironic.common import exception
 from ironic.common.i18n import _
-from ironic.common import utils
+from ironic.drivers.modules.drac import client as drac_client
 
-drac_client = importutils.try_import('dracclient.client')
-drac_constants = importutils.try_import('dracclient.constants')
-
-LOG = logging.getLogger(__name__)
+pywsman = importutils.try_import('pywsman')
 
 REQUIRED_PROPERTIES = {
-    'drac_address': _('IP address or hostname of the DRAC card. Required.'),
+    'drac_host': _('IP address or hostname of the DRAC card. Required.'),
     'drac_username': _('username used for authentication. Required.'),
     'drac_password': _('password used for authentication. Required.')
 }
@@ -39,15 +35,17 @@ OPTIONAL_PROPERTIES = {
     'drac_protocol': _('protocol used for WS-Man endpoint; one of http, https;'
                        ' default is "https". Optional.'),
 }
-
 COMMON_PROPERTIES = REQUIRED_PROPERTIES.copy()
 COMMON_PROPERTIES.update(OPTIONAL_PROPERTIES)
 
+# ReturnValue constants
+RET_SUCCESS = '0'
+RET_ERROR = '2'
+RET_CREATED = '4096'
+
 
 def parse_driver_info(node):
-    """Parse a node's driver_info values.
-
-    Parses the driver_info of the node, reads default values
+    """Parses the driver_info of the node, reads default values
     and returns a dict containing the combination of both.
 
     :param node: an ironic node object.
@@ -79,39 +77,52 @@ def parse_driver_info(node):
     try:
         parsed_driver_info['drac_protocol'] = str(
             driver_info.get('drac_protocol', 'https'))
-
-        if parsed_driver_info['drac_protocol'] not in ['http', 'https']:
-            error_msgs.append(_("'drac_protocol' must be either 'http' or "
-                                "'https'."))
     except UnicodeEncodeError:
         error_msgs.append(_("'drac_protocol' contains non-ASCII symbol."))
 
+    try:
+        parsed_driver_info['drac_port'] = int(parsed_driver_info['drac_port'])
+    except ValueError:
+        error_msgs.append(_("'drac_port' is not an integer value."))
+
     if error_msgs:
         msg = (_('The following errors were encountered while parsing '
                  'driver_info:\n%s') % '\n'.join(error_msgs))
         raise exception.InvalidParameterValue(msg)
 
-    port = parsed_driver_info['drac_port']
-    parsed_driver_info['drac_port'] = utils.validate_network_port(
-        port, 'drac_port')
-
     return parsed_driver_info
 
 
-def get_drac_client(node):
-    """Returns a DRACClient object from python-dracclient library.
+def get_wsman_client(node):
+    """Given an ironic node object, this method gives back a
+    Client object which is a wrapper for pywsman.Client.
 
     :param node: an ironic node object.
-    :returns: a DRACClient object.
-    :raises: InvalidParameterValue if mandatory information is missing on the
-             node or on invalid input.
+    :returns: a Client object.
+    :raises: InvalidParameterValue if some mandatory information
+             is missing on the node or on invalid inputs.
     """
     driver_info = parse_driver_info(node)
-    client = drac_client.DRACClient(driver_info['drac_address'],
-                                    driver_info['drac_username'],
-                                    driver_info['drac_password'],
-                                    driver_info['drac_port'],
-                                    driver_info['drac_path'],
-                                    driver_info['drac_protocol'])
-
+    client = drac_client.Client(**driver_info)
     return client
+
+
+def find_xml(doc, item, namespace, find_all=False):
+    """Find the first or all elements in a ElementTree object.
+
+    :param doc: the element tree object.
+    :param item: the element name.
+    :param namespace: the namespace of the element.
+    :param find_all: Boolean value, if True find all elements, if False
+                     find only the first one. Defaults to False.
+    :returns: if find_all is False the element object will be returned
+              if found, None if not found. If find_all is True a list of
+              element objects will be returned or an empty list if no
+              elements were found.
+
+    """
+    query = ('.//{%(namespace)s}%(item)s' % {'namespace': namespace,
+                                             'item': item})
+    if find_all:
+        return doc.findall(query)
+    return doc.find(query)
