@@ -19,43 +19,18 @@
 Ironic iBoot PDU power manager.
 """
 
-import time
-
-from oslo_config import cfg
-from oslo_log import log as logging
-from oslo_service import loopingcall
-from oslo_utils import importutils
+from oslo.utils import importutils
 
 from ironic.common import exception
 from ironic.common.i18n import _
 from ironic.common.i18n import _LW
 from ironic.common import states
-from ironic.common import utils
 from ironic.conductor import task_manager
 from ironic.drivers import base
+from ironic.openstack.common import log as logging
 
 iboot = importutils.try_import('iboot')
 
-opts = [
-    cfg.IntOpt('max_retry',
-               default=3,
-               help=_('Maximum retries for iBoot operations')),
-    cfg.IntOpt('retry_interval',
-               default=1,
-               help=_('Time (in seconds) between retry attempts for iBoot '
-                      'operations')),
-    cfg.IntOpt('reboot_delay',
-               default=5,
-               min=0,
-               help=_('Time (in seconds) to sleep between when rebooting '
-                      '(powering off and on again).'))
-]
-
-CONF = cfg.CONF
-opt_group = cfg.OptGroup(name='iboot',
-                         title='Options for the iBoot power driver')
-CONF.register_group(opt_group)
-CONF.register_opts(opts, opt_group)
 
 LOG = logging.getLogger(__name__)
 
@@ -76,9 +51,9 @@ def _parse_driver_info(node):
     info = node.driver_info or {}
     missing_info = [key for key in REQUIRED_PROPERTIES if not info.get(key)]
     if missing_info:
-        raise exception.MissingParameterValue(
-            _("Missing the following iBoot credentials in node's"
-              " driver_info: %s.") % missing_info)
+        raise exception.MissingParameterValue(_(
+              "The following iBoot credentials were not supplied to iBoot PDU "
+              "driver: %s.") % missing_info)
 
     address = info.get('iboot_address', None)
     username = info.get('iboot_username', None)
@@ -88,20 +63,24 @@ def _parse_driver_info(node):
     try:
         relay_id = int(relay_id)
     except ValueError:
-        raise exception.InvalidParameterValue(
-            _("iBoot PDU relay id must be an integer."))
+        raise exception.InvalidParameterValue(_(
+              "iBoot PDU relay id must be an integer."))
 
     port = info.get('iboot_port', 9100)
-    port = utils.validate_network_port(port, 'iboot_port')
+    try:
+        port = int(port)
+    except ValueError:
+        raise exception.InvalidParameterValue(_(
+              "iBoot PDU port must be an integer."))
 
     return {
-        'address': address,
-        'username': username,
-        'password': password,
-        'port': port,
-        'relay_id': relay_id,
-        'uuid': node.uuid,
-    }
+            'address': address,
+            'username': username,
+            'password': password,
+            'port': port,
+            'relay_id': relay_id,
+            'uuid': node.uuid,
+           }
 
 
 def _get_connection(driver_info):
@@ -116,83 +95,33 @@ def _get_connection(driver_info):
 def _switch(driver_info, enabled):
     conn = _get_connection(driver_info)
     relay_id = driver_info['relay_id']
-
-    def _wait_for_switch(mutable):
-        if mutable['retries'] > CONF.iboot.max_retry:
-            LOG.warning(_LW(
-                'Reached maximum number of attempts (%(attempts)d) to set '
-                'power state for node %(node)s to "%(op)s"'),
-                {'attempts': mutable['retries'], 'node': driver_info['uuid'],
-                 'op': states.POWER_ON if enabled else states.POWER_OFF})
-            raise loopingcall.LoopingCallDone()
-
-        try:
-            mutable['retries'] += 1
-            mutable['response'] = conn.switch(relay_id, enabled)
-            if mutable['response']:
-                raise loopingcall.LoopingCallDone()
-        except (TypeError, IndexError):
-            LOG.warning(_LW("Cannot call set power state for node '%(node)s' "
-                            "at relay '%(relay)s'. iBoot switch() failed."),
-                        {'node': driver_info['uuid'], 'relay': relay_id})
-
-    mutable = {'response': False, 'retries': 0}
-    timer = loopingcall.FixedIntervalLoopingCall(_wait_for_switch,
-                                                 mutable)
-    timer.start(interval=CONF.iboot.retry_interval).wait()
-    return mutable['response']
-
-
-def _sleep_switch(seconds):
-    """Function broken out for testing purpose."""
-    time.sleep(seconds)
-
-
-def _check_power_state(driver_info, pstate):
-    """Function to check power state is correct. Up to max retries."""
-    # always try once + number of retries
-    for num in range(0, 1 + CONF.iboot.max_retry):
-        state = _power_status(driver_info)
-        if state == pstate:
-            return
-        if num < CONF.iboot.max_retry:
-            time.sleep(CONF.iboot.retry_interval)
-    raise exception.PowerStateFailure(pstate=pstate)
+    return conn.switch(relay_id, enabled)
 
 
 def _power_status(driver_info):
     conn = _get_connection(driver_info)
     relay_id = driver_info['relay_id']
+    try:
+        response = conn.get_relays()
+        status = response[relay_id - 1]
+    except TypeError:
+        msg = (_("Cannot get power status for node '%(node)s'. iBoot "
+                 "get_relays() returned '%(resp)s'.")
+                 % {'node': driver_info['uuid'], 'resp': response})
+        LOG.error(msg)
+        raise exception.IBootOperationError(message=msg)
+    except IndexError:
+        LOG.warning(_LW("Cannot get power status for node '%(node)s' at relay "
+                        "'%(relay)s'. iBoot get_relays() returned "
+                        "'%(resp)s'."),
+                        {'node': driver_info['uuid'], 'relay': relay_id,
+                         'resp': response})
+        return states.ERROR
 
-    def _wait_for_power_status(mutable):
-
-        if mutable['retries'] > CONF.iboot.max_retry:
-            LOG.warning(_LW(
-                'Reached maximum number of attempts (%(attempts)d) to get '
-                'power state for node %(node)s'),
-                {'attempts': mutable['retries'], 'node': driver_info['uuid']})
-            raise loopingcall.LoopingCallDone()
-
-        try:
-            mutable['retries'] += 1
-            response = conn.get_relays()
-            status = response[relay_id - 1]
-            if status:
-                mutable['state'] = states.POWER_ON
-            else:
-                mutable['state'] = states.POWER_OFF
-            raise loopingcall.LoopingCallDone()
-        except (TypeError, IndexError):
-            LOG.warning(_LW("Cannot get power state for node '%(node)s' at "
-                            "relay '%(relay)s'. iBoot get_relays() failed."),
-                        {'node': driver_info['uuid'], 'relay': relay_id})
-
-    mutable = {'state': states.ERROR, 'retries': 0}
-
-    timer = loopingcall.FixedIntervalLoopingCall(_wait_for_power_status,
-                                                 mutable)
-    timer.start(interval=CONF.iboot.retry_interval).wait()
-    return mutable['state']
+    if status:
+        return states.POWER_ON
+    else:
+        return states.POWER_OFF
 
 
 class IBootPower(base.PowerInterface):
@@ -256,11 +185,13 @@ class IBootPower(base.PowerInterface):
         elif pstate == states.POWER_OFF:
             _switch(driver_info, False)
         else:
-            raise exception.InvalidParameterValue(
-                _("set_power_state called with invalid "
+            raise exception.InvalidParameterValue(_(
+                  "set_power_state called with invalid "
                   "power state %s.") % pstate)
 
-        _check_power_state(driver_info, pstate)
+        state = _power_status(driver_info)
+        if state != pstate:
+            raise exception.PowerStateFailure(pstate=pstate)
 
     @task_manager.require_exclusive_lock
     def reboot(self, task):
@@ -277,6 +208,8 @@ class IBootPower(base.PowerInterface):
         """
         driver_info = _parse_driver_info(task.node)
         _switch(driver_info, False)
-        _sleep_switch(CONF.iboot.reboot_delay)
         _switch(driver_info, True)
-        _check_power_state(driver_info, states.POWER_ON)
+
+        state = _power_status(driver_info)
+        if state != states.POWER_ON:
+            raise exception.PowerStateFailure(pstate=states.POWER_ON)
