@@ -20,48 +20,50 @@ Ironic Native IPMI power manager.
 """
 
 import os
+import tempfile
 
-from ironic_lib import metrics_utils
-from ironic_lib import utils as ironic_utils
-from oslo_log import log as logging
-from oslo_utils import excutils
-from oslo_utils import importutils
-from oslo_utils import strutils
+from oslo.config import cfg
+from oslo.utils import excutils
+from oslo.utils import importutils
 
 from ironic.common import boot_devices
 from ironic.common import exception
-from ironic.common.i18n import _, _LE, _LW
+from ironic.common.i18n import _
+from ironic.common.i18n import _LE
+from ironic.common.i18n import _LW
 from ironic.common import states
 from ironic.common import utils
 from ironic.conductor import task_manager
-from ironic.conf import CONF
 from ironic.drivers import base
 from ironic.drivers.modules import console_utils
-from ironic.drivers.modules import deploy_utils
-from ironic.drivers import utils as driver_utils
+from ironic.openstack.common import log as logging
 
 pyghmi = importutils.try_import('pyghmi')
 if pyghmi:
     from pyghmi import exceptions as pyghmi_exception
     from pyghmi.ipmi import command as ipmi_command
 
-LOG = logging.getLogger(__name__)
+opts = [
+    cfg.IntOpt('retry_timeout',
+               default=60,
+               help='Maximum time in seconds to retry IPMI operations.'),
+    cfg.IntOpt('min_command_interval',
+               default=5,
+               help='Minimum time, in seconds, between IPMI operations '
+                    'sent to a server. There is a risk with some hardware '
+                    'that setting this too low may cause the BMC to crash. '
+                    'Recommended setting is 5 seconds.'),
+    ]
 
-METRICS = metrics_utils.get_metrics_logger(__name__)
+CONF = cfg.CONF
+CONF.register_opts(opts, group='ipmi')
+
+LOG = logging.getLogger(__name__)
 
 REQUIRED_PROPERTIES = {'ipmi_address': _("IP of the node's BMC. Required."),
                        'ipmi_password': _("IPMI password. Required."),
                        'ipmi_username': _("IPMI username. Required.")}
-OPTIONAL_PROPERTIES = {
-    'ipmi_force_boot_device': _("Whether Ironic should specify the boot "
-                                "device to the BMC each time the server "
-                                "is turned on, eg. because the BMC is not "
-                                "capable of remembering the selected boot "
-                                "device across power cycles; default value "
-                                "is False. Optional.")
-}
-COMMON_PROPERTIES = REQUIRED_PROPERTIES.copy()
-COMMON_PROPERTIES.update(OPTIONAL_PROPERTIES)
+COMMON_PROPERTIES = REQUIRED_PROPERTIES
 CONSOLE_PROPERTIES = {
     'ipmi_terminal_port': _("node's UDP port to connect to. Only required for "
                             "console access.")
@@ -69,7 +71,7 @@ CONSOLE_PROPERTIES = {
 
 _BOOT_DEVICES_MAP = {
     boot_devices.DISK: 'hd',
-    boot_devices.PXE: 'network',
+    boot_devices.PXE: 'net',
     boot_devices.CDROM: 'cdrom',
     boot_devices.BIOS: 'setup',
 }
@@ -77,7 +79,6 @@ _BOOT_DEVICES_MAP = {
 
 def _parse_driver_info(node):
     """Gets the bmc access info for the given node.
-
     :raises: MissingParameterValue when required ipmi credentials
             are missing.
     :raises: InvalidParameterValue when the IPMI terminal port is not an
@@ -88,14 +89,14 @@ def _parse_driver_info(node):
     missing_info = [key for key in REQUIRED_PROPERTIES if not info.get(key)]
     if missing_info:
         raise exception.MissingParameterValue(_(
-            "Missing the following IPMI credentials in node's"
-            " driver_info: %s.") % missing_info)
+            "The following IPMI credentials are not supplied"
+            " to IPMI driver: %s."
+             ) % missing_info)
 
     bmc_info = {}
     bmc_info['address'] = info.get('ipmi_address')
     bmc_info['username'] = info.get('ipmi_username')
     bmc_info['password'] = info.get('ipmi_password')
-    bmc_info['force_boot_device'] = info.get('ipmi_force_boot_device', False)
 
     # get additional info
     bmc_info['uuid'] = node.uuid
@@ -103,7 +104,11 @@ def _parse_driver_info(node):
     # terminal port must be an integer
     port = info.get('ipmi_terminal_port')
     if port is not None:
-        port = utils.validate_network_port(port, 'ipmi_terminal_port')
+        try:
+            port = int(port)
+        except ValueError:
+            raise exception.InvalidParameterValue(_(
+                "IPMI terminal port is not an integer."))
     bmc_info['port'] = port
 
     return bmc_info
@@ -112,7 +117,7 @@ def _parse_driver_info(node):
 def _console_pwfile_path(uuid):
     """Return the file path for storing the ipmi password."""
     file_name = "%(uuid)s.pw" % {'uuid': uuid}
-    return os.path.join(CONF.tempdir, file_name)
+    return os.path.join(tempfile.gettempdir(), file_name)
 
 
 def _power_on(driver_info):
@@ -125,26 +130,24 @@ def _power_on(driver_info):
              from ipmi.
     """
 
-    msg = _("IPMI power on failed for node %(node_id)s with the "
-            "following error: %(error)s")
+    msg = _LW("IPMI power on failed for node %(node_id)s with the "
+              "following error: %(error)s")
     try:
         ipmicmd = ipmi_command.Command(bmc=driver_info['address'],
-                                       userid=driver_info['username'],
-                                       password=driver_info['password'])
+                           userid=driver_info['username'],
+                           password=driver_info['password'])
         wait = CONF.ipmi.retry_timeout
         ret = ipmicmd.set_power('on', wait)
     except pyghmi_exception.IpmiException as e:
-        error = msg % {'node_id': driver_info['uuid'], 'error': e}
-        LOG.error(error)
-        raise exception.IPMIFailure(error)
+        LOG.warning(msg, {'node_id': driver_info['uuid'], 'error': str(e)})
+        raise exception.IPMIFailure(cmd=str(e))
 
     state = ret.get('powerstate')
     if state == 'on':
         return states.POWER_ON
     else:
-        error = _("bad response: %s") % ret
-        LOG.error(msg, {'node_id': driver_info['uuid'], 'error': error})
-        raise exception.PowerStateFailure(pstate=states.POWER_ON)
+        LOG.warning(msg, {'node_id': driver_info['uuid'], 'error': ret})
+        raise exception.PowerStateFailure(pstate=state)
 
 
 def _power_off(driver_info):
@@ -157,26 +160,24 @@ def _power_off(driver_info):
              from ipmi.
     """
 
-    msg = _("IPMI power off failed for node %(node_id)s with the "
-            "following error: %(error)s")
+    msg = _LW("IPMI power off failed for node %(node_id)s with the "
+              "following error: %(error)s")
     try:
         ipmicmd = ipmi_command.Command(bmc=driver_info['address'],
-                                       userid=driver_info['username'],
-                                       password=driver_info['password'])
+                           userid=driver_info['username'],
+                           password=driver_info['password'])
         wait = CONF.ipmi.retry_timeout
         ret = ipmicmd.set_power('off', wait)
     except pyghmi_exception.IpmiException as e:
-        error = msg % {'node_id': driver_info['uuid'], 'error': e}
-        LOG.error(error)
-        raise exception.IPMIFailure(error)
+        LOG.warning(msg, {'node_id': driver_info['uuid'], 'error': str(e)})
+        raise exception.IPMIFailure(cmd=str(e))
 
     state = ret.get('powerstate')
     if state == 'off':
         return states.POWER_OFF
     else:
-        error = _("bad response: %s") % ret
-        LOG.error(msg, {'node_id': driver_info['uuid'], 'error': error})
-        raise exception.PowerStateFailure(pstate=states.POWER_OFF)
+        LOG.warning(msg % {'node_id': driver_info['uuid'], 'error': ret})
+        raise exception.PowerStateFailure(pstate=state)
 
 
 def _reboot(driver_info):
@@ -191,25 +192,24 @@ def _reboot(driver_info):
              from ipmi.
     """
 
-    msg = _("IPMI power reboot failed for node %(node_id)s with the "
-            "following error: %(error)s")
+    msg = _LW("IPMI power reboot failed for node %(node_id)s with the "
+              "following error: %(error)s")
     try:
         ipmicmd = ipmi_command.Command(bmc=driver_info['address'],
-                                       userid=driver_info['username'],
-                                       password=driver_info['password'])
+                           userid=driver_info['username'],
+                           password=driver_info['password'])
         wait = CONF.ipmi.retry_timeout
         ret = ipmicmd.set_power('boot', wait)
     except pyghmi_exception.IpmiException as e:
-        error = msg % {'node_id': driver_info['uuid'], 'error': e}
-        LOG.error(error)
-        raise exception.IPMIFailure(error)
+        LOG.warning(msg % {'node_id': driver_info['uuid'], 'error': str(e)})
+        raise exception.IPMIFailure(cmd=str(e))
 
-    if 'error' in ret:
-        error = _("bad response: %s") % ret
-        LOG.error(msg, {'node_id': driver_info['uuid'], 'error': error})
-        raise exception.PowerStateFailure(pstate=states.REBOOT)
-
-    return states.POWER_ON
+    state = ret.get('powerstate')
+    if state == 'on':
+        return states.POWER_ON
+    else:
+        LOG.warning(msg % {'node_id': driver_info['uuid'], 'error': ret})
+        raise exception.PowerStateFailure(pstate=state)
 
 
 def _power_status(driver_info):
@@ -223,15 +223,14 @@ def _power_status(driver_info):
 
     try:
         ipmicmd = ipmi_command.Command(bmc=driver_info['address'],
-                                       userid=driver_info['username'],
-                                       password=driver_info['password'])
+                           userid=driver_info['username'],
+                           password=driver_info['password'])
         ret = ipmicmd.get_power()
     except pyghmi_exception.IpmiException as e:
-        msg = (_("IPMI get power state failed for node %(node_id)s "
-                 "with the following error: %(error)s") %
-               {'node_id': driver_info['uuid'], 'error': e})
-        LOG.error(msg)
-        raise exception.IPMIFailure(msg)
+        LOG.warning(_LW("IPMI get power state failed for node %(node_id)s "
+                        "with the following error: %(error)s"),
+                    {'node_id': driver_info['uuid'], 'error': str(e)})
+        raise exception.IPMIFailure(cmd=str(e))
 
     state = ret.get('powerstate')
     if state == 'on':
@@ -257,15 +256,15 @@ def _get_sensors_data(driver_info):
     """
     try:
         ipmicmd = ipmi_command.Command(bmc=driver_info['address'],
-                                       userid=driver_info['username'],
-                                       password=driver_info['password'])
+            userid=driver_info['username'],
+            password=driver_info['password'])
         ret = ipmicmd.get_sensor_data()
     except Exception as e:
         LOG.error(_LE("IPMI get sensor data failed for node %(node_id)s "
                   "with the following error: %(error)s"),
-                  {'node_id': driver_info['uuid'], 'error': e})
+              {'node_id': driver_info['uuid'], 'error': e})
         raise exception.FailedToGetSensorData(
-            node=driver_info['uuid'], error=e)
+                    node=driver_info['uuid'], error=e)
 
     if not ret:
         return {}
@@ -275,63 +274,23 @@ def _get_sensors_data(driver_info):
         # ignore the sensor data which has no sensor reading value
         if not reading.value:
             continue
-        sensors_data.setdefault(
-            reading.type,
+        sensors_data.setdefault(reading.type,
             {})[reading.name] = {
-                'Sensor Reading': '%s %s' % (reading.value, reading.units),
-                'Sensor ID': reading.name,
-                'States': str(reading.states),
-                'Units': reading.units,
-                'Health': str(reading.health)}
+              'Sensor Reading': '%s %s' % (reading.value, reading.units),
+              'Sensor ID': reading.name,
+              'States': str(reading.states),
+              'Units': reading.units,
+              'Health': str(reading.health)}
 
     return sensors_data
 
 
-def _parse_raw_bytes(raw_bytes):
-    """Parse raw bytes string.
-
-    :param raw_bytes: a string of hexadecimal raw bytes, e.g. '0x00 0x01'.
-    :returns: a tuple containing the arguments for pyghmi call as integers,
-             (IPMI net function, IPMI command, list of command's data).
-    :raises: InvalidParameterValue when an invalid value is specified.
-    """
-    try:
-        bytes_list = [int(x, base=16) for x in raw_bytes.split()]
-        return bytes_list[0], bytes_list[1], bytes_list[2:]
-    except ValueError:
-        raise exception.InvalidParameterValue(_(
-            "Invalid raw bytes string: '%s'") % raw_bytes)
-    except IndexError:
-        raise exception.InvalidParameterValue(_(
-            "Raw bytes string requires two bytes at least."))
-
-
-def _send_raw(driver_info, raw_bytes):
-    """Send raw bytes to the BMC."""
-    netfn, command, data = _parse_raw_bytes(raw_bytes)
-    LOG.debug("Sending raw bytes %(bytes)s to node %(node_id)s",
-              {'bytes': raw_bytes, 'node_id': driver_info['uuid']})
-    try:
-        ipmicmd = ipmi_command.Command(bmc=driver_info['address'],
-                                       userid=driver_info['username'],
-                                       password=driver_info['password'])
-        ipmicmd.xraw_command(netfn, command, data=data)
-    except pyghmi_exception.IpmiException as e:
-        msg = (_("IPMI send raw bytes '%(bytes)s' failed for node %(node_id)s"
-                 " with the following error: %(error)s") %
-               {'bytes': raw_bytes, 'node_id': driver_info['uuid'],
-                'error': e})
-        LOG.error(msg)
-        raise exception.IPMIFailure(msg)
-
-
 class NativeIPMIPower(base.PowerInterface):
     """The power driver using native python-ipmi library."""
 
     def get_properties(self):
         return COMMON_PROPERTIES
 
-    @METRICS.timer('NativeIPMIPower.validate')
     def validate(self, task):
         """Check that node['driver_info'] contains IPMI credentials.
 
@@ -341,7 +300,6 @@ class NativeIPMIPower(base.PowerInterface):
         """
         _parse_driver_info(task.node)
 
-    @METRICS.timer('NativeIPMIPower.get_power_state')
     def get_power_state(self, task):
         """Get the current power state of the task's node.
 
@@ -355,7 +313,6 @@ class NativeIPMIPower(base.PowerInterface):
         driver_info = _parse_driver_info(task.node)
         return _power_status(driver_info)
 
-    @METRICS.timer('NativeIPMIPower.set_power_state')
     @task_manager.require_exclusive_lock
     def set_power_state(self, task, pstate):
         """Turn the power on or off.
@@ -374,16 +331,14 @@ class NativeIPMIPower(base.PowerInterface):
         driver_info = _parse_driver_info(task.node)
 
         if pstate == states.POWER_ON:
-            driver_utils.ensure_next_boot_device(task, driver_info)
             _power_on(driver_info)
         elif pstate == states.POWER_OFF:
             _power_off(driver_info)
         else:
-            raise exception.InvalidParameterValue(
-                _("set_power_state called with an invalid power state: %s."
-                  ) % pstate)
+            raise exception.InvalidParameterValue(_(
+                "set_power_state called with an invalid power state: %s."
+                ) % pstate)
 
-    @METRICS.timer('NativeIPMIPower.reboot')
     @task_manager.require_exclusive_lock
     def reboot(self, task):
         """Cycles the power to the task's node.
@@ -397,7 +352,6 @@ class NativeIPMIPower(base.PowerInterface):
         """
 
         driver_info = _parse_driver_info(task.node)
-        driver_utils.ensure_next_boot_device(task, driver_info)
         _reboot(driver_info)
 
 
@@ -406,7 +360,6 @@ class NativeIPMIManagement(base.ManagementInterface):
     def get_properties(self):
         return COMMON_PROPERTIES
 
-    @METRICS.timer('NativeIPMIManagement.validate')
     def validate(self, task):
         """Check that 'driver_info' contains IPMI credentials.
 
@@ -420,17 +373,15 @@ class NativeIPMIManagement(base.ManagementInterface):
         """
         _parse_driver_info(task.node)
 
-    def get_supported_boot_devices(self, task):
+    def get_supported_boot_devices(self):
         """Get a list of the supported boot devices.
 
-        :param task: a task from TaskManager.
         :returns: A list with the supported boot devices defined
                   in :mod:`ironic.common.boot_devices`.
 
         """
         return list(_BOOT_DEVICES_MAP.keys())
 
-    @METRICS.timer('NativeIPMIManagement.set_boot_device')
     @task_manager.require_exclusive_lock
     def set_boot_device(self, task, device, persistent=False):
         """Set the boot device for the task's node.
@@ -449,34 +400,22 @@ class NativeIPMIManagement(base.ManagementInterface):
                  are missing.
         :raises: IPMIFailure on an error from pyghmi.
         """
-        if device not in self.get_supported_boot_devices(task):
+        if device not in self.get_supported_boot_devices():
             raise exception.InvalidParameterValue(_(
                 "Invalid boot device %s specified.") % device)
-
-        if task.node.driver_info.get('ipmi_force_boot_device', False):
-            driver_utils.force_persistent_boot(task,
-                                               device,
-                                               persistent)
-            # Reset persistent to False, in case of BMC does not support
-            # persistent or we do not have admin rights.
-            persistent = False
-
-        boot_mode = deploy_utils.get_boot_mode_for_deploy(task.node)
         driver_info = _parse_driver_info(task.node)
         try:
             ipmicmd = ipmi_command.Command(bmc=driver_info['address'],
-                                           userid=driver_info['username'],
-                                           password=driver_info['password'])
+                               userid=driver_info['username'],
+                               password=driver_info['password'])
             bootdev = _BOOT_DEVICES_MAP[device]
-            uefiboot = boot_mode == 'uefi'
-            ipmicmd.set_bootdev(bootdev, persist=persistent, uefiboot=uefiboot)
+            ipmicmd.set_bootdev(bootdev, persist=persistent)
         except pyghmi_exception.IpmiException as e:
             LOG.error(_LE("IPMI set boot device failed for node %(node_id)s "
                           "with the following error: %(error)s"),
                       {'node_id': driver_info['uuid'], 'error': e})
             raise exception.IPMIFailure(cmd=e)
 
-    @METRICS.timer('NativeIPMIManagement.get_boot_device')
     def get_boot_device(self, task):
         """Get the current boot device for the task's node.
 
@@ -494,23 +433,12 @@ class NativeIPMIManagement(base.ManagementInterface):
                 future boots or not, None if it is unknown.
 
         """
-        driver_info = task.node.driver_info
-        driver_internal_info = task.node.driver_internal_info
-        if (driver_info.get('ipmi_force_boot_device', False) and
-                driver_internal_info.get('persistent_boot_device') and
-                driver_internal_info.get('is_next_boot_persistent', True)):
-            return {
-                'boot_device': driver_internal_info['persistent_boot_device'],
-                'persistent': True
-            }
-
         driver_info = _parse_driver_info(task.node)
         response = {'boot_device': None}
-
         try:
             ipmicmd = ipmi_command.Command(bmc=driver_info['address'],
-                                           userid=driver_info['username'],
-                                           password=driver_info['password'])
+                               userid=driver_info['username'],
+                               password=driver_info['password'])
             ret = ipmicmd.get_bootdev()
             # FIXME(lucasagomes): pyghmi doesn't seem to handle errors
             # consistently, for some errors it raises an exception
@@ -531,7 +459,6 @@ class NativeIPMIManagement(base.ManagementInterface):
                                             if hdev == bootdev), None)
         return response
 
-    @METRICS.timer('NativeIPMIManagement.get_sensors_data')
     def get_sensors_data(self, task):
         """Get sensors data.
 
@@ -553,7 +480,6 @@ class NativeIPMIShellinaboxConsole(base.ConsoleInterface):
         d.update(CONSOLE_PROPERTIES)
         return d
 
-    @METRICS.timer('NativeIPMIShellinaboxConsole.validate')
     def validate(self, task):
         """Validate the Node console info.
 
@@ -566,10 +492,8 @@ class NativeIPMIShellinaboxConsole(base.ConsoleInterface):
         driver_info = _parse_driver_info(task.node)
         if not driver_info['port']:
             raise exception.MissingParameterValue(_(
-                "Missing 'ipmi_terminal_port' parameter in node's"
-                " driver_info."))
+                "IPMI terminal port not supplied to the IPMI driver."))
 
-    @METRICS.timer('NativeIPMIShellinaboxConsole.start_console')
     def start_console(self, task):
         """Start a remote console for the node.
 
@@ -584,38 +508,41 @@ class NativeIPMIShellinaboxConsole(base.ConsoleInterface):
 
         path = _console_pwfile_path(driver_info['uuid'])
         pw_file = console_utils.make_persistent_password_file(
-            path, driver_info['password'])
+                path, driver_info['password'])
 
-        console_cmd = ("/:%(uid)s:%(gid)s:HOME:pyghmicons %(bmc)s"
-                       " %(user)s"
-                       " %(passwd_file)s"
-                       % {'uid': os.getuid(),
-                          'gid': os.getgid(),
-                          'bmc': driver_info['address'],
-                          'user': driver_info['username'],
-                          'passwd_file': pw_file})
+        console_cmd = "/:%(uid)s:%(gid)s:HOME:pyghmicons %(bmc)s" \
+                      " %(user)s" \
+                      " %(passwd_file)s" \
+                      % {'uid': os.getuid(),
+                         'gid': os.getgid(),
+                         'bmc': driver_info['address'],
+                         'user': driver_info['username'],
+                         'passwd_file': pw_file}
         try:
             console_utils.start_shellinabox_console(driver_info['uuid'],
                                                     driver_info['port'],
                                                     console_cmd)
         except exception.ConsoleError:
             with excutils.save_and_reraise_exception():
-                ironic_utils.unlink_without_raise(path)
+                utils.unlink_without_raise(path)
 
-    @METRICS.timer('NativeIPMIShellinaboxConsole.stop_console')
     def stop_console(self, task):
         """Stop the remote console session for the node.
 
         :param task: a TaskManager instance containing the node to act on.
+        :raises: MissingParameterValue when required IPMI credentials or
+            the IPMI terminal port are missing
+        :raises: InvalidParameterValue when the IPMI terminal port is not
+                an integer.
         :raises: ConsoleError if unable to stop the console process.
         """
+        driver_info = _parse_driver_info(task.node)
         try:
-            console_utils.stop_shellinabox_console(task.node.uuid)
+            console_utils.stop_shellinabox_console(driver_info['uuid'])
         finally:
-            password_file = _console_pwfile_path(task.node.uuid)
-            ironic_utils.unlink_without_raise(password_file)
+            password_file = _console_pwfile_path(driver_info['uuid'])
+            utils.unlink_without_raise(password_file)
 
-    @METRICS.timer('NativeIPMIShellinaboxConsole.get_console')
     def get_console(self, task):
         """Get the type and connection information about the console.
 
@@ -628,75 +555,3 @@ class NativeIPMIShellinaboxConsole(base.ConsoleInterface):
         driver_info = _parse_driver_info(task.node)
         url = console_utils.get_shellinabox_console_url(driver_info['port'])
         return {'type': 'shellinabox', 'url': url}
-
-
-class VendorPassthru(base.VendorInterface):
-
-    def get_properties(self):
-        return COMMON_PROPERTIES
-
-    @METRICS.timer('VendorPassthru.validate')
-    def validate(self, task, method, **kwargs):
-        """Validate vendor-specific actions.
-
-        :param task: a task from TaskManager.
-        :param method: method to be validated
-        :param kwargs: info for action.
-        :raises: InvalidParameterValue when an invalid parameter value is
-                 specified.
-        :raises: MissingParameterValue if a required parameter is missing.
-
-        """
-        if method == 'send_raw':
-            raw_bytes = kwargs.get('raw_bytes')
-            if not raw_bytes:
-                raise exception.MissingParameterValue(_(
-                    'Parameter raw_bytes (string of bytes) was not '
-                    'specified.'))
-            _parse_raw_bytes(raw_bytes)
-
-        _parse_driver_info(task.node)
-
-    @METRICS.timer('VendorPassthru.send_raw')
-    @base.passthru(['POST'],
-                   description=_("Send raw bytes to the BMC. Required "
-                                 "argument: 'raw_bytes' - a string of raw "
-                                 "bytes (e.g. '0x00 0x01')."))
-    @task_manager.require_exclusive_lock
-    def send_raw(self, task, http_method, raw_bytes):
-        """Send raw bytes to the BMC. Bytes should be a string of bytes.
-
-        :param task: a TaskManager instance.
-        :param http_method: the HTTP method used on the request.
-        :param raw_bytes: a string of raw bytes to send, e.g. '0x00 0x01'
-        :raises: IPMIFailure on an error from native IPMI call.
-        :raises: MissingParameterValue if a required parameter is missing.
-        :raises: InvalidParameterValue when an invalid value is specified.
-
-        """
-        driver_info = _parse_driver_info(task.node)
-        _send_raw(driver_info, raw_bytes)
-
-    @METRICS.timer('VendorPassthru.bmc_reset')
-    @base.passthru(['POST'],
-                   description=_("Reset the BMC. Required argument: 'warm' "
-                                 "(Boolean) - for warm (True) or cold (False) "
-                                 "reset."))
-    @task_manager.require_exclusive_lock
-    def bmc_reset(self, task, http_method, warm=True):
-        """Reset BMC via IPMI command.
-
-        :param task: a TaskManager instance.
-        :param http_method: the HTTP method used on the request.
-        :param warm: boolean parameter to decide on warm or cold reset.
-        :raises: IPMIFailure on an error from native IPMI call.
-        :raises: MissingParameterValue if a required parameter is missing.
-        :raises: InvalidParameterValue when an invalid value is specified
-
-        """
-        driver_info = _parse_driver_info(task.node)
-        warm = strutils.bool_from_string(warm)
-        # NOTE(yuriyz): pyghmi 0.8.0 does not have a method for BMC reset
-        command = '0x03' if warm else '0x02'
-        raw_command = '0x06 ' + command
-        _send_raw(driver_info, raw_command)
