@@ -18,15 +18,9 @@ python-seamicroclient.
 
 Provides vendor passthru methods for SeaMicro specific functionality.
 """
-import os
-import re
 
-from oslo_config import cfg
-from oslo_log import log as logging
-from oslo_service import loopingcall
-from oslo_utils import importutils
-import six
-from six.moves.urllib import parse as urlparse
+from oslo.config import cfg
+from oslo.utils import importutils
 
 from ironic.common import boot_devices
 from ironic.common import exception
@@ -34,10 +28,10 @@ from ironic.common.i18n import _
 from ironic.common.i18n import _LE
 from ironic.common.i18n import _LW
 from ironic.common import states
-from ironic.common import utils
 from ironic.conductor import task_manager
 from ironic.drivers import base
-from ironic.drivers.modules import console_utils
+from ironic.openstack.common import log as logging
+from ironic.openstack.common import loopingcall
 
 seamicroclient = importutils.try_import('seamicroclient')
 if seamicroclient:
@@ -47,10 +41,10 @@ if seamicroclient:
 opts = [
     cfg.IntOpt('max_retry',
                default=3,
-               help=_('Maximum retries for SeaMicro operations')),
+               help='Maximum retries for SeaMicro operations'),
     cfg.IntOpt('action_timeout',
                default=10,
-               help=_('Seconds to wait for power action to be completed'))
+               help='Seconds to wait for power action to be completed')
 ]
 
 CONF = cfg.CONF
@@ -61,6 +55,8 @@ CONF.register_opts(opts, opt_group)
 
 LOG = logging.getLogger(__name__)
 
+VENDOR_PASSTHRU_METHODS = ['attach_volume', 'set_node_vlan_id']
+
 _BOOT_DEVICES_MAP = {
     boot_devices.DISK: 'hd0',
     boot_devices.PXE: 'pxe',
@@ -78,11 +74,6 @@ OPTIONAL_PROPERTIES = {
 }
 COMMON_PROPERTIES = REQUIRED_PROPERTIES.copy()
 COMMON_PROPERTIES.update(OPTIONAL_PROPERTIES)
-CONSOLE_PROPERTIES = {
-    'seamicro_terminal_port': _("node's UDP port to connect to. "
-                                "Only required for console access.")
-}
-PORT_BASE = 2000
 
 
 def _get_client(*args, **kwargs):
@@ -110,46 +101,27 @@ def _parse_driver_info(node):
     :param node: An Ironic node object.
     :returns: SeaMicro driver info.
     :raises: MissingParameterValue if any required parameters are missing.
-    :raises: InvalidParameterValue if required parameter are invalid.
     """
 
     info = node.driver_info or {}
     missing_info = [key for key in REQUIRED_PROPERTIES if not info.get(key)]
     if missing_info:
         raise exception.MissingParameterValue(_(
-            "SeaMicro driver requires the following parameters to be set in"
-            " node's driver_info: %s.") % missing_info)
+            "SeaMicro driver requires the following to be set: %s.")
+            % missing_info)
 
     api_endpoint = info.get('seamicro_api_endpoint')
     username = info.get('seamicro_username')
     password = info.get('seamicro_password')
     server_id = info.get('seamicro_server_id')
     api_version = info.get('seamicro_api_version', "2")
-    port = info.get('seamicro_terminal_port')
-
-    if port is not None:
-        port = utils.validate_network_port(port, 'seamicro_terminal_port')
-
-    r = re.compile(r"(^[0-9]+)/([0-9]+$)")
-    if not r.match(server_id):
-        raise exception.InvalidParameterValue(_(
-            "Invalid 'seamicro_server_id' parameter in node's "
-            "driver_info. Expected format of 'seamicro_server_id' "
-            "is <int>/<int>"))
-
-    url = urlparse.urlparse(api_endpoint)
-    if (not (url.scheme == "http") or not url.netloc):
-        raise exception.InvalidParameterValue(_(
-            "Invalid 'seamicro_api_endpoint' parameter in node's "
-            "driver_info."))
 
     res = {'username': username,
            'password': password,
            'api_endpoint': api_endpoint,
            'server_id': server_id,
            'api_version': api_version,
-           'uuid': node.uuid,
-           'port': port}
+           'uuid': node.uuid}
 
     return res
 
@@ -278,8 +250,7 @@ def _power_off(node, timeout=None):
 
 
 def _reboot(node, timeout=None):
-    """Reboot this node.
-
+    """Reboot this node
     :param node: Ironic node one of :class:`ironic.db.models.Node`
     :param timeout: Time in seconds to wait till reboot is compelete
     :raises: InvalidParameterValue if a seamicro parameter is invalid.
@@ -359,12 +330,6 @@ def _create_volume(driver_info, volume_size):
                                                      least_used_pool)
 
 
-def get_telnet_port(driver_info):
-    """Get SeaMicro telnet port to listen."""
-    server_id = int(driver_info['server_id'].split("/")[0])
-    return PORT_BASE + (10 * server_id)
-
-
 class Power(base.PowerInterface):
     """SeaMicro Power Interface.
 
@@ -449,12 +414,22 @@ class VendorPassthru(base.VendorInterface):
     def get_properties(self):
         return COMMON_PROPERTIES
 
-    def validate(self, task, method, **kwargs):
+    def validate(self, task, **kwargs):
+        method = kwargs['method']
+        if method not in VENDOR_PASSTHRU_METHODS:
+            raise exception.InvalidParameterValue(_(
+                "Unsupported method (%s) passed to SeaMicro driver.")
+                % method)
         _parse_driver_info(task.node)
 
-    @base.passthru(['POST'])
-    def set_node_vlan_id(self, task, **kwargs):
-        """Sets an untagged vlan id for NIC 0 of node.
+    def vendor_passthru(self, task, **kwargs):
+        """Dispatch vendor specific method calls."""
+        method = kwargs['method']
+        if method in VENDOR_PASSTHRU_METHODS:
+            return getattr(self, "_" + method)(task, **kwargs)
+
+    def _set_node_vlan_id(self, task, **kwargs):
+        """Sets a untagged vlan id for NIC 0 of node.
 
         @kwargs vlan_id: id of untagged vlan for NIC 0 of node
         """
@@ -481,13 +456,10 @@ class VendorPassthru(base.VendorInterface):
         node.properties = properties
         node.save()
 
-    @base.passthru(['POST'])
-    def attach_volume(self, task, **kwargs):
-        """Attach a volume to a node.
-
-        Attach volume from SeaMicro storage pools for ironic to node.
-        If kwargs['volume_id'] not given, Create volume in SeaMicro
-        storage pool and attach to node.
+    def _attach_volume(self, task, **kwargs):
+        """Attach volume from SeaMicro storage pools for ironic to node.
+            If kwargs['volume_id'] not given, Create volume in SeaMicro
+            storage pool and attach to node.
 
         @kwargs volume_id: id of pre-provisioned volume that is to be attached
                            as root volume of node
@@ -538,10 +510,9 @@ class Management(base.ManagementInterface):
         """
         _parse_driver_info(task.node)
 
-    def get_supported_boot_devices(self, task):
+    def get_supported_boot_devices(self):
         """Get a list of the supported boot devices.
 
-        :param task: a task from TaskManager.
         :returns: A list with the supported boot devices defined
                   in :mod:`ironic.common.boot_devices`.
 
@@ -566,7 +537,7 @@ class Management(base.ManagementInterface):
         :raises: MissingParameterValue when a required parameter is missing
 
         """
-        if device not in self.get_supported_boot_devices(task):
+        if device not in self.get_supported_boot_devices():
             raise exception.InvalidParameterValue(_(
                 "Invalid boot device %s specified.") % device)
 
@@ -578,8 +549,8 @@ class Management(base.ManagementInterface):
         except seamicro_client_exception.ClientException as ex:
             LOG.error(_LE("Seamicro set boot device failed for node "
                           "%(node)s with the following error: %(error)s"),
-                      {'node': task.node.uuid, 'error': ex})
-            raise exception.IronicException(message=six.text_type(ex))
+                      {'node': task.node.uuid, 'error': ex.message})
+            raise exception.IronicException(message=ex.message)
 
     def get_boot_device(self, task):
         """Get the current boot device for the task's node.
@@ -609,73 +580,3 @@ class Management(base.ManagementInterface):
 
         """
         raise NotImplementedError()
-
-
-class ShellinaboxConsole(base.ConsoleInterface):
-    """A ConsoleInterface that uses telnet and shellinabox."""
-
-    def get_properties(self):
-        d = COMMON_PROPERTIES.copy()
-        d.update(CONSOLE_PROPERTIES)
-        return d
-
-    def validate(self, task):
-        """Validate the Node console info.
-
-        :param task: a task from TaskManager.
-        :raises: MissingParameterValue if required seamicro parameters are
-                 missing
-        :raises: InvalidParameterValue if required parameter are invalid.
-        """
-        driver_info = _parse_driver_info(task.node)
-        if not driver_info['port']:
-            raise exception.MissingParameterValue(_(
-                "Missing 'seamicro_terminal_port' parameter in node's "
-                "driver_info"))
-
-    def start_console(self, task):
-        """Start a remote console for the node.
-
-        :param task: a task from TaskManager
-        :raises: MissingParameterValue if required seamicro parameters are
-                 missing
-        :raises: ConsoleError if the directory for the PID file cannot be
-                 created
-        :raises: ConsoleSubprocessFailed when invoking the subprocess failed
-        :raises: InvalidParameterValue if required parameter are invalid.
-        """
-
-        driver_info = _parse_driver_info(task.node)
-        telnet_port = get_telnet_port(driver_info)
-        chassis_ip = urlparse.urlparse(driver_info['api_endpoint']).netloc
-
-        seamicro_cmd = ("/:%(uid)s:%(gid)s:HOME:telnet %(chassis)s %(port)s"
-                        % {'uid': os.getuid(),
-                           'gid': os.getgid(),
-                           'chassis': chassis_ip,
-                           'port': telnet_port})
-
-        console_utils.start_shellinabox_console(driver_info['uuid'],
-                                                driver_info['port'],
-                                                seamicro_cmd)
-
-    def stop_console(self, task):
-        """Stop the remote console session for the node.
-
-        :param task: a task from TaskManager
-        :raises: ConsoleError if unable to stop the console
-        """
-
-        console_utils.stop_shellinabox_console(task.node.uuid)
-
-    def get_console(self, task):
-        """Get the type and connection information about the console.
-
-        :raises: MissingParameterValue if required seamicro parameters are
-                 missing
-        :raises: InvalidParameterValue if required parameter are invalid.
-        """
-
-        driver_info = _parse_driver_info(task.node)
-        url = console_utils.get_shellinabox_console_url(driver_info['port'])
-        return {'type': 'shellinabox', 'url': url}
