@@ -13,83 +13,86 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from oslo_utils import strutils
-from oslo_utils import uuidutils
-from oslo_versionedobjects import base as object_base
-
 from ironic.common import exception
+from ironic.common import utils
 from ironic.db import api as dbapi
 from ironic.objects import base
-from ironic.objects import fields as object_fields
-from ironic.objects import notification
+from ironic.objects import utils as obj_utils
 
 
-@base.IronicObjectRegistry.register
-class Chassis(base.IronicObject, object_base.VersionedObjectDictCompat):
+class Chassis(base.IronicObject):
     # Version 1.0: Initial version
     # Version 1.1: Add get() and get_by_id() and make get_by_uuid()
     #              only work with a uuid
     # Version 1.2: Add create() and destroy()
     # Version 1.3: Add list()
-    # Version 1.4: Relevant methods changed to be remotable methods.
-    VERSION = '1.4'
+    VERSION = '1.3'
 
     dbapi = dbapi.get_instance()
 
     fields = {
-        'id': object_fields.IntegerField(),
-        'uuid': object_fields.UUIDField(nullable=True),
-        'extra': object_fields.FlexibleDictField(nullable=True),
-        'description': object_fields.StringField(nullable=True),
+        'id': int,
+        'uuid': obj_utils.str_or_none,
+        'extra': obj_utils.dict_or_none,
+        'description': obj_utils.str_or_none,
     }
 
-    @object_base.remotable_classmethod
+    @staticmethod
+    def _from_db_object(chassis, db_chassis):
+        """Converts a database entity to a formal :class:`Chassis` object.
+
+        :param chassis: An object of :class:`Chassis`.
+        :param db_chassis: A DB model of a chassis.
+        :return: a :class:`Chassis` object.
+        """
+        for field in chassis.fields:
+            chassis[field] = db_chassis[field]
+
+        chassis.obj_reset_changes()
+        return chassis
+
+    @base.remotable_classmethod
     def get(cls, context, chassis_id):
         """Find a chassis based on its id or uuid and return a Chassis object.
 
-        :param context: Security context
         :param chassis_id: the id *or* uuid of a chassis.
         :returns: a :class:`Chassis` object.
         """
-        if strutils.is_int_like(chassis_id):
+        if utils.is_int_like(chassis_id):
             return cls.get_by_id(context, chassis_id)
-        elif uuidutils.is_uuid_like(chassis_id):
+        elif utils.is_uuid_like(chassis_id):
             return cls.get_by_uuid(context, chassis_id)
         else:
             raise exception.InvalidIdentity(identity=chassis_id)
 
-    @object_base.remotable_classmethod
+    @base.remotable_classmethod
     def get_by_id(cls, context, chassis_id):
-        """Find a chassis based on its integer ID and return a Chassis object.
+        """Find a chassis based on its integer id and return a Chassis object.
 
-        :param cls: the :class:`Chassis`
-        :param context: Security context
-        :param chassis_id: the ID of a chassis.
+        :param chassis_id: the id of a chassis.
         :returns: a :class:`Chassis` object.
         """
         db_chassis = cls.dbapi.get_chassis_by_id(chassis_id)
-        chassis = cls._from_db_object(context, cls(), db_chassis)
+        chassis = Chassis._from_db_object(cls(context), db_chassis)
         return chassis
 
-    @object_base.remotable_classmethod
+    @base.remotable_classmethod
     def get_by_uuid(cls, context, uuid):
-        """Find a chassis based on UUID and return a :class:`Chassis` object.
+        """Find a chassis based on uuid and return a :class:`Chassis` object.
 
-        :param cls: the :class:`Chassis`
+        :param uuid: the uuid of a chassis.
         :param context: Security context
-        :param uuid: the UUID of a chassis.
         :returns: a :class:`Chassis` object.
         """
         db_chassis = cls.dbapi.get_chassis_by_uuid(uuid)
-        chassis = cls._from_db_object(context, cls(), db_chassis)
+        chassis = Chassis._from_db_object(cls(context), db_chassis)
         return chassis
 
-    @object_base.remotable_classmethod
+    @base.remotable_classmethod
     def list(cls, context, limit=None, marker=None,
              sort_key=None, sort_dir=None):
         """Return a list of Chassis objects.
 
-        :param cls: the :class:`Chassis`
         :param context: Security context.
         :param limit: maximum number of resources to return in a single result.
         :param marker: pagination marker for large data sets.
@@ -102,9 +105,10 @@ class Chassis(base.IronicObject, object_base.VersionedObjectDictCompat):
                                                 marker=marker,
                                                 sort_key=sort_key,
                                                 sort_dir=sort_dir)
-        return cls._from_db_object_list(context, db_chassis)
+        return [Chassis._from_db_object(cls(context), obj)
+                for obj in db_chassis]
 
-    @object_base.remotable
+    @base.remotable
     def create(self, context=None):
         """Create a Chassis record in the DB.
 
@@ -121,11 +125,11 @@ class Chassis(base.IronicObject, object_base.VersionedObjectDictCompat):
                         object, e.g.: Chassis(context)
 
         """
-        values = self.do_version_changes_for_db()
+        values = self.obj_get_changes()
         db_chassis = self.dbapi.create_chassis(values)
-        self._from_db_object(self._context, self, db_chassis)
+        self._from_db_object(self, db_chassis)
 
-    @object_base.remotable
+    @base.remotable
     def destroy(self, context=None):
         """Delete the Chassis from the DB.
 
@@ -139,7 +143,7 @@ class Chassis(base.IronicObject, object_base.VersionedObjectDictCompat):
         self.dbapi.destroy_chassis(self.uuid)
         self.obj_reset_changes()
 
-    @object_base.remotable
+    @base.remotable
     def save(self, context=None):
         """Save updates to this Chassis.
 
@@ -153,11 +157,12 @@ class Chassis(base.IronicObject, object_base.VersionedObjectDictCompat):
                         A context should be set when instantiating the
                         object, e.g.: Chassis(context)
         """
-        updates = self.do_version_changes_for_db()
-        updated_chassis = self.dbapi.update_chassis(self.uuid, updates)
-        self._from_db_object(self._context, self, updated_chassis)
+        updates = self.obj_get_changes()
+        self.dbapi.update_chassis(self.uuid, updates)
 
-    @object_base.remotable
+        self.obj_reset_changes()
+
+    @base.remotable
     def refresh(self, context=None):
         """Loads and applies updates for this Chassis.
 
@@ -172,42 +177,8 @@ class Chassis(base.IronicObject, object_base.VersionedObjectDictCompat):
                         A context should be set when instantiating the
                         object, e.g.: Chassis(context)
         """
-        current = self.get_by_uuid(self._context, uuid=self.uuid)
-        self.obj_refresh(current)
-
-
-@base.IronicObjectRegistry.register
-class ChassisCRUDNotification(notification.NotificationBase):
-    """Notification emitted when ironic creates, updates, deletes a chassis."""
-    # Version 1.0: Initial version
-    VERSION = '1.0'
-
-    fields = {
-        'payload': object_fields.ObjectField('ChassisCRUDPayload')
-    }
-
-
-@base.IronicObjectRegistry.register
-class ChassisCRUDPayload(notification.NotificationPayloadBase):
-    # Version 1.0: Initial version
-    VERSION = '1.0'
-
-    SCHEMA = {
-        'description': ('chassis', 'description'),
-        'extra': ('chassis', 'extra'),
-        'created_at': ('chassis', 'created_at'),
-        'updated_at': ('chassis', 'updated_at'),
-        'uuid': ('chassis', 'uuid')
-    }
-
-    fields = {
-        'description': object_fields.StringField(nullable=True),
-        'extra': object_fields.FlexibleDictField(nullable=True),
-        'created_at': object_fields.DateTimeField(nullable=True),
-        'updated_at': object_fields.DateTimeField(nullable=True),
-        'uuid': object_fields.UUIDField()
-    }
-
-    def __init__(self, chassis, **kwargs):
-        super(ChassisCRUDPayload, self).__init__(**kwargs)
-        self.populate_schema(chassis=chassis)
+        current = self.__class__.get_by_uuid(self._context, uuid=self.uuid)
+        for field in self.fields:
+            if (hasattr(self, base.get_attrname(field)) and
+                    self[field] != current[field]):
+                self[field] = current[field]
