@@ -20,23 +20,21 @@
 #       ceilometer/tests/api/__init__.py). This should be oslo'ified:
 #       https://bugs.launchpad.net/ironic/+bug/1255115.
 
-import mock
-from oslo_config import cfg
+# NOTE(deva): import auth_token so we can override a config option
+from keystonemiddleware import auth_token  # noqa
+from oslo.config import cfg
 import pecan
 import pecan.testing
 from six.moves.urllib import parse as urlparse
 
+from ironic.db import api as dbapi
 from ironic.tests.db import base
 
 PATH_PREFIX = '/v1'
 
-cfg.CONF.import_group('keystone_authtoken', 'keystonemiddleware.auth_token')
-
 
 class FunctionalTest(base.DbTestCase):
-    """Pecan controller functional testing class.
-
-    Used for functional tests of Pecan controllers where you need to
+    """Used for functional tests of Pecan controllers where you need to
     test your literal application and its integration with the
     framework.
     """
@@ -50,16 +48,13 @@ class FunctionalTest(base.DbTestCase):
         cfg.CONF.set_override("admin_user", "admin",
                               group='keystone_authtoken')
         self.app = self._make_app()
+        self.dbapi = dbapi.get_instance()
 
         def reset_pecan():
             pecan.set_config({}, overwrite=True)
 
         self.addCleanup(reset_pecan)
 
-        p = mock.patch('ironic.api.controllers.v1.Controller._check_version')
-        self._check_version = p.start()
-        self.addCleanup(p.stop)
-
     def _make_app(self, enable_acl=False):
         # Determine where we are so we can set up paths in the config
         root_dir = self.path_get()
