@@ -17,16 +17,17 @@ are blocked or allowed to be processed.
 """
 
 import mock
-from oslo_config import cfg
-from six.moves import http_client
 
+# NOTE(deva): import auth_token so we can override a config option
+from keystonemiddleware import auth_token  # noqa
+
+from oslo.config import cfg
+
+from ironic.db import api as db_api
 from ironic.tests.api import base
 from ironic.tests.api import utils
 from ironic.tests.db import utils as db_utils
 
-cfg.CONF.import_opt('cache', 'keystonemiddleware.auth_token',
-                    group='keystone_authtoken')
-
 
 class TestACL(base.FunctionalTest):
 
@@ -35,15 +36,16 @@ class TestACL(base.FunctionalTest):
 
         self.environ = {'fake.cache': utils.FakeMemcache()}
         self.fake_db_node = db_utils.get_test_node(chassis_id=None)
+        self.dbapi = db_api.get_instance()
         self.node_path = '/nodes/%s' % self.fake_db_node['uuid']
 
     def get_json(self, path, expect_errors=False, headers=None, q=[], **param):
         return super(TestACL, self).get_json(path,
-                                             expect_errors=expect_errors,
-                                             headers=headers,
-                                             q=q,
-                                             extra_environ=self.environ,
-                                             **param)
+                                                expect_errors=expect_errors,
+                                                headers=headers,
+                                                q=q,
+                                                extra_environ=self.environ,
+                                                **param)
 
     def _make_app(self):
         cfg.CONF.set_override('cache', 'fake.cache',
@@ -52,15 +54,15 @@ class TestACL(base.FunctionalTest):
 
     def test_non_authenticated(self):
         response = self.get_json(self.node_path, expect_errors=True)
-        self.assertEqual(http_client.UNAUTHORIZED, response.status_int)
+        self.assertEqual(401, response.status_int)
 
     def test_authenticated(self):
         with mock.patch.object(self.dbapi, 'get_node_by_uuid',
                                autospec=True) as mock_get_node:
             mock_get_node.return_value = self.fake_db_node
 
-            response = self.get_json(
-                self.node_path, headers={'X-Auth-Token': utils.ADMIN_TOKEN})
+            response = self.get_json(self.node_path,
+                                 headers={'X-Auth-Token': utils.ADMIN_TOKEN})
 
             self.assertEqual(self.fake_db_node['uuid'], response['uuid'])
             mock_get_node.assert_called_once_with(self.fake_db_node['uuid'])
@@ -70,7 +72,7 @@ class TestACL(base.FunctionalTest):
                                  headers={'X-Auth-Token': utils.MEMBER_TOKEN},
                                  expect_errors=True)
 
-        self.assertEqual(http_client.FORBIDDEN, response.status_int)
+        self.assertEqual(403, response.status_int)
 
     def test_non_admin_with_admin_header(self):
         response = self.get_json(self.node_path,
@@ -78,7 +80,7 @@ class TestACL(base.FunctionalTest):
                                           'X-Roles': 'admin'},
                                  expect_errors=True)
 
-        self.assertEqual(http_client.FORBIDDEN, response.status_int)
+        self.assertEqual(403, response.status_int)
 
     def test_public_api(self):
         # expect_errors should be set to True: If expect_errors is set to False
@@ -87,13 +89,10 @@ class TestACL(base.FunctionalTest):
         for route in ('/', '/v1'):
             response = self.get_json(route,
                                      path_prefix='', expect_errors=True)
-            self.assertEqual(http_client.OK, response.status_int)
+            self.assertEqual(200, response.status_int)
 
     def test_public_api_with_path_extensions(self):
-        routes = {'/v1/': http_client.OK,
-                  '/v1.json': http_client.OK,
-                  '/v1.xml': http_client.NOT_FOUND}
-        for url in routes:
-            response = self.get_json(url,
+        for route in ('/v1/', '/v1.json', '/v1.xml'):
+            response = self.get_json(route,
                                      path_prefix='', expect_errors=True)
-            self.assertEqual(routes[url], response.status_int)
+            self.assertEqual(200, response.status_int)
