@@ -18,33 +18,17 @@ Tests for the API /chassis/ methods.
 import datetime
 
 import mock
-from oslo_config import cfg
-from oslo_utils import timeutils
-from oslo_utils import uuidutils
-import six
-from six.moves import http_client
+from oslo.config import cfg
+from oslo.utils import timeutils
 from six.moves.urllib import parse as urlparse
-from wsme import types as wtypes
 
-from ironic.api.controllers import base as api_base
-from ironic.api.controllers import v1 as api_v1
-from ironic.api.controllers.v1 import chassis as api_chassis
-from ironic.tests.api import base as test_api_base
+from ironic.common import utils
+from ironic.tests.api import base
 from ironic.tests.api import utils as apiutils
-from ironic.tests import base
 from ironic.tests.objects import utils as obj_utils
 
 
-class TestChassisObject(base.TestCase):
-
-    def test_chassis_init(self):
-        chassis_dict = apiutils.chassis_post_data()
-        del chassis_dict['description']
-        chassis = api_chassis.Chassis(**chassis_dict)
-        self.assertEqual(wtypes.Unset, chassis.description)
-
-
-class TestListChassis(test_api_base.FunctionalTest):
+class TestListChassis(base.FunctionalTest):
 
     def test_empty(self):
         data = self.get_json('/chassis')
@@ -64,50 +48,6 @@ class TestListChassis(test_api_base.FunctionalTest):
         self.assertIn('extra', data)
         self.assertIn('nodes', data)
 
-    def test_get_one_custom_fields(self):
-        chassis = obj_utils.create_test_chassis(self.context)
-        fields = 'extra,description'
-        data = self.get_json(
-            '/chassis/%s?fields=%s' % (chassis.uuid, fields),
-            headers={api_base.Version.string: str(api_v1.MAX_VER)})
-        # We always append "links"
-        self.assertItemsEqual(['description', 'extra', 'links'], data)
-
-    def test_get_collection_custom_fields(self):
-        fields = 'uuid,extra'
-        for i in range(3):
-            obj_utils.create_test_chassis(
-                self.context, uuid=uuidutils.generate_uuid())
-
-        data = self.get_json(
-            '/chassis?fields=%s' % fields,
-            headers={api_base.Version.string: str(api_v1.MAX_VER)})
-
-        self.assertEqual(3, len(data['chassis']))
-        for ch in data['chassis']:
-            # We always append "links"
-            self.assertItemsEqual(['uuid', 'extra', 'links'], ch)
-
-    def test_get_custom_fields_invalid_fields(self):
-        chassis = obj_utils.create_test_chassis(self.context)
-        fields = 'uuid,spongebob'
-        response = self.get_json(
-            '/chassis/%s?fields=%s' % (chassis.uuid, fields),
-            headers={api_base.Version.string: str(api_v1.MAX_VER)},
-            expect_errors=True)
-        self.assertEqual(http_client.BAD_REQUEST, response.status_int)
-        self.assertEqual('application/json', response.content_type)
-        self.assertIn('spongebob', response.json['error_message'])
-
-    def test_get_custom_fields_invalid_api_version(self):
-        chassis = obj_utils.create_test_chassis(self.context)
-        fields = 'uuid,extra'
-        response = self.get_json(
-            '/chassis/%s?fields=%s' % (chassis.uuid, fields),
-            headers={api_base.Version.string: str(api_v1.MIN_VER)},
-            expect_errors=True)
-        self.assertEqual(http_client.NOT_ACCEPTABLE, response.status_int)
-
     def test_detail(self):
         chassis = obj_utils.create_test_chassis(self.context)
         data = self.get_json('/chassis/detail')
@@ -119,23 +59,22 @@ class TestListChassis(test_api_base.FunctionalTest):
         chassis = obj_utils.create_test_chassis(self.context)
         response = self.get_json('/chassis/%s/detail' % chassis['uuid'],
                                  expect_errors=True)
-        self.assertEqual(http_client.NOT_FOUND, response.status_int)
+        self.assertEqual(404, response.status_int)
 
     def test_many(self):
         ch_list = []
         for id_ in range(5):
-            chassis = obj_utils.create_test_chassis(
-                self.context, uuid=uuidutils.generate_uuid())
+            chassis = obj_utils.create_test_chassis(self.context, id=id_,
+                                                    uuid=utils.generate_uuid())
             ch_list.append(chassis.uuid)
         data = self.get_json('/chassis')
         self.assertEqual(len(ch_list), len(data['chassis']))
         uuids = [n['uuid'] for n in data['chassis']]
-        six.assertCountEqual(self, ch_list, uuids)
+        self.assertEqual(ch_list.sort(), uuids.sort())
 
-    def _test_links(self, public_url=None):
-        cfg.CONF.set_override('public_endpoint', public_url, 'api')
-        uuid = uuidutils.generate_uuid()
-        obj_utils.create_test_chassis(self.context, uuid=uuid)
+    def test_links(self):
+        uuid = utils.generate_uuid()
+        obj_utils.create_test_chassis(self.context, id=1, uuid=uuid)
         data = self.get_json('/chassis/%s' % uuid)
         self.assertIn('links', data.keys())
         self.assertEqual(2, len(data['links']))
@@ -144,24 +83,10 @@ class TestListChassis(test_api_base.FunctionalTest):
             bookmark = l['rel'] == 'bookmark'
             self.assertTrue(self.validate_link(l['href'], bookmark=bookmark))
 
-        if public_url is not None:
-            expected = [{'href': '%s/v1/chassis/%s' % (public_url, uuid),
-                         'rel': 'self'},
-                        {'href': '%s/chassis/%s' % (public_url, uuid),
-                         'rel': 'bookmark'}]
-            for i in expected:
-                self.assertIn(i, data['links'])
-
-    def test_links(self):
-        self._test_links()
-
-    def test_links_public_url(self):
-        self._test_links(public_url='http://foo')
-
     def test_collection_links(self):
         for id in range(5):
-            obj_utils.create_test_chassis(self.context,
-                                          uuid=uuidutils.generate_uuid())
+            obj_utils.create_test_chassis(self.context, id=id,
+                                          uuid=utils.generate_uuid())
         data = self.get_json('/chassis/?limit=3')
         self.assertEqual(3, len(data['chassis']))
 
@@ -171,33 +96,14 @@ class TestListChassis(test_api_base.FunctionalTest):
     def test_collection_links_default_limit(self):
         cfg.CONF.set_override('max_limit', 3, 'api')
         for id_ in range(5):
-            obj_utils.create_test_chassis(self.context,
-                                          uuid=uuidutils.generate_uuid())
+            obj_utils.create_test_chassis(self.context, id=id_,
+                                          uuid=utils.generate_uuid())
         data = self.get_json('/chassis')
         self.assertEqual(3, len(data['chassis']))
 
         next_marker = data['chassis'][-1]['uuid']
         self.assertIn(next_marker, data['next'])
 
-    def test_sort_key(self):
-        ch_list = []
-        for id_ in range(3):
-            chassis = obj_utils.create_test_chassis(
-                self.context, uuid=uuidutils.generate_uuid())
-            ch_list.append(chassis.uuid)
-        data = self.get_json('/chassis?sort_key=uuid')
-        uuids = [n['uuid'] for n in data['chassis']]
-        self.assertEqual(sorted(ch_list), uuids)
-
-    def test_sort_key_invalid(self):
-        invalid_keys_list = ['foo', 'extra']
-        for invalid_key in invalid_keys_list:
-            response = self.get_json('/chassis?sort_key=%s' % invalid_key,
-                                     expect_errors=True)
-            self.assertEqual(http_client.BAD_REQUEST, response.status_int)
-            self.assertEqual('application/json', response.content_type)
-            self.assertIn(invalid_key, response.json['error_message'])
-
     def test_nodes_subresource_link(self):
         chassis = obj_utils.create_test_chassis(self.context)
         data = self.get_json('/chassis/%s' % chassis.uuid)
@@ -207,9 +113,9 @@ class TestListChassis(test_api_base.FunctionalTest):
         chassis = obj_utils.create_test_chassis(self.context)
 
         for id_ in range(2):
-            obj_utils.create_test_node(self.context,
+            obj_utils.create_test_node(self.context, id=id_,
                                        chassis_id=chassis.id,
-                                       uuid=uuidutils.generate_uuid())
+                                       uuid=utils.generate_uuid())
 
         data = self.get_json('/chassis/%s/nodes' % chassis.uuid)
         self.assertEqual(2, len(data['nodes']))
@@ -222,28 +128,28 @@ class TestListChassis(test_api_base.FunctionalTest):
 
     def test_nodes_subresource_no_uuid(self):
         response = self.get_json('/chassis/nodes', expect_errors=True)
-        self.assertEqual(http_client.BAD_REQUEST, response.status_int)
+        self.assertEqual(400, response.status_int)
 
     def test_nodes_subresource_chassis_not_found(self):
         non_existent_uuid = 'eeeeeeee-cccc-aaaa-bbbb-cccccccccccc'
         response = self.get_json('/chassis/%s/nodes' % non_existent_uuid,
                                  expect_errors=True)
-        self.assertEqual(http_client.NOT_FOUND, response.status_int)
+        self.assertEqual(404, response.status_int)
 
 
-class TestPatch(test_api_base.FunctionalTest):
+class TestPatch(base.FunctionalTest):
 
     def setUp(self):
         super(TestPatch, self).setUp()
         obj_utils.create_test_chassis(self.context)
 
     def test_update_not_found(self):
-        uuid = uuidutils.generate_uuid()
+        uuid = utils.generate_uuid()
         response = self.patch_json('/chassis/%s' % uuid,
                                    [{'path': '/extra/a', 'value': 'b',
                                      'op': 'add'}],
                                    expect_errors=True)
-        self.assertEqual(http_client.NOT_FOUND, response.status_int)
+        self.assertEqual(404, response.status_int)
         self.assertEqual('application/json', response.content_type)
         self.assertTrue(response.json['error_message'])
 
@@ -258,23 +164,24 @@ class TestPatch(test_api_base.FunctionalTest):
                                    [{'path': '/description',
                                      'value': description, 'op': 'replace'}])
         self.assertEqual('application/json', response.content_type)
-        self.assertEqual(http_client.OK, response.status_code)
+        self.assertEqual(200, response.status_code)
         result = self.get_json('/chassis/%s' % chassis.uuid)
         self.assertEqual(description, result['description'])
         return_updated_at = timeutils.parse_isotime(
-            result['updated_at']).replace(tzinfo=None)
+                            result['updated_at']).replace(tzinfo=None)
         self.assertEqual(test_time, return_updated_at)
 
     def test_replace_multi(self):
         extra = {"foo1": "bar1", "foo2": "bar2", "foo3": "bar3"}
         chassis = obj_utils.create_test_chassis(self.context, extra=extra,
-                                                uuid=uuidutils.generate_uuid())
+                                                uuid=utils.generate_uuid(),
+                                                id=1)
         new_value = 'new value'
         response = self.patch_json('/chassis/%s' % chassis.uuid,
                                    [{'path': '/extra/foo2',
                                      'value': new_value, 'op': 'replace'}])
         self.assertEqual('application/json', response.content_type)
-        self.assertEqual(http_client.OK, response.status_code)
+        self.assertEqual(200, response.status_code)
         result = self.get_json('/chassis/%s' % chassis.uuid)
 
         extra["foo2"] = new_value
@@ -282,11 +189,12 @@ class TestPatch(test_api_base.FunctionalTest):
 
     def test_remove_singular(self):
         chassis = obj_utils.create_test_chassis(self.context, extra={'a': 'b'},
-                                                uuid=uuidutils.generate_uuid())
+                                                uuid=utils.generate_uuid(),
+                                                id=1)
         response = self.patch_json('/chassis/%s' % chassis.uuid,
                                    [{'path': '/description', 'op': 'remove'}])
         self.assertEqual('application/json', response.content_type)
-        self.assertEqual(http_client.OK, response.status_code)
+        self.assertEqual(200, response.status_code)
         result = self.get_json('/chassis/%s' % chassis.uuid)
         self.assertIsNone(result['description'])
 
@@ -298,13 +206,14 @@ class TestPatch(test_api_base.FunctionalTest):
         extra = {"foo1": "bar1", "foo2": "bar2", "foo3": "bar3"}
         chassis = obj_utils.create_test_chassis(self.context, extra=extra,
                                                 description="foobar",
-                                                uuid=uuidutils.generate_uuid())
+                                                uuid=utils.generate_uuid(),
+                                                id=1)
 
         # Removing one item from the collection
         response = self.patch_json('/chassis/%s' % chassis.uuid,
                                    [{'path': '/extra/foo2', 'op': 'remove'}])
         self.assertEqual('application/json', response.content_type)
-        self.assertEqual(http_client.OK, response.status_code)
+        self.assertEqual(200, response.status_code)
         result = self.get_json('/chassis/%s' % chassis.uuid)
         extra.pop("foo2")
         self.assertEqual(extra, result['extra'])
@@ -313,7 +222,7 @@ class TestPatch(test_api_base.FunctionalTest):
         response = self.patch_json('/chassis/%s' % chassis.uuid,
                                    [{'path': '/extra', 'op': 'remove'}])
         self.assertEqual('application/json', response.content_type)
-        self.assertEqual(http_client.OK, response.status_code)
+        self.assertEqual(200, response.status_code)
         result = self.get_json('/chassis/%s' % chassis.uuid)
         self.assertEqual({}, result['extra'])
 
@@ -323,12 +232,11 @@ class TestPatch(test_api_base.FunctionalTest):
 
     def test_remove_non_existent_property_fail(self):
         chassis = obj_utils.get_test_chassis(self.context)
-        response = self.patch_json(
-            '/chassis/%s' % chassis.uuid,
-            [{'path': '/extra/non-existent', 'op': 'remove'}],
-            expect_errors=True)
+        response = self.patch_json('/chassis/%s' % chassis.uuid,
+                             [{'path': '/extra/non-existent', 'op': 'remove'}],
+                             expect_errors=True)
         self.assertEqual('application/json', response.content_type)
-        self.assertEqual(http_client.BAD_REQUEST, response.status_code)
+        self.assertEqual(400, response.status_code)
         self.assertTrue(response.json['error_message'])
 
     def test_add_root(self):
@@ -337,7 +245,7 @@ class TestPatch(test_api_base.FunctionalTest):
                                    [{'path': '/description', 'value': 'test',
                                      'op': 'add'}])
         self.assertEqual('application/json', response.content_type)
-        self.assertEqual(http_client.OK, response.status_int)
+        self.assertEqual(200, response.status_int)
 
     def test_add_root_non_existent(self):
         chassis = obj_utils.get_test_chassis(self.context)
@@ -346,7 +254,7 @@ class TestPatch(test_api_base.FunctionalTest):
                                      'op': 'add'}],
                                    expect_errors=True)
         self.assertEqual('application/json', response.content_type)
-        self.assertEqual(http_client.BAD_REQUEST, response.status_int)
+        self.assertEqual(400, response.status_int)
         self.assertTrue(response.json['error_message'])
 
     def test_add_multi(self):
@@ -357,7 +265,7 @@ class TestPatch(test_api_base.FunctionalTest):
                                     {'path': '/extra/foo2', 'value': 'bar2',
                                      'op': 'add'}])
         self.assertEqual('application/json', response.content_type)
-        self.assertEqual(http_client.OK, response.status_code)
+        self.assertEqual(200, response.status_code)
         result = self.get_json('/chassis/%s' % chassis.uuid)
         expected = {"foo1": "bar1", "foo2": "bar2"}
         self.assertEqual(expected, result['extra'])
@@ -367,19 +275,19 @@ class TestPatch(test_api_base.FunctionalTest):
         response = self.patch_json('/chassis/%s/nodes' % chassis.uuid,
                                    [{'path': '/extra/foo', 'value': 'bar',
                                      'op': 'add'}], expect_errors=True)
-        self.assertEqual(http_client.FORBIDDEN, response.status_int)
+        self.assertEqual(403, response.status_int)
 
     def test_remove_uuid(self):
         chassis = obj_utils.get_test_chassis(self.context)
         response = self.patch_json('/chassis/%s' % chassis.uuid,
                                    [{'path': '/uuid', 'op': 'remove'}],
                                    expect_errors=True)
-        self.assertEqual(http_client.BAD_REQUEST, response.status_int)
+        self.assertEqual(400, response.status_int)
         self.assertEqual('application/json', response.content_type)
         self.assertTrue(response.json['error_message'])
 
 
-class TestPost(test_api_base.FunctionalTest):
+class TestPost(base.FunctionalTest):
 
     @mock.patch.object(timeutils, 'utcnow')
     def test_create_chassis(self, mock_utcnow):
@@ -388,12 +296,12 @@ class TestPost(test_api_base.FunctionalTest):
         mock_utcnow.return_value = test_time
 
         response = self.post_json('/chassis', cdict)
-        self.assertEqual(http_client.CREATED, response.status_int)
+        self.assertEqual(201, response.status_int)
         result = self.get_json('/chassis/%s' % cdict['uuid'])
         self.assertEqual(cdict['uuid'], result['uuid'])
         self.assertFalse(result['updated_at'])
         return_created_at = timeutils.parse_isotime(
-            result['created_at']).replace(tzinfo=None)
+                            result['created_at']).replace(tzinfo=None)
         self.assertEqual(test_time, return_created_at)
         # Check location header
         self.assertIsNotNone(response.location)
@@ -419,25 +327,29 @@ class TestPost(test_api_base.FunctionalTest):
         result = self.get_json('/chassis')
         self.assertEqual(cdict['description'],
                          result['chassis'][0]['description'])
-        self.assertTrue(uuidutils.is_uuid_like(result['chassis'][0]['uuid']))
+        self.assertTrue(utils.is_uuid_like(result['chassis'][0]['uuid']))
 
     def test_post_nodes_subresource(self):
         chassis = obj_utils.create_test_chassis(self.context)
-        ndict = apiutils.node_post_data()
+        ndict = apiutils.node_post_data(chassis_id=None)
         ndict['chassis_uuid'] = chassis.uuid
         response = self.post_json('/chassis/nodes', ndict,
-                                  expect_errors=True)
-        self.assertEqual(http_client.FORBIDDEN, response.status_int)
+                                   expect_errors=True)
+        self.assertEqual(403, response.status_int)
 
     def test_create_chassis_valid_extra(self):
-        cdict = apiutils.chassis_post_data(extra={'str': 'foo', 'int': 123,
-                                                  'float': 0.1, 'bool': True,
-                                                  'list': [1, 2], 'none': None,
-                                                  'dict': {'cat': 'meow'}})
+        cdict = apiutils.chassis_post_data(extra={'foo': 123})
         self.post_json('/chassis', cdict)
         result = self.get_json('/chassis/%s' % cdict['uuid'])
         self.assertEqual(cdict['extra'], result['extra'])
 
+    def test_create_chassis_invalid_extra(self):
+        cdict = apiutils.chassis_post_data(extra={'foo': 0.123})
+        response = self.post_json('/chassis', cdict, expect_errors=True)
+        self.assertEqual(400, response.status_int)
+        self.assertEqual('application/json', response.content_type)
+        self.assertTrue(response.json['error_message'])
+
     def test_create_chassis_unicode_description(self):
         descr = u'\u0430\u043c\u043e'
         cdict = apiutils.chassis_post_data(description=descr)
@@ -446,14 +358,14 @@ class TestPost(test_api_base.FunctionalTest):
         self.assertEqual(descr, result['description'])
 
 
-class TestDelete(test_api_base.FunctionalTest):
+class TestDelete(base.FunctionalTest):
 
     def test_delete_chassis(self):
         chassis = obj_utils.create_test_chassis(self.context)
         self.delete('/chassis/%s' % chassis.uuid)
         response = self.get_json('/chassis/%s' % chassis.uuid,
                                  expect_errors=True)
-        self.assertEqual(http_client.NOT_FOUND, response.status_int)
+        self.assertEqual(404, response.status_int)
         self.assertEqual('application/json', response.content_type)
         self.assertTrue(response.json['error_message'])
 
@@ -462,15 +374,15 @@ class TestDelete(test_api_base.FunctionalTest):
         obj_utils.create_test_node(self.context, chassis_id=chassis.id)
         response = self.delete('/chassis/%s' % chassis.uuid,
                                expect_errors=True)
-        self.assertEqual(http_client.BAD_REQUEST, response.status_int)
+        self.assertEqual(400, response.status_int)
         self.assertEqual('application/json', response.content_type)
         self.assertTrue(response.json['error_message'])
         self.assertIn(chassis.uuid, response.json['error_message'])
 
     def test_delete_chassis_not_found(self):
-        uuid = uuidutils.generate_uuid()
+        uuid = utils.generate_uuid()
         response = self.delete('/chassis/%s' % uuid, expect_errors=True)
-        self.assertEqual(http_client.NOT_FOUND, response.status_int)
+        self.assertEqual(404, response.status_int)
         self.assertEqual('application/json', response.content_type)
         self.assertTrue(response.json['error_message'])
 
@@ -478,4 +390,4 @@ class TestDelete(test_api_base.FunctionalTest):
         chassis = obj_utils.create_test_chassis(self.context)
         response = self.delete('/chassis/%s/nodes' % chassis.uuid,
                                expect_errors=True)
-        self.assertEqual(http_client.FORBIDDEN, response.status_int)
+        self.assertEqual(403, response.status_int)
