@@ -17,18 +17,16 @@
 
 import mock
 import six
-from six.moves import http_client
 import webtest
 import wsme
-from wsme import types as wtypes
 
 from ironic.api.controllers.v1 import types
 from ironic.common import exception
 from ironic.common import utils
-from ironic.tests import base
+from ironic.tests.api import base
 
 
-class TestMacAddressType(base.TestCase):
+class TestMacAddressType(base.FunctionalTest):
 
     def test_valid_mac_addr(self):
         test_mac = 'aa:bb:cc:11:22:33'
@@ -41,53 +39,19 @@ class TestMacAddressType(base.TestCase):
                           types.MacAddressType.validate, 'invalid-mac')
 
 
-class TestUuidType(base.TestCase):
+class TestUuidType(base.FunctionalTest):
 
     def test_valid_uuid(self):
         test_uuid = '1a1a1a1a-2b2b-3c3c-4d4d-5e5e5e5e5e5e'
-        self.assertEqual(test_uuid, types.UuidType.validate(test_uuid))
+        with mock.patch.object(utils, 'is_uuid_like') as uuid_mock:
+            types.UuidType.validate(test_uuid)
+            uuid_mock.assert_called_once_with(test_uuid)
 
     def test_invalid_uuid(self):
         self.assertRaises(exception.InvalidUUID,
                           types.UuidType.validate, 'invalid-uuid')
 
 
-class TestNameType(base.TestCase):
-
-    @mock.patch("pecan.request")
-    def test_valid_name(self, mock_pecan_req):
-        mock_pecan_req.version.minor = 10
-        test_name = 'hal-9000'
-        self.assertEqual(test_name, types.NameType.validate(test_name))
-
-    @mock.patch("pecan.request")
-    def test_invalid_name(self, mock_pecan_req):
-        mock_pecan_req.version.minor = 10
-        self.assertRaises(exception.InvalidName,
-                          types.NameType.validate, '-this is not valid-')
-
-
-class TestUuidOrNameType(base.TestCase):
-
-    @mock.patch("pecan.request")
-    def test_valid_uuid(self, mock_pecan_req):
-        mock_pecan_req.version.minor = 10
-        test_uuid = '1a1a1a1a-2b2b-3c3c-4d4d-5e5e5e5e5e5e'
-        self.assertTrue(types.UuidOrNameType.validate(test_uuid))
-
-    @mock.patch("pecan.request")
-    def test_valid_name(self, mock_pecan_req):
-        mock_pecan_req.version.minor = 10
-        test_name = 'dc16-database5'
-        self.assertTrue(types.UuidOrNameType.validate(test_name))
-
-    @mock.patch("pecan.request")
-    def test_invalid_uuid_or_name(self, mock_pecan_req):
-        mock_pecan_req.version.minor = 10
-        self.assertRaises(exception.InvalidUuidOrName,
-                          types.UuidOrNameType.validate, 'inval#uuid%or*name')
-
-
 class MyPatchType(types.JsonPatchType):
     """Helper class for TestJsonPatchType tests."""
 
@@ -109,7 +73,7 @@ class MyRoot(wsme.WSRoot):
         return patch
 
 
-class TestJsonPatchType(base.TestCase):
+class TestJsonPatchType(base.FunctionalTest):
 
     def setUp(self):
         super(TestJsonPatchType, self).setUp()
@@ -117,89 +81,94 @@ class TestJsonPatchType(base.TestCase):
 
     def _patch_json(self, params, expect_errors=False):
         return self.app.patch_json('/test', params=params,
-                                   headers={'Accept': 'application/json'},
-                                   expect_errors=expect_errors)
+                              headers={'Accept': 'application/json'},
+                              expect_errors=expect_errors)
 
     def test_valid_patches(self):
         valid_patches = [{'path': '/extra/foo', 'op': 'remove'},
                          {'path': '/extra/foo', 'op': 'add', 'value': 'bar'},
-                         {'path': '/str', 'op': 'replace', 'value': 'bar'},
-                         {'path': '/bool', 'op': 'add', 'value': True},
-                         {'path': '/int', 'op': 'add', 'value': 1},
-                         {'path': '/float', 'op': 'add', 'value': 0.123},
-                         {'path': '/list', 'op': 'add', 'value': [1, 2]},
-                         {'path': '/none', 'op': 'add', 'value': None},
-                         {'path': '/empty_dict', 'op': 'add', 'value': {}},
-                         {'path': '/empty_list', 'op': 'add', 'value': []},
-                         {'path': '/dict', 'op': 'add',
-                          'value': {'cat': 'meow'}}]
+                         {'path': '/foo', 'op': 'replace', 'value': 'bar'}]
         ret = self._patch_json(valid_patches, False)
-        self.assertEqual(http_client.OK, ret.status_int)
-        self.assertItemsEqual(valid_patches, ret.json)
+        self.assertEqual(200, ret.status_int)
+        self.assertEqual(sorted(valid_patches), sorted(ret.json))
 
     def test_cannot_update_internal_attr(self):
         patch = [{'path': '/internal', 'op': 'replace', 'value': 'foo'}]
         ret = self._patch_json(patch, True)
-        self.assertEqual(http_client.BAD_REQUEST, ret.status_int)
-        self.assertTrue(ret.json['faultstring'])
-
-    def test_cannot_update_internal_dict_attr(self):
-        patch = [{'path': '/internal/test', 'op': 'replace',
-                 'value': 'foo'}]
-        ret = self._patch_json(patch, True)
-        self.assertEqual(http_client.BAD_REQUEST, ret.status_int)
+        self.assertEqual(400, ret.status_int)
         self.assertTrue(ret.json['faultstring'])
 
     def test_mandatory_attr(self):
         patch = [{'op': 'replace', 'path': '/mandatory', 'value': 'foo'}]
         ret = self._patch_json(patch, False)
-        self.assertEqual(http_client.OK, ret.status_int)
+        self.assertEqual(200, ret.status_int)
         self.assertEqual(patch, ret.json)
 
     def test_cannot_remove_mandatory_attr(self):
         patch = [{'op': 'remove', 'path': '/mandatory'}]
         ret = self._patch_json(patch, True)
-        self.assertEqual(http_client.BAD_REQUEST, ret.status_int)
+        self.assertEqual(400, ret.status_int)
         self.assertTrue(ret.json['faultstring'])
 
     def test_missing_required_fields_path(self):
         missing_path = [{'op': 'remove'}]
         ret = self._patch_json(missing_path, True)
-        self.assertEqual(http_client.BAD_REQUEST, ret.status_int)
+        self.assertEqual(400, ret.status_int)
         self.assertTrue(ret.json['faultstring'])
 
     def test_missing_required_fields_op(self):
         missing_op = [{'path': '/foo'}]
         ret = self._patch_json(missing_op, True)
-        self.assertEqual(http_client.BAD_REQUEST, ret.status_int)
+        self.assertEqual(400, ret.status_int)
         self.assertTrue(ret.json['faultstring'])
 
     def test_invalid_op(self):
         patch = [{'path': '/foo', 'op': 'invalid'}]
         ret = self._patch_json(patch, True)
-        self.assertEqual(http_client.BAD_REQUEST, ret.status_int)
+        self.assertEqual(400, ret.status_int)
         self.assertTrue(ret.json['faultstring'])
 
     def test_invalid_path(self):
         patch = [{'path': 'invalid-path', 'op': 'remove'}]
         ret = self._patch_json(patch, True)
-        self.assertEqual(http_client.BAD_REQUEST, ret.status_int)
+        self.assertEqual(400, ret.status_int)
         self.assertTrue(ret.json['faultstring'])
 
     def test_cannot_add_with_no_value(self):
         patch = [{'path': '/extra/foo', 'op': 'add'}]
         ret = self._patch_json(patch, True)
-        self.assertEqual(http_client.BAD_REQUEST, ret.status_int)
+        self.assertEqual(400, ret.status_int)
         self.assertTrue(ret.json['faultstring'])
 
     def test_cannot_replace_with_no_value(self):
         patch = [{'path': '/foo', 'op': 'replace'}]
         ret = self._patch_json(patch, True)
-        self.assertEqual(http_client.BAD_REQUEST, ret.status_int)
+        self.assertEqual(400, ret.status_int)
         self.assertTrue(ret.json['faultstring'])
 
 
-class TestBooleanType(base.TestCase):
+class TestMultiType(base.FunctionalTest):
+
+    def test_valid_values(self):
+        vt = types.MultiType(wsme.types.text, six.integer_types)
+        value = vt.validate("hello")
+        self.assertEqual("hello", value)
+        value = vt.validate(10)
+        self.assertEqual(10, value)
+
+    def test_invalid_values(self):
+        vt = types.MultiType(wsme.types.text, six.integer_types)
+        self.assertRaises(ValueError, vt.validate, 0.10)
+        self.assertRaises(ValueError, vt.validate, object())
+
+    def test_multitype_tostring(self):
+        vt = types.MultiType(str, int)
+        vts = str(vt)
+        self.assertIn(str(str), vts)
+        self.assertIn(str(int), vts)
+
+
+class TestBooleanType(base.FunctionalTest):
 
     def test_valid_true_values(self):
         v = types.BooleanType()
@@ -227,53 +196,3 @@ class TestBooleanType(base.TestCase):
         v = types.BooleanType()
         self.assertRaises(exception.Invalid, v.validate, "invalid-value")
         self.assertRaises(exception.Invalid, v.validate, "01")
-
-
-class TestJsonType(base.TestCase):
-
-    def test_valid_values(self):
-        vt = types.jsontype
-        value = vt.validate("hello")
-        self.assertEqual("hello", value)
-        value = vt.validate(10)
-        self.assertEqual(10, value)
-        value = vt.validate(0.123)
-        self.assertEqual(0.123, value)
-        value = vt.validate(True)
-        self.assertEqual(True, value)
-        value = vt.validate([1, 2, 3])
-        self.assertEqual([1, 2, 3], value)
-        value = vt.validate({'foo': 'bar'})
-        self.assertEqual({'foo': 'bar'}, value)
-        value = vt.validate(None)
-        self.assertIsNone(value)
-
-    def test_invalid_values(self):
-        vt = types.jsontype
-        self.assertRaises(exception.Invalid, vt.validate, object())
-
-    def test_apimultitype_tostring(self):
-        vts = str(types.jsontype)
-        self.assertIn(str(wtypes.text), vts)
-        self.assertIn(str(int), vts)
-        if six.PY2:
-            self.assertIn(str(long), vts)
-        self.assertIn(str(float), vts)
-        self.assertIn(str(types.BooleanType), vts)
-        self.assertIn(str(list), vts)
-        self.assertIn(str(dict), vts)
-        self.assertIn(str(None), vts)
-
-
-class TestListType(base.TestCase):
-
-    def test_list_type(self):
-        v = types.ListType()
-        self.assertItemsEqual(['foo', 'bar'], v.validate('foo,bar'))
-        self.assertItemsEqual(['cat', 'meow'], v.validate("cat  ,  meow"))
-        self.assertItemsEqual(['spongebob', 'squarepants'],
-                              v.validate("SpongeBob,SquarePants"))
-        self.assertItemsEqual(['foo', 'bar'],
-                              v.validate("foo, ,,bar"))
-        self.assertItemsEqual(['foo', 'bar'],
-                              v.validate("foo,foo,foo,bar"))
