@@ -20,16 +20,13 @@
 import eventlet
 from eventlet import greenpool
 import mock
-from oslo_utils import uuidutils
 
 from ironic.common import driver_factory
 from ironic.common import exception
-from ironic.common import fsm
-from ironic.common import states
+from ironic.common import utils
 from ironic.conductor import task_manager
 from ironic import objects
 from ironic.tests import base as tests_base
-from ironic.tests.db import base as tests_db_base
 from ironic.tests.objects import utils as obj_utils
 
 
@@ -38,13 +35,14 @@ from ironic.tests.objects import utils as obj_utils
 @mock.patch.object(objects.Node, 'reserve')
 @mock.patch.object(driver_factory, 'get_driver')
 @mock.patch.object(objects.Port, 'list_by_node_id')
-class TaskManagerTestCase(tests_db_base.DbTestCase):
+class TaskManagerTestCase(tests_base.TestCase):
     def setUp(self):
         super(TaskManagerTestCase, self).setUp()
         self.host = 'test-host'
         self.config(host=self.host)
         self.config(node_locked_retry_attempts=1, group='conductor')
         self.config(node_locked_retry_interval=0, group='conductor')
+        self.context = mock.sentinel.context
         self.node = obj_utils.create_test_node(self.context)
 
     def test_excl_lock(self, get_ports_mock, get_driver_mock,
@@ -89,7 +87,8 @@ class TaskManagerTestCase(tests_db_base.DbTestCase):
                                  reserve_mock, release_mock,
                                  node_get_mock):
         node2 = obj_utils.create_test_node(self.context,
-                                           uuid=uuidutils.generate_uuid(),
+                                           id=2,
+                                           uuid=utils.generate_uuid(),
                                            driver='fake')
 
         reserve_mock.return_value = self.node
@@ -142,9 +141,7 @@ class TaskManagerTestCase(tests_db_base.DbTestCase):
         with task_manager.TaskManager(self.context, 'fake-node-id') as task:
             self.assertFalse(task.shared)
 
-        expected_calls = [mock.call(self.context, self.host,
-                                    'fake-node-id')] * 2
-        reserve_mock.assert_has_calls(expected_calls)
+        reserve_mock.assert_called(self.context, self.host, 'fake-node-id')
         self.assertEqual(2, reserve_mock.call_count)
 
     def test_excl_lock_reserve_exception(self, get_ports_mock,
@@ -192,8 +189,8 @@ class TaskManagerTestCase(tests_db_base.DbTestCase):
                                             get_driver_mock, reserve_mock,
                                             release_mock, node_get_mock):
         reserve_mock.return_value = self.node
-        get_driver_mock.side_effect = (
-            exception.DriverNotFound(driver_name='foo'))
+        get_driver_mock.side_effect = exception.DriverNotFound(
+                driver_name='foo')
 
         self.assertRaises(exception.DriverNotFound,
                           task_manager.TaskManager,
@@ -284,8 +281,8 @@ class TaskManagerTestCase(tests_db_base.DbTestCase):
                                               get_driver_mock, reserve_mock,
                                               release_mock, node_get_mock):
         node_get_mock.return_value = self.node
-        get_driver_mock.side_effect = (
-            exception.DriverNotFound(driver_name='foo'))
+        get_driver_mock.side_effect = exception.DriverNotFound(
+                driver_name='foo')
 
         self.assertRaises(exception.DriverNotFound,
                           task_manager.TaskManager,
@@ -299,40 +296,11 @@ class TaskManagerTestCase(tests_db_base.DbTestCase):
         get_ports_mock.assert_called_once_with(self.context, self.node.id)
         get_driver_mock.assert_called_once_with(self.node.driver)
 
-    def test_upgrade_lock(self, get_ports_mock, get_driver_mock,
-                          reserve_mock, release_mock, node_get_mock):
-        node_get_mock.return_value = self.node
-        reserve_mock.return_value = self.node
-        with task_manager.TaskManager(self.context, 'fake-node-id',
-                                      shared=True) as task:
-            self.assertEqual(self.context, task.context)
-            self.assertEqual(self.node, task.node)
-            self.assertEqual(get_ports_mock.return_value, task.ports)
-            self.assertEqual(get_driver_mock.return_value, task.driver)
-            self.assertTrue(task.shared)
-            self.assertFalse(reserve_mock.called)
-
-            task.upgrade_lock()
-            self.assertFalse(task.shared)
-            # second upgrade does nothing
-            task.upgrade_lock()
-            self.assertFalse(task.shared)
-
-        # make sure reserve() was called only once
-        reserve_mock.assert_called_once_with(self.context, self.host,
-                                             'fake-node-id')
-        release_mock.assert_called_once_with(self.context, self.host,
-                                             self.node.id)
-        node_get_mock.assert_called_once_with(self.context, 'fake-node-id')
-        get_ports_mock.assert_called_once_with(self.context, self.node.id)
-        get_driver_mock.assert_called_once_with(self.node.driver)
-
     def test_spawn_after(self, get_ports_mock, get_driver_mock,
                          reserve_mock, release_mock, node_get_mock):
         thread_mock = mock.Mock(spec_set=['link', 'cancel'])
         spawn_mock = mock.Mock(return_value=thread_mock)
         task_release_mock = mock.Mock()
-        reserve_mock.return_value = self.node
 
         with task_manager.TaskManager(self.context, 'node-id') as task:
             task.spawn_after(spawn_mock, 1, 2, foo='bar', cat='meow')
@@ -340,7 +308,7 @@ class TaskManagerTestCase(tests_db_base.DbTestCase):
 
         spawn_mock.assert_called_once_with(1, 2, foo='bar', cat='meow')
         thread_mock.link.assert_called_once_with(
-            task._thread_release_resources)
+                task._thread_release_resources)
         self.assertFalse(thread_mock.cancel.called)
         # Since we mocked link(), we're testing that __exit__ didn't
         # release resources pending the finishing of the background
@@ -354,7 +322,6 @@ class TaskManagerTestCase(tests_db_base.DbTestCase):
                                                  node_get_mock):
         spawn_mock = mock.Mock()
         task_release_mock = mock.Mock()
-        reserve_mock.return_value = self.node
 
         def _test_it():
             with task_manager.TaskManager(self.context, 'node-id') as task:
@@ -371,7 +338,6 @@ class TaskManagerTestCase(tests_db_base.DbTestCase):
                                      node_get_mock):
         spawn_mock = mock.Mock(side_effect=exception.IronicException('foo'))
         task_release_mock = mock.Mock()
-        reserve_mock.return_value = self.node
 
         def _test_it():
             with task_manager.TaskManager(self.context, 'node-id') as task:
@@ -391,13 +357,13 @@ class TaskManagerTestCase(tests_db_base.DbTestCase):
         spawn_mock = mock.Mock(return_value=thread_mock)
         task_release_mock = mock.Mock()
         thr_release_mock = mock.Mock(spec_set=[])
-        reserve_mock.return_value = self.node
 
         def _test_it():
             with task_manager.TaskManager(self.context, 'node-id') as task:
                 task.spawn_after(spawn_mock, 1, 2, foo='bar', cat='meow')
                 task._thread_release_resources = thr_release_mock
                 task.release_resources = task_release_mock
+
         self.assertRaises(exception.IronicException, _test_it)
 
         spawn_mock.assert_called_once_with(1, 2, foo='bar', cat='meow')
@@ -412,7 +378,6 @@ class TaskManagerTestCase(tests_db_base.DbTestCase):
         spawn_mock = mock.Mock(side_effect=expected_exception)
         task_release_mock = mock.Mock()
         on_error_handler = mock.Mock()
-        reserve_mock.return_value = self.node
 
         def _test_it():
             with task_manager.TaskManager(self.context, 'node-id') as task:
@@ -436,7 +401,6 @@ class TaskManagerTestCase(tests_db_base.DbTestCase):
         # Raise an exception within the on_error handler
         on_error_handler = mock.Mock(side_effect=Exception('unexpected'))
         on_error_handler.__name__ = 'foo_method'
-        reserve_mock.return_value = self.node
 
         def _test_it():
             with task_manager.TaskManager(self.context, 'node-id') as task:
@@ -452,92 +416,6 @@ class TaskManagerTestCase(tests_db_base.DbTestCase):
         on_error_handler.assert_called_once_with(expected_exception,
                                                  'fake-argument')
 
-    @mock.patch.object(states.machine, 'copy')
-    def test_init_prepares_fsm(
-            self, copy_mock, get_ports_mock, get_driver_mock, reserve_mock,
-            release_mock, node_get_mock):
-        m = mock.Mock(spec=fsm.FSM)
-        reserve_mock.return_value = self.node
-        copy_mock.return_value = m
-        t = task_manager.TaskManager('fake', 'fake')
-        copy_mock.assert_called_once_with()
-        self.assertIs(m, t.fsm)
-        m.initialize.assert_called_once_with(self.node.provision_state)
-
-
-class TaskManagerStateModelTestCases(tests_base.TestCase):
-    def setUp(self):
-        super(TaskManagerStateModelTestCases, self).setUp()
-        self.fsm = mock.Mock(spec=fsm.FSM)
-        self.node = mock.Mock(spec=objects.Node)
-        self.task = mock.Mock(spec=task_manager.TaskManager)
-        self.task.fsm = self.fsm
-        self.task.node = self.node
-
-    def test_release_clears_resources(self):
-        t = self.task
-        t.release_resources = task_manager.TaskManager.release_resources
-        t.driver = mock.Mock()
-        t.ports = mock.Mock()
-        t.shared = True
-        t._purpose = 'purpose'
-        t._debug_timer = mock.Mock()
-
-        t.release_resources(t)
-        self.assertIsNone(t.node)
-        self.assertIsNone(t.driver)
-        self.assertIsNone(t.ports)
-        self.assertIsNone(t.fsm)
-
-    def test_process_event_fsm_raises(self):
-        self.task.process_event = task_manager.TaskManager.process_event
-        self.fsm.process_event.side_effect = exception.InvalidState('test')
-
-        self.assertRaises(
-            exception.InvalidState,
-            self.task.process_event,
-            self.task, 'fake')
-        self.assertEqual(0, self.task.spawn_after.call_count)
-        self.assertFalse(self.task.node.save.called)
-
-    def test_process_event_sets_callback(self):
-        cb = mock.Mock()
-        arg = mock.Mock()
-        kwarg = mock.Mock()
-        self.task.process_event = task_manager.TaskManager.process_event
-        self.task.process_event(
-            self.task, 'fake', callback=cb, call_args=[arg],
-            call_kwargs={'mock': kwarg})
-        self.fsm.process_event.assert_called_once_with('fake')
-        self.task.spawn_after.assert_called_with(cb, arg, mock=kwarg)
-        self.assertEqual(1, self.task.node.save.call_count)
-        self.assertIsNone(self.node.last_error)
-
-    def test_process_event_sets_callback_and_error_handler(self):
-        arg = mock.Mock()
-        cb = mock.Mock()
-        er = mock.Mock()
-        kwarg = mock.Mock()
-        provision_state = 'provision_state'
-        target_provision_state = 'target'
-        self.node.provision_state = provision_state
-        self.node.target_provision_state = target_provision_state
-        self.task.process_event = task_manager.TaskManager.process_event
-
-        self.task.process_event(
-            self.task, 'fake', callback=cb, call_args=[arg],
-            call_kwargs={'mock': kwarg}, err_handler=er)
-
-        self.task.set_spawn_error_hook.assert_called_once_with(
-            er, self.node, provision_state, target_provision_state)
-        self.fsm.process_event.assert_called_once_with('fake')
-        self.task.spawn_after.assert_called_with(cb, arg, mock=kwarg)
-        self.assertEqual(1, self.task.node.save.call_count)
-        self.assertIsNone(self.node.last_error)
-        self.assertNotEqual(provision_state, self.node.provision_state)
-        self.assertNotEqual(target_provision_state,
-                            self.node.target_provision_state)
-
 
 @task_manager.require_exclusive_lock
 def _req_excl_lock_method(*args, **kwargs):
