@@ -38,12 +38,17 @@ class DbPortTestCase(base.DbTestCase):
 
     def test_get_port_by_id(self):
         self.dbapi.create_port(self.p)
-        res = self.dbapi.get_port(self.p['id'])
+        res = self.dbapi.get_port_by_id(self.p['id'])
         self.assertEqual(self.p['address'], res.address)
 
     def test_get_port_by_uuid(self):
         self.dbapi.create_port(self.p)
-        res = self.dbapi.get_port(self.p['uuid'])
+        res = self.dbapi.get_port_by_uuid(self.p['uuid'])
+        self.assertEqual(self.p['id'], res.id)
+
+    def test_get_port_by_address(self):
+        self.dbapi.create_port(self.p)
+        res = self.dbapi.get_port_by_address(self.p['address'])
         self.assertEqual(self.p['id'], res.id)
 
     def test_get_port_list(self):
@@ -57,39 +62,15 @@ class DbPortTestCase(base.DbTestCase):
         res_uuids = [r.uuid for r in res]
         self.assertEqual(uuids.sort(), res_uuids.sort())
 
-    def test_get_port_by_address(self):
-        self.dbapi.create_port(self.p)
-
-        res = self.dbapi.get_port(self.p['address'])
-        self.assertEqual(self.p['id'], res.id)
-
-        self.assertRaises(exception.PortNotFound,
-                          self.dbapi.get_port, 99)
-        self.assertRaises(exception.PortNotFound,
-                          self.dbapi.get_port, 'aa:bb:cc:dd:ee:ff')
-        self.assertRaises(exception.InvalidIdentity,
-                          self.dbapi.get_port, 'not-a-mac')
-
     def test_get_ports_by_node_id(self):
         p = db_utils.get_test_port(node_id=self.n.id)
         self.dbapi.create_port(p)
-        res = self.dbapi.get_ports_by_node(self.n.id)
+        res = self.dbapi.get_ports_by_node_id(self.n.id)
         self.assertEqual(self.p['address'], res[0].address)
 
-    def test_get_ports_by_node_uuid(self):
-        p = db_utils.get_test_port(node_id=self.n.id)
-        self.dbapi.create_port(p)
-        res = self.dbapi.get_ports_by_node(self.n.uuid)
-        self.assertEqual(self.p['address'], res[0].address)
-
-    def test_get_ports_by_node_that_does_not_exist(self):
+    def test_get_ports_by_node_id_that_does_not_exist(self):
         self.dbapi.create_port(self.p)
-        self.assertRaises(exception.NodeNotFound,
-                          self.dbapi.get_ports_by_node,
-                          99)
-        self.assertRaises(exception.NodeNotFound,
-                          self.dbapi.get_ports_by_node,
-                          '12345678-9999-0000-aaaa-123456789012')
+        self.assertEqual([], self.dbapi.get_ports_by_node_id(99))
 
     def test_destroy_port(self):
         self.dbapi.create_port(self.p)
@@ -107,10 +88,16 @@ class DbPortTestCase(base.DbTestCase):
         res = self.dbapi.update_port(self.p['id'], {'address': new_address})
         self.assertEqual(new_address, res.address)
 
+    def test_update_port_uuid(self):
+        self.dbapi.create_port(self.p)
+        self.assertRaises(exception.InvalidParameterValue,
+                          self.dbapi.update_port, self.p['id'],
+                          {'uuid': ''})
+
     def test_destroy_port_on_reserved_node(self):
         p = self.dbapi.create_port(db_utils.get_test_port(node_id=self.n.id))
         uuid = self.n.uuid
-        self.dbapi.reserve_nodes('fake-reservation', [uuid])
+        self.dbapi.reserve_node('fake-reservation', uuid)
         self.assertRaises(exception.NodeLocked,
                           self.dbapi.destroy_port, p.id)
 
@@ -132,3 +119,11 @@ class DbPortTestCase(base.DbTestCase):
                                  node_id=self.n.id, address=dup_address)
         self.assertRaises(exception.MACAlreadyExists,
                           self.dbapi.create_port, p2)
+
+    def test_create_port_duplicated_uuid(self):
+        self.dbapi.create_port(self.p)
+        p2 = db_utils.get_test_port(id=123, uuid=self.p['uuid'],
+                                    node_id=self.n.id,
+                                    address='aa-bb-cc-33-11-22')
+        self.assertRaises(exception.PortAlreadyExists,
+                          self.dbapi.create_port, p2)
