@@ -15,10 +15,9 @@
 """Ironic test utilities."""
 
 
-from oslo_utils import timeutils
+from oslo.utils import timeutils
 
 from ironic.common import states
-from ironic.db import api as db_api
 
 
 def get_test_ipmi_info():
@@ -64,14 +63,8 @@ def get_test_ssh_info(auth_type='password'):
 
 def get_test_pxe_driver_info():
     return {
-        "deploy_kernel": "glance://deploy_kernel_uuid",
-        "deploy_ramdisk": "glance://deploy_ramdisk_uuid",
-    }
-
-
-def get_test_pxe_driver_internal_info():
-    return {
-        "is_whole_disk_image": False,
+        "pxe_deploy_kernel": "glance://deploy_kernel_uuid",
+        "pxe_deploy_ramdisk": "glance://deploy_ramdisk_uuid",
     }
 
 
@@ -93,9 +86,9 @@ def get_test_seamicro_info():
 
 def get_test_ilo_info():
     return {
-        "ilo_address": "1.2.3.4",
-        "ilo_username": "admin",
-        "ilo_password": "fake",
+            "ilo_address": "1.2.3.4",
+            "ilo_username": "admin",
+            "ilo_password": "fake",
     }
 
 
@@ -110,56 +103,19 @@ def get_test_drac_info():
     }
 
 
-def get_test_irmc_info():
-    return {
-        "irmc_address": "1.2.3.4",
-        "irmc_username": "admin0",
-        "irmc_password": "fake0",
-        "irmc_port": 80,
-        "irmc_auth_method": "digest",
-    }
-
-
-def get_test_amt_info():
-    return {
-        "amt_address": "1.2.3.4",
-        "amt_protocol": "http",
-        "amt_username": "admin",
-        "amt_password": "fake",
-    }
-
-
-def get_test_msftocs_info():
-    return {
-        "msftocs_base_url": "http://fakehost:8000",
-        "msftocs_username": "admin",
-        "msftocs_password": "fake",
-        "msftocs_blade_id": 1,
-    }
-
-
 def get_test_agent_instance_info():
     return {
         'image_source': 'fake-image',
         'image_url': 'http://image',
-        'image_checksum': 'checksum',
-        'image_disk_format': 'qcow2',
-        'image_container_format': 'bare',
+        'image_checksum': 'checksum'
     }
 
 
 def get_test_agent_driver_info():
     return {
+        'agent_url': 'http://127.0.0.1/foo',
         'deploy_kernel': 'glance://deploy_kernel_uuid',
         'deploy_ramdisk': 'glance://deploy_ramdisk_uuid',
-        'ipmi_password': 'foo',
-    }
-
-
-def get_test_agent_driver_internal_info():
-    return {
-        'agent_url': 'http://127.0.0.1/foo',
-        'is_whole_disk_image': True,
     }
 
 
@@ -193,12 +149,11 @@ def get_test_node(**kw):
         "local_gb": "10",
         "memory_mb": "4096",
     }
-    fake_info = {"foo": "bar", "fake_password": "fakepass"}
+    fake_info = {"foo": "bar"}
     return {
         'id': kw.get('id', 123),
-        'name': kw.get('name', None),
         'uuid': kw.get('uuid', '1be26c0b-03f2-4d2e-ae87-c02d7f33c123'),
-        'chassis_id': kw.get('chassis_id', None),
+        'chassis_id': kw.get('chassis_id', 42),
         'conductor_affinity': kw.get('conductor_affinity', None),
         'power_state': kw.get('power_state', states.NOSTATE),
         'target_power_state': kw.get('target_power_state', states.NOSTATE),
@@ -211,40 +166,16 @@ def get_test_node(**kw):
         'instance_info': kw.get('instance_info', fake_info),
         'driver': kw.get('driver', 'fake'),
         'driver_info': kw.get('driver_info', fake_info),
-        'driver_internal_info': kw.get('driver_internal_info', fake_info),
-        'clean_step': kw.get('clean_step'),
         'properties': kw.get('properties', properties),
         'reservation': kw.get('reservation'),
         'maintenance': kw.get('maintenance', False),
-        'maintenance_reason': kw.get('maintenance_reason'),
         'console_enabled': kw.get('console_enabled', False),
         'extra': kw.get('extra', {}),
-        'updated_at': kw.get('updated_at'),
-        'created_at': kw.get('created_at'),
-        'inspection_finished_at': kw.get('inspection_finished_at'),
-        'inspection_started_at': kw.get('inspection_started_at'),
-        'raid_config': kw.get('raid_config'),
-        'target_raid_config': kw.get('target_raid_config'),
+        'updated_at': kw.get('created_at'),
+        'created_at': kw.get('updated_at'),
     }
 
 
-def create_test_node(**kw):
-    """Create test node entry in DB and return Node DB object.
-
-    Function to be used to create test Node objects in the database.
-
-    :param kw: kwargs with overriding values for node's attributes.
-    :returns: Test Node DB object.
-
-    """
-    node = get_test_node(**kw)
-    # Let DB generate ID if it isn't specified explicitly
-    if 'id' not in kw:
-        del node['id']
-    dbapi = db_api.get_instance()
-    return dbapi.create_node(node)
-
-
 def get_test_port(**kw):
     return {
         'id': kw.get('id', 987),
@@ -257,23 +188,6 @@ def get_test_port(**kw):
     }
 
 
-def create_test_port(**kw):
-    """Create test port entry in DB and return Port DB object.
-
-    Function to be used to create test Port objects in the database.
-
-    :param kw: kwargs with overriding values for port's attributes.
-    :returns: Test Port DB object.
-
-    """
-    port = get_test_port(**kw)
-    # Let DB generate ID if it isn't specified explicitly
-    if 'id' not in kw:
-        del port['id']
-    dbapi = db_api.get_instance()
-    return dbapi.create_port(port)
-
-
 def get_test_chassis(**kw):
     return {
         'id': kw.get('id', 42),
@@ -285,23 +199,6 @@ def get_test_chassis(**kw):
     }
 
 
-def create_test_chassis(**kw):
-    """Create test chassis entry in DB and return Chassis DB object.
-
-    Function to be used to create test Chassis objects in the database.
-
-    :param kw: kwargs with overriding values for chassis's attributes.
-    :returns: Test Chassis DB object.
-
-    """
-    chassis = get_test_chassis(**kw)
-    # Let DB generate ID if it isn't specified explicitly
-    if 'id' not in kw:
-        del chassis['id']
-    dbapi = db_api.get_instance()
-    return dbapi.create_chassis(chassis)
-
-
 def get_test_conductor(**kw):
     return {
         'id': kw.get('id', 6),
@@ -310,20 +207,3 @@ def get_test_conductor(**kw):
         'created_at': kw.get('created_at', timeutils.utcnow()),
         'updated_at': kw.get('updated_at', timeutils.utcnow()),
     }
-
-
-def get_test_ucs_info():
-    return {
-        "ucs_username": "admin",
-        "ucs_password": "password",
-        "ucs_service_profile": "org-root/ls-devstack",
-        "ucs_address": "ucs-b",
-    }
-
-
-def get_test_cimc_info():
-    return {
-        "cimc_username": "admin",
-        "cimc_password": "password",
-        "cimc_address": "1.2.3.4",
-    }
