@@ -17,11 +17,11 @@
 import mock
 from neutronclient.common import exceptions as neutron_client_exc
 from neutronclient.v2_0 import client
-from oslo_utils import uuidutils
 
 from ironic.common import dhcp_factory
 from ironic.common import exception
 from ironic.common import pxe_utils
+from ironic.common import utils
 from ironic.conductor import task_manager
 from ironic.dhcp import neutron
 from ironic.tests.conductor import utils as mgr_utils
@@ -34,15 +34,11 @@ class TestNeutron(db_base.DbTestCase):
     def setUp(self):
         super(TestNeutron, self).setUp()
         mgr_utils.mock_the_extension_manager(driver='fake')
-        self.config(
-            cleaning_network_uuid='00000000-0000-0000-0000-000000000000',
-            group='neutron')
         self.config(enabled_drivers=['fake'])
         self.config(dhcp_provider='neutron',
                     group='dhcp')
         self.config(url='test-url',
                     url_timeout=30,
-                    retries=2,
                     group='neutron')
         self.config(insecure=False,
                     certfile='test-file',
@@ -52,15 +48,6 @@ class TestNeutron(db_base.DbTestCase):
                     auth_uri='test-auth-uri',
                     group='keystone_authtoken')
         self.node = object_utils.create_test_node(self.context)
-        self.ports = [
-            object_utils.create_test_port(
-                self.context, node_id=self.node.id, id=2,
-                uuid='1be26c0b-03f2-4d2e-ae87-c02d7f33c782',
-                address='52:54:00:cf:2d:32')]
-        # Very simple neutron port representation
-        self.neutron_port = {'id': '132f871f-eaec-4fed-9475-0d54465e0f00',
-                             'mac_address': '52:54:00:cf:2d:32'}
-
         dhcp_factory.DHCPFactory._dhcp_provider = None
 
     def test__build_client_invalid_auth_strategy(self):
@@ -74,7 +61,6 @@ class TestNeutron(db_base.DbTestCase):
     def test__build_client_with_token(self, mock_client_init):
         token = 'test-token-123'
         expected = {'timeout': 30,
-                    'retries': 2,
                     'insecure': False,
                     'ca_cert': 'test-file',
                     'token': token,
@@ -88,7 +74,6 @@ class TestNeutron(db_base.DbTestCase):
     @mock.patch.object(client.Client, "__init__")
     def test__build_client_without_token(self, mock_client_init):
         expected = {'timeout': 30,
-                    'retries': 2,
                     'insecure': False,
                     'ca_cert': 'test-file',
                     'endpoint_url': 'test-url',
@@ -101,25 +86,6 @@ class TestNeutron(db_base.DbTestCase):
         neutron._build_client(token=None)
         mock_client_init.assert_called_once_with(**expected)
 
-    @mock.patch.object(client.Client, "__init__")
-    def test__build_client_with_region(self, mock_client_init):
-        expected = {'timeout': 30,
-                    'retries': 2,
-                    'insecure': False,
-                    'ca_cert': 'test-file',
-                    'endpoint_url': 'test-url',
-                    'username': 'test-admin-user',
-                    'tenant_name': 'test-admin-tenant',
-                    'password': 'test-admin-password',
-                    'auth_url': 'test-auth-uri',
-                    'region_name': 'test-region'}
-
-        self.config(region_name='test-region',
-                    group='keystone')
-        mock_client_init.return_value = None
-        neutron._build_client(token=None)
-        mock_client_init.assert_called_once_with(**expected)
-
     @mock.patch.object(client.Client, "__init__")
     def test__build_client_noauth(self, mock_client_init):
         self.config(auth_strategy='noauth', group='neutron')
@@ -127,7 +93,6 @@ class TestNeutron(db_base.DbTestCase):
                     'insecure': False,
                     'endpoint_url': 'test-url',
                     'timeout': 30,
-                    'retries': 2,
                     'auth_strategy': 'noauth'}
 
         mock_client_init.return_value = None
@@ -163,9 +128,9 @@ class TestNeutron(db_base.DbTestCase):
 
         api = dhcp_factory.DHCPFactory()
         self.assertRaises(
-            exception.FailedToUpdateDHCPOptOnPort,
-            api.provider.update_port_dhcp_opts,
-            port_id, opts)
+                exception.FailedToUpdateDHCPOptOnPort,
+                api.provider.update_port_dhcp_opts,
+                port_id, opts)
 
     @mock.patch.object(client.Client, 'update_port')
     @mock.patch.object(client.Client, '__init__')
@@ -264,7 +229,7 @@ class TestNeutron(db_base.DbTestCase):
                 }
             ],
             "device_id": 'bece68a3-2f8b-4e66-9092-244493d6aba7',
-        }
+            }
         fake_client = mock.Mock()
         fake_client.show_port.return_value = {'port': port_data}
         result = api._get_fixed_ip_address(port_id, fake_client)
@@ -287,7 +252,7 @@ class TestNeutron(db_base.DbTestCase):
                 }
             ],
             "device_id": 'bece68a3-2f8b-4e66-9092-244493d6aba7',
-        }
+            }
         fake_client = mock.Mock()
         fake_client.show_port.return_value = {'port': port_data}
         self.assertRaises(exception.InvalidIPv4Address,
@@ -301,7 +266,7 @@ class TestNeutron(db_base.DbTestCase):
 
         fake_client = mock.Mock()
         fake_client.show_port.side_effect = (
-            neutron_client_exc.NeutronClientException())
+                                neutron_client_exc.NeutronClientException())
         self.assertRaises(exception.FailedToGetIPAddressOnPort,
                           api._get_fixed_ip_address, port_id, fake_client)
         fake_client.show_port.assert_called_once_with(port_id)
@@ -312,8 +277,8 @@ class TestNeutron(db_base.DbTestCase):
         expected = "192.168.1.3"
         port = object_utils.create_test_port(self.context,
                                              node_id=self.node.id,
-                                             address='aa:bb:cc:dd:ee:ff',
-                                             uuid=uuidutils.generate_uuid(),
+                                             id=6, address='aa:bb:cc',
+                                             uuid=utils.generate_uuid(),
                                              extra={'vif_port_id':
                                                     'test-vif-A'},
                                              driver='fake')
@@ -334,8 +299,8 @@ class TestNeutron(db_base.DbTestCase):
         expected = "192.168.1.3"
         port = object_utils.create_test_port(self.context,
                                              node_id=self.node.id,
-                                             address='aa:bb:cc:dd:ee:ff',
-                                             uuid=uuidutils.generate_uuid(),
+                                             id=6, address='aa:bb:cc',
+                                             uuid=utils.generate_uuid(),
                                              extra={'vif_port_id':
                                                     'test-vif-A'},
                                              driver='fake')
@@ -352,98 +317,16 @@ class TestNeutron(db_base.DbTestCase):
     @mock.patch('ironic.dhcp.neutron.NeutronDHCPApi._get_port_ip_address')
     def test_get_ip_addresses(self, get_ip_mock):
         ip_address = '10.10.0.1'
+        address = "aa:aa:aa:aa:aa:aa"
         expected = [ip_address]
+        port = object_utils.create_test_port(self.context,
+                                             node_id=self.node.id,
+                                             address=address)
 
         get_ip_mock.return_value = ip_address
 
         with task_manager.acquire(self.context, self.node.uuid) as task:
             api = dhcp_factory.DHCPFactory().provider
             result = api.get_ip_addresses(task)
-            get_ip_mock.assert_called_once_with(task, self.ports[0].uuid,
-                                                mock.ANY)
+            get_ip_mock.assert_called_once_with(task, port.uuid, mock.ANY)
         self.assertEqual(expected, result)
-
-    @mock.patch.object(client.Client, 'create_port')
-    def test_create_cleaning_ports(self, create_mock):
-        # Ensure we can create cleaning ports for in band cleaning
-        create_mock.return_value = {'port': self.neutron_port}
-        expected = {self.ports[0].uuid: self.neutron_port['id']}
-        api = dhcp_factory.DHCPFactory().provider
-
-        with task_manager.acquire(self.context, self.node.uuid) as task:
-            ports = api.create_cleaning_ports(task)
-            self.assertEqual(expected, ports)
-            create_mock.assert_called_once_with({'port': {
-                'network_id': '00000000-0000-0000-0000-000000000000',
-                'admin_state_up': True, 'mac_address': self.ports[0].address}})
-
-    @mock.patch.object(neutron.NeutronDHCPApi, '_rollback_cleaning_ports')
-    @mock.patch.object(client.Client, 'create_port')
-    def test_create_cleaning_ports_fail(self, create_mock, rollback_mock):
-        # Check that if creating a port fails, the ports are cleaned up
-        create_mock.side_effect = neutron_client_exc.ConnectionFailed
-        api = dhcp_factory.DHCPFactory().provider
-
-        with task_manager.acquire(self.context, self.node.uuid) as task:
-            self.assertRaises(exception.NodeCleaningFailure,
-                              api.create_cleaning_ports,
-                              task)
-            create_mock.assert_called_once_with({'port': {
-                'network_id': '00000000-0000-0000-0000-000000000000',
-                'admin_state_up': True, 'mac_address': self.ports[0].address}})
-            rollback_mock.assert_called_once_with(task)
-
-    @mock.patch.object(client.Client, 'create_port')
-    def test_create_cleaning_ports_bad_config(self, create_mock):
-        # Check an error is raised if the cleaning network is not set
-        self.config(cleaning_network_uuid=None, group='neutron')
-        api = dhcp_factory.DHCPFactory().provider
-
-        with task_manager.acquire(self.context, self.node.uuid) as task:
-            self.assertRaises(exception.InvalidParameterValue,
-                              api.create_cleaning_ports, task)
-
-    @mock.patch.object(client.Client, 'delete_port')
-    @mock.patch.object(client.Client, 'list_ports')
-    def test_delete_cleaning_ports(self, list_mock, delete_mock):
-        # Ensure that we can delete cleaning ports, and that ports with
-        # different macs don't get deleted
-        other_port = {'id': '132f871f-eaec-4fed-9475-0d54465e0f01',
-                      'mac_address': 'aa:bb:cc:dd:ee:ff'}
-        list_mock.return_value = {'ports': [self.neutron_port, other_port]}
-        api = dhcp_factory.DHCPFactory().provider
-
-        with task_manager.acquire(self.context, self.node.uuid) as task:
-            api.delete_cleaning_ports(task)
-            list_mock.assert_called_once_with(
-                network_id='00000000-0000-0000-0000-000000000000')
-            delete_mock.assert_called_once_with(self.neutron_port['id'])
-
-    @mock.patch.object(client.Client, 'list_ports')
-    def test_delete_cleaning_ports_list_fail(self, list_mock):
-        # Check that if listing ports fails, the node goes to cleanfail
-        list_mock.side_effect = neutron_client_exc.ConnectionFailed
-        api = dhcp_factory.DHCPFactory().provider
-
-        with task_manager.acquire(self.context, self.node.uuid) as task:
-            self.assertRaises(exception.NodeCleaningFailure,
-                              api.delete_cleaning_ports,
-                              task)
-            list_mock.assert_called_once_with(
-                network_id='00000000-0000-0000-0000-000000000000')
-
-    @mock.patch.object(client.Client, 'delete_port')
-    @mock.patch.object(client.Client, 'list_ports')
-    def test_delete_cleaning_ports_delete_fail(self, list_mock, delete_mock):
-        # Check that if deleting ports fails, the node goes to cleanfail
-        list_mock.return_value = {'ports': [self.neutron_port]}
-        delete_mock.side_effect = neutron_client_exc.ConnectionFailed
-        api = dhcp_factory.DHCPFactory().provider
-
-        with task_manager.acquire(self.context, self.node.uuid) as task:
-            self.assertRaises(exception.NodeCleaningFailure,
-                              api.delete_cleaning_ports,
-                              task)
-            list_mock.assert_called_once_with(
-                network_id='00000000-0000-0000-0000-000000000000')
-            delete_mock.assert_called_once_with(self.neutron_port['id'])
