@@ -16,15 +16,10 @@
 
 """Tests for ImageCache class and helper functions."""
 
-import datetime
+import mock
 import os
 import tempfile
 import time
-import uuid
-
-import mock
-from oslo_utils import uuidutils
-import six
 
 from ironic.common import exception
 from ironic.common import image_service
@@ -38,6 +33,7 @@ def touch(filename):
     open(filename, 'w').close()
 
 
+@mock.patch.object(image_cache, '_fetch_to_raw')
 class TestImageCacheFetch(base.TestCase):
 
     def setUp(self):
@@ -46,126 +42,62 @@ class TestImageCacheFetch(base.TestCase):
         self.cache = image_cache.ImageCache(self.master_dir, None, None)
         self.dest_dir = tempfile.mkdtemp()
         self.dest_path = os.path.join(self.dest_dir, 'dest')
-        self.uuid = uuidutils.generate_uuid()
+        self.uuid = 'uuid'
         self.master_path = os.path.join(self.master_dir, self.uuid)
 
-    @mock.patch.object(image_cache, '_fetch', autospec=True)
-    @mock.patch.object(image_cache.ImageCache, 'clean_up', autospec=True)
-    @mock.patch.object(image_cache.ImageCache, '_download_image',
-                       autospec=True)
+    @mock.patch.object(image_cache.ImageCache, 'clean_up')
+    @mock.patch.object(image_cache.ImageCache, '_download_image')
     def test_fetch_image_no_master_dir(self, mock_download, mock_clean_up,
-                                       mock_fetch):
+                                       mock_fetch_to_raw):
         self.cache.master_dir = None
-        self.cache.fetch_image(self.uuid, self.dest_path)
+        self.cache.fetch_image('uuid', self.dest_path)
         self.assertFalse(mock_download.called)
-        mock_fetch.assert_called_once_with(
-            None, self.uuid, self.dest_path, True)
+        mock_fetch_to_raw.assert_called_once_with(
+            None, 'uuid', self.dest_path, None)
         self.assertFalse(mock_clean_up.called)
 
-    @mock.patch.object(image_cache.ImageCache, 'clean_up', autospec=True)
-    @mock.patch.object(image_cache.ImageCache, '_download_image',
-                       autospec=True)
-    @mock.patch.object(os, 'link', autospec=True)
-    @mock.patch.object(image_cache, '_delete_dest_path_if_stale',
-                       return_value=True, autospec=True)
-    @mock.patch.object(image_cache, '_delete_master_path_if_stale',
-                       return_value=True, autospec=True)
-    def test_fetch_image_dest_and_master_uptodate(
-            self, mock_cache_upd, mock_dest_upd, mock_link, mock_download,
-            mock_clean_up):
+    @mock.patch.object(image_cache.ImageCache, 'clean_up')
+    @mock.patch.object(image_cache.ImageCache, '_download_image')
+    def test_fetch_image_dest_exists(self, mock_download, mock_clean_up,
+                                     mock_fetch_to_raw):
+        touch(self.dest_path)
         self.cache.fetch_image(self.uuid, self.dest_path)
-        mock_cache_upd.assert_called_once_with(self.master_path, self.uuid,
-                                               None)
-        mock_dest_upd.assert_called_once_with(self.master_path, self.dest_path)
-        self.assertFalse(mock_link.called)
         self.assertFalse(mock_download.called)
+        self.assertFalse(mock_fetch_to_raw.called)
         self.assertFalse(mock_clean_up.called)
 
-    @mock.patch.object(image_cache.ImageCache, 'clean_up', autospec=True)
-    @mock.patch.object(image_cache.ImageCache, '_download_image',
-                       autospec=True)
-    @mock.patch.object(os, 'link', autospec=True)
-    @mock.patch.object(image_cache, '_delete_dest_path_if_stale',
-                       return_value=False, autospec=True)
-    @mock.patch.object(image_cache, '_delete_master_path_if_stale',
-                       return_value=True, autospec=True)
-    def test_fetch_image_dest_out_of_date(
-            self, mock_cache_upd, mock_dest_upd, mock_link, mock_download,
-            mock_clean_up):
+    @mock.patch.object(image_cache.ImageCache, 'clean_up')
+    @mock.patch.object(image_cache.ImageCache, '_download_image')
+    def test_fetch_image_master_exists(self, mock_download, mock_clean_up,
+                                       mock_fetch_to_raw):
+        touch(self.master_path)
         self.cache.fetch_image(self.uuid, self.dest_path)
-        mock_cache_upd.assert_called_once_with(self.master_path, self.uuid,
-                                               None)
-        mock_dest_upd.assert_called_once_with(self.master_path, self.dest_path)
-        mock_link.assert_called_once_with(self.master_path, self.dest_path)
         self.assertFalse(mock_download.called)
+        self.assertFalse(mock_fetch_to_raw.called)
+        self.assertTrue(os.path.isfile(self.dest_path))
+        self.assertEqual(os.stat(self.dest_path).st_ino,
+                         os.stat(self.master_path).st_ino)
         self.assertFalse(mock_clean_up.called)
 
-    @mock.patch.object(image_cache.ImageCache, 'clean_up', autospec=True)
-    @mock.patch.object(image_cache.ImageCache, '_download_image',
-                       autospec=True)
-    @mock.patch.object(os, 'link', autospec=True)
-    @mock.patch.object(image_cache, '_delete_dest_path_if_stale',
-                       return_value=True, autospec=True)
-    @mock.patch.object(image_cache, '_delete_master_path_if_stale',
-                       return_value=False, autospec=True)
-    def test_fetch_image_master_out_of_date(
-            self, mock_cache_upd, mock_dest_upd, mock_link, mock_download,
-            mock_clean_up):
+    @mock.patch.object(image_cache.ImageCache, 'clean_up')
+    @mock.patch.object(image_cache.ImageCache, '_download_image')
+    def test_fetch_image(self, mock_download, mock_clean_up,
+                         mock_fetch_to_raw):
         self.cache.fetch_image(self.uuid, self.dest_path)
-        mock_cache_upd.assert_called_once_with(self.master_path, self.uuid,
-                                               None)
-        mock_dest_upd.assert_called_once_with(self.master_path, self.dest_path)
-        self.assertFalse(mock_link.called)
+        self.assertFalse(mock_fetch_to_raw.called)
         mock_download.assert_called_once_with(
-            self.cache, self.uuid, self.master_path, self.dest_path,
-            ctx=None, force_raw=True)
-        mock_clean_up.assert_called_once_with(self.cache)
-
-    @mock.patch.object(image_cache.ImageCache, 'clean_up', autospec=True)
-    @mock.patch.object(image_cache.ImageCache, '_download_image',
-                       autospec=True)
-    @mock.patch.object(os, 'link', autospec=True)
-    @mock.patch.object(image_cache, '_delete_dest_path_if_stale',
-                       return_value=True, autospec=True)
-    @mock.patch.object(image_cache, '_delete_master_path_if_stale',
-                       return_value=False, autospec=True)
-    def test_fetch_image_both_master_and_dest_out_of_date(
-            self, mock_cache_upd, mock_dest_upd, mock_link, mock_download,
-            mock_clean_up):
-        self.cache.fetch_image(self.uuid, self.dest_path)
-        mock_cache_upd.assert_called_once_with(self.master_path, self.uuid,
-                                               None)
-        mock_dest_upd.assert_called_once_with(self.master_path, self.dest_path)
-        self.assertFalse(mock_link.called)
-        mock_download.assert_called_once_with(
-            self.cache, self.uuid, self.master_path, self.dest_path,
-            ctx=None, force_raw=True)
-        mock_clean_up.assert_called_once_with(self.cache)
-
-    @mock.patch.object(image_cache.ImageCache, 'clean_up', autospec=True)
-    @mock.patch.object(image_cache.ImageCache, '_download_image',
-                       autospec=True)
-    def test_fetch_image_not_uuid(self, mock_download, mock_clean_up):
-        href = u'http://abc.com/ubuntu.qcow2'
-        href_encoded = href.encode('utf-8') if six.PY2 else href
-        href_converted = str(uuid.uuid5(uuid.NAMESPACE_URL, href_encoded))
-        master_path = os.path.join(self.master_dir, href_converted)
-        self.cache.fetch_image(href, self.dest_path)
-        mock_download.assert_called_once_with(
-            self.cache, href, master_path, self.dest_path,
-            ctx=None, force_raw=True)
+            self.uuid, self.master_path, self.dest_path, ctx=None)
         self.assertTrue(mock_clean_up.called)
 
-    @mock.patch.object(image_cache, '_fetch', autospec=True)
-    def test__download_image(self, mock_fetch):
-        def _fake_fetch(ctx, uuid, tmp_path, *args):
+    def test__download_image(self, mock_fetch_to_raw):
+        def _fake_fetch_to_raw(ctx, uuid, tmp_path, *args):
             self.assertEqual(self.uuid, uuid)
             self.assertNotEqual(self.dest_path, tmp_path)
             self.assertNotEqual(os.path.dirname(tmp_path), self.master_dir)
             with open(tmp_path, 'w') as fp:
                 fp.write("TEST")
 
-        mock_fetch.side_effect = _fake_fetch
+        mock_fetch_to_raw.side_effect = _fake_fetch_to_raw
         self.cache._download_image(self.uuid, self.master_path, self.dest_path)
         self.assertTrue(os.path.isfile(self.dest_path))
         self.assertTrue(os.path.isfile(self.master_path))
@@ -175,119 +107,6 @@ class TestImageCacheFetch(base.TestCase):
             self.assertEqual("TEST", fp.read())
 
 
-@mock.patch.object(os, 'unlink', autospec=True)
-class TestUpdateImages(base.TestCase):
-
-    def setUp(self):
-        super(TestUpdateImages, self).setUp()
-        self.master_dir = tempfile.mkdtemp()
-        self.dest_dir = tempfile.mkdtemp()
-        self.dest_path = os.path.join(self.dest_dir, 'dest')
-        self.uuid = uuidutils.generate_uuid()
-        self.master_path = os.path.join(self.master_dir, self.uuid)
-
-    @mock.patch.object(os.path, 'exists', return_value=False, autospec=True)
-    @mock.patch.object(image_service, 'get_image_service', autospec=True)
-    def test__delete_master_path_if_stale_glance_img_not_cached(
-            self, mock_gis, mock_path_exists, mock_unlink):
-        res = image_cache._delete_master_path_if_stale(self.master_path,
-                                                       self.uuid, None)
-        self.assertFalse(mock_gis.called)
-        self.assertFalse(mock_unlink.called)
-        mock_path_exists.assert_called_once_with(self.master_path)
-        self.assertFalse(res)
-
-    @mock.patch.object(os.path, 'exists', return_value=True, autospec=True)
-    @mock.patch.object(image_service, 'get_image_service', autospec=True)
-    def test__delete_master_path_if_stale_glance_img(
-            self, mock_gis, mock_path_exists, mock_unlink):
-        res = image_cache._delete_master_path_if_stale(self.master_path,
-                                                       self.uuid, None)
-        self.assertFalse(mock_gis.called)
-        self.assertFalse(mock_unlink.called)
-        mock_path_exists.assert_called_once_with(self.master_path)
-        self.assertTrue(res)
-
-    @mock.patch.object(image_service, 'get_image_service', autospec=True)
-    def test__delete_master_path_if_stale_no_master(self, mock_gis,
-                                                    mock_unlink):
-        res = image_cache._delete_master_path_if_stale(self.master_path,
-                                                       'http://11', None)
-        self.assertFalse(mock_gis.called)
-        self.assertFalse(mock_unlink.called)
-        self.assertFalse(res)
-
-    @mock.patch.object(image_service, 'get_image_service', autospec=True)
-    def test__delete_master_path_if_stale_no_updated_at(self, mock_gis,
-                                                        mock_unlink):
-        touch(self.master_path)
-        href = 'http://awesomefreeimages.al/img111'
-        mock_gis.return_value.show.return_value = {}
-        res = image_cache._delete_master_path_if_stale(self.master_path, href,
-                                                       None)
-        mock_gis.assert_called_once_with(href, context=None)
-        self.assertFalse(mock_unlink.called)
-        self.assertTrue(res)
-
-    @mock.patch.object(image_service, 'get_image_service', autospec=True)
-    def test__delete_master_path_if_stale_master_up_to_date(self, mock_gis,
-                                                            mock_unlink):
-        touch(self.master_path)
-        href = 'http://awesomefreeimages.al/img999'
-        mock_gis.return_value.show.return_value = {
-            'updated_at': datetime.datetime(1999, 11, 15, 8, 12, 31)
-        }
-        res = image_cache._delete_master_path_if_stale(self.master_path, href,
-                                                       None)
-        mock_gis.assert_called_once_with(href, context=None)
-        self.assertFalse(mock_unlink.called)
-        self.assertTrue(res)
-
-    @mock.patch.object(image_service, 'get_image_service', autospec=True)
-    def test__delete_master_path_if_stale_out_of_date(self, mock_gis,
-                                                      mock_unlink):
-        touch(self.master_path)
-        href = 'http://awesomefreeimages.al/img999'
-        mock_gis.return_value.show.return_value = {
-            'updated_at': datetime.datetime((datetime.datetime.utcnow().year
-                                             + 1), 11, 15, 8, 12, 31)
-        }
-        res = image_cache._delete_master_path_if_stale(self.master_path, href,
-                                                       None)
-        mock_gis.assert_called_once_with(href, context=None)
-        mock_unlink.assert_called_once_with(self.master_path)
-        self.assertFalse(res)
-
-    def test__delete_dest_path_if_stale_no_dest(self, mock_unlink):
-        res = image_cache._delete_dest_path_if_stale(self.master_path,
-                                                     self.dest_path)
-        self.assertFalse(mock_unlink.called)
-        self.assertFalse(res)
-
-    def test__delete_dest_path_if_stale_no_master(self, mock_unlink):
-        touch(self.dest_path)
-        res = image_cache._delete_dest_path_if_stale(self.master_path,
-                                                     self.dest_path)
-        mock_unlink.assert_called_once_with(self.dest_path)
-        self.assertFalse(res)
-
-    def test__delete_dest_path_if_stale_out_of_date(self, mock_unlink):
-        touch(self.master_path)
-        touch(self.dest_path)
-        res = image_cache._delete_dest_path_if_stale(self.master_path,
-                                                     self.dest_path)
-        mock_unlink.assert_called_once_with(self.dest_path)
-        self.assertFalse(res)
-
-    def test__delete_dest_path_if_stale_up_to_date(self, mock_unlink):
-        touch(self.master_path)
-        os.link(self.master_path, self.dest_path)
-        res = image_cache._delete_dest_path_if_stale(self.master_path,
-                                                     self.dest_path)
-        self.assertFalse(mock_unlink.called)
-        self.assertTrue(res)
-
-
 class TestImageCacheCleanUp(base.TestCase):
 
     def setUp(self):
@@ -297,8 +116,7 @@ class TestImageCacheCleanUp(base.TestCase):
                                             cache_size=10,
                                             cache_ttl=600)
 
-    @mock.patch.object(image_cache.ImageCache, '_clean_up_ensure_cache_size',
-                       autospec=True)
+    @mock.patch.object(image_cache.ImageCache, '_clean_up_ensure_cache_size')
     def test_clean_up_old_deleted(self, mock_clean_size):
         mock_clean_size.return_value = None
         files = [os.path.join(self.master_dir, str(i))
@@ -311,8 +129,8 @@ class TestImageCacheCleanUp(base.TestCase):
         with mock.patch.object(time, 'time', lambda: new_current_time):
             self.cache.clean_up()
 
-        mock_clean_size.assert_called_once_with(self.cache, mock.ANY, None)
-        survived = mock_clean_size.call_args[0][1]
+        mock_clean_size.assert_called_once_with(mock.ANY, None)
+        survived = mock_clean_size.call_args[0][0]
         self.assertEqual(1, len(survived))
         self.assertEqual(files[0], survived[0][0])
         # NOTE(dtantsur): do not compare milliseconds
@@ -320,13 +138,12 @@ class TestImageCacheCleanUp(base.TestCase):
         self.assertEqual(int(new_current_time - 100),
                          int(survived[0][2].st_mtime))
 
-    @mock.patch.object(image_cache.ImageCache, '_clean_up_ensure_cache_size',
-                       autospec=True)
+    @mock.patch.object(image_cache.ImageCache, '_clean_up_ensure_cache_size')
     def test_clean_up_old_with_amount(self, mock_clean_size):
         files = [os.path.join(self.master_dir, str(i))
                  for i in range(2)]
         for filename in files:
-            open(filename, 'wb').write(b'X')
+            open(filename, 'wb').write('X')
         new_current_time = time.time() + 900
         with mock.patch.object(time, 'time', lambda: new_current_time):
             self.cache.clean_up(amount=1)
@@ -336,8 +153,7 @@ class TestImageCacheCleanUp(base.TestCase):
         self.assertTrue(any(os.path.exists(f) for f in files))
         self.assertFalse(all(os.path.exists(f) for f in files))
 
-    @mock.patch.object(image_cache.ImageCache, '_clean_up_ensure_cache_size',
-                       autospec=True)
+    @mock.patch.object(image_cache.ImageCache, '_clean_up_ensure_cache_size')
     def test_clean_up_files_with_links_untouched(self, mock_clean_size):
         mock_clean_size.return_value = None
         files = [os.path.join(self.master_dir, str(i))
@@ -352,12 +168,11 @@ class TestImageCacheCleanUp(base.TestCase):
 
         for filename in files:
             self.assertTrue(os.path.exists(filename))
-        mock_clean_size.assert_called_once_with(mock.ANY, [], None)
+        mock_clean_size.assert_called_once_with([], None)
 
-    @mock.patch.object(image_cache.ImageCache, '_clean_up_too_old',
-                       autospec=True)
+    @mock.patch.object(image_cache.ImageCache, '_clean_up_too_old')
     def test_clean_up_ensure_cache_size(self, mock_clean_ttl):
-        mock_clean_ttl.side_effect = lambda *xx: xx[1:]
+        mock_clean_ttl.side_effect = lambda *xx: xx
         # NOTE(dtantsur): Cache size in test is 10 bytes, we create 6 files
         # with 3 bytes each and expect 3 to be deleted
         files = [os.path.join(self.master_dir, str(i))
@@ -379,12 +194,11 @@ class TestImageCacheCleanUp(base.TestCase):
         for filename in files[3:]:
             self.assertFalse(os.path.exists(filename))
 
-        mock_clean_ttl.assert_called_once_with(mock.ANY, mock.ANY, None)
+        mock_clean_ttl.assert_called_once_with(mock.ANY, None)
 
-    @mock.patch.object(image_cache.ImageCache, '_clean_up_too_old',
-                       autospec=True)
+    @mock.patch.object(image_cache.ImageCache, '_clean_up_too_old')
     def test_clean_up_ensure_cache_size_with_amount(self, mock_clean_ttl):
-        mock_clean_ttl.side_effect = lambda *xx: xx[1:]
+        mock_clean_ttl.side_effect = lambda *xx: xx
         # NOTE(dtantsur): Cache size in test is 10 bytes, we create 6 files
         # with 3 bytes each and set amount to be 15, 5 files are to be deleted
         files = [os.path.join(self.master_dir, str(i))
@@ -404,13 +218,12 @@ class TestImageCacheCleanUp(base.TestCase):
         for filename in files[5:]:
             self.assertFalse(os.path.exists(filename))
 
-        mock_clean_ttl.assert_called_once_with(mock.ANY, mock.ANY, 15)
+        mock_clean_ttl.assert_called_once_with(mock.ANY, 15)
 
-    @mock.patch.object(image_cache.LOG, 'info', autospec=True)
-    @mock.patch.object(image_cache.ImageCache, '_clean_up_too_old',
-                       autospec=True)
+    @mock.patch.object(image_cache.LOG, 'info')
+    @mock.patch.object(image_cache.ImageCache, '_clean_up_too_old')
     def test_clean_up_cache_still_large(self, mock_clean_ttl, mock_log):
-        mock_clean_ttl.side_effect = lambda *xx: xx[1:]
+        mock_clean_ttl.side_effect = lambda *xx: xx
         # NOTE(dtantsur): Cache size in test is 10 bytes, we create 2 files
         # than cannot be deleted and expected this to be logged
         files = [os.path.join(self.master_dir, str(i))
@@ -425,12 +238,12 @@ class TestImageCacheCleanUp(base.TestCase):
         for filename in files:
             self.assertTrue(os.path.exists(filename))
         self.assertTrue(mock_log.called)
-        mock_clean_ttl.assert_called_once_with(mock.ANY, mock.ANY, None)
+        mock_clean_ttl.assert_called_once_with(mock.ANY, None)
 
-    @mock.patch.object(utils, 'rmtree_without_raise', autospec=True)
-    @mock.patch.object(image_cache, '_fetch', autospec=True)
-    def test_temp_images_not_cleaned(self, mock_fetch, mock_rmtree):
-        def _fake_fetch(ctx, uuid, tmp_path, *args):
+    @mock.patch.object(utils, 'rmtree_without_raise')
+    @mock.patch.object(image_cache, '_fetch_to_raw')
+    def test_temp_images_not_cleaned(self, mock_fetch_to_raw, mock_rmtree):
+        def _fake_fetch_to_raw(ctx, uuid, tmp_path, *args):
             with open(tmp_path, 'w') as fp:
                 fp.write("TEST" * 10)
 
@@ -438,30 +251,28 @@ class TestImageCacheCleanUp(base.TestCase):
             self.cache.clean_up()
             self.assertTrue(os.path.exists(tmp_path))
 
-        mock_fetch.side_effect = _fake_fetch
+        mock_fetch_to_raw.side_effect = _fake_fetch_to_raw
         master_path = os.path.join(self.master_dir, 'uuid')
         dest_path = os.path.join(tempfile.mkdtemp(), 'dest')
         self.cache._download_image('uuid', master_path, dest_path)
         self.assertTrue(mock_rmtree.called)
 
-    @mock.patch.object(utils, 'rmtree_without_raise', autospec=True)
-    @mock.patch.object(image_cache, '_fetch', autospec=True)
-    def test_temp_dir_exception(self, mock_fetch, mock_rmtree):
-        mock_fetch.side_effect = exception.IronicException
+    @mock.patch.object(utils, 'rmtree_without_raise')
+    @mock.patch.object(image_cache, '_fetch_to_raw')
+    def test_temp_dir_exception(self, mock_fetch_to_raw, mock_rmtree):
+        mock_fetch_to_raw.side_effect = exception.IronicException
         self.assertRaises(exception.IronicException,
                           self.cache._download_image,
                           'uuid', 'fake', 'fake')
         self.assertTrue(mock_rmtree.called)
 
-    @mock.patch.object(image_cache.LOG, 'warn', autospec=True)
-    @mock.patch.object(image_cache.ImageCache, '_clean_up_too_old',
-                       autospec=True)
-    @mock.patch.object(image_cache.ImageCache, '_clean_up_ensure_cache_size',
-                       autospec=True)
+    @mock.patch.object(image_cache.LOG, 'warn')
+    @mock.patch.object(image_cache.ImageCache, '_clean_up_too_old')
+    @mock.patch.object(image_cache.ImageCache, '_clean_up_ensure_cache_size')
     def test_clean_up_amount_not_satisfied(self, mock_clean_size,
                                            mock_clean_ttl, mock_log):
-        mock_clean_ttl.side_effect = lambda *xx: xx[1:]
-        mock_clean_size.side_effect = lambda self, listing, amount: amount
+        mock_clean_ttl.side_effect = lambda *xx: xx
+        mock_clean_size.side_effect = lambda listing, amount: amount
         self.cache.clean_up(amount=15)
         self.assertTrue(mock_log.called)
 
@@ -494,15 +305,15 @@ class TestImageCacheCleanUp(base.TestCase):
         self.assertEqual(item_possibilities[0], third_item_actual)
 
 
-@mock.patch.object(image_cache, '_cache_cleanup_list', autospec=True)
-@mock.patch.object(os, 'statvfs', autospec=True)
-@mock.patch.object(image_service, 'get_image_service', autospec=True)
+@mock.patch.object(image_cache, '_cache_cleanup_list')
+@mock.patch.object(os, 'statvfs')
+@mock.patch.object(image_service, 'Service')
 class CleanupImageCacheTestCase(base.TestCase):
 
     def setUp(self):
         super(CleanupImageCacheTestCase, self).setUp()
-        self.mock_first_cache = mock.MagicMock(spec_set=[])
-        self.mock_second_cache = mock.MagicMock(spec_set=[])
+        self.mock_first_cache = mock.MagicMock()
+        self.mock_second_cache = mock.MagicMock()
         self.cache_cleanup_list = [(50, self.mock_first_cache),
                                    (20, self.mock_second_cache)]
         self.mock_first_cache.return_value.master_dir = 'first_cache_dir'
@@ -513,8 +324,7 @@ class CleanupImageCacheTestCase(base.TestCase):
         # Enough space found - no clean up
         mock_show = mock_image_service.return_value.show
         mock_show.return_value = dict(size=42)
-        mock_statvfs.return_value = mock.MagicMock(
-            spec_set=['f_frsize', 'f_bavail'], f_frsize=1, f_bavail=1024)
+        mock_statvfs.return_value = mock.Mock(f_frsize=1, f_bavail=1024)
 
         cache_cleanup_list_mock.__iter__.return_value = self.cache_cleanup_list
 
@@ -527,7 +337,7 @@ class CleanupImageCacheTestCase(base.TestCase):
 
         mock_statvfs.assert_called_once_with('master_dir')
 
-    @mock.patch.object(os, 'stat', autospec=True)
+    @mock.patch.object(os, 'stat')
     def test_one_clean_up(self, mock_stat, mock_image_service, mock_statvfs,
                           cache_cleanup_list_mock):
         # Not enough space, first cache clean up is enough
@@ -535,10 +345,8 @@ class CleanupImageCacheTestCase(base.TestCase):
         mock_show = mock_image_service.return_value.show
         mock_show.return_value = dict(size=42)
         mock_statvfs.side_effect = [
-            mock.MagicMock(f_frsize=1, f_bavail=1,
-                           spec_set=['f_frsize', 'f_bavail']),
-            mock.MagicMock(f_frsize=1, f_bavail=1024,
-                           spec_set=['f_frsize', 'f_bavail'])
+            mock.Mock(f_frsize=1, f_bavail=1),
+            mock.Mock(f_frsize=1, f_bavail=1024)
         ]
         cache_cleanup_list_mock.__iter__.return_value = self.cache_cleanup_list
         image_cache.clean_up_caches(None, 'master_dir', [('uuid', 'path')])
@@ -560,20 +368,18 @@ class CleanupImageCacheTestCase(base.TestCase):
         self.assertEqual(mock_stat_calls_expected, mock_stat.mock_calls)
         self.assertEqual(mock_statvfs_calls_expected, mock_statvfs.mock_calls)
 
-    @mock.patch.object(os, 'stat', autospec=True)
+    @mock.patch.object(os, 'stat')
     def test_clean_up_another_fs(self, mock_stat, mock_image_service,
                                  mock_statvfs, cache_cleanup_list_mock):
         # Not enough space, need to cleanup second cache
-        mock_stat.side_effect = [mock.MagicMock(st_dev=1, spec_set=['st_dev']),
-                                 mock.MagicMock(st_dev=2, spec_set=['st_dev']),
-                                 mock.MagicMock(st_dev=1, spec_set=['st_dev'])]
+        mock_stat.side_effect = [mock.Mock(st_dev=1),
+                                 mock.Mock(st_dev=2),
+                                 mock.Mock(st_dev=1)]
         mock_show = mock_image_service.return_value.show
         mock_show.return_value = dict(size=42)
         mock_statvfs.side_effect = [
-            mock.MagicMock(f_frsize=1, f_bavail=1,
-                           spec_set=['f_frsize', 'f_bavail']),
-            mock.MagicMock(f_frsize=1, f_bavail=1024,
-                           spec_set=['f_frsize', 'f_bavail'])
+            mock.Mock(f_frsize=1, f_bavail=1),
+            mock.Mock(f_frsize=1, f_bavail=1024)
         ]
 
         cache_cleanup_list_mock.__iter__.return_value = self.cache_cleanup_list
@@ -596,7 +402,7 @@ class CleanupImageCacheTestCase(base.TestCase):
         self.assertEqual(mock_stat_calls_expected, mock_stat.mock_calls)
         self.assertEqual(mock_statvfs_calls_expected, mock_statvfs.mock_calls)
 
-    @mock.patch.object(os, 'stat', autospec=True)
+    @mock.patch.object(os, 'stat')
     def test_both_clean_up(self, mock_stat, mock_image_service, mock_statvfs,
                            cache_cleanup_list_mock):
         # Not enough space, clean up of both caches required
@@ -604,12 +410,9 @@ class CleanupImageCacheTestCase(base.TestCase):
         mock_show = mock_image_service.return_value.show
         mock_show.return_value = dict(size=42)
         mock_statvfs.side_effect = [
-            mock.MagicMock(f_frsize=1, f_bavail=1,
-                           spec_set=['f_frsize', 'f_bavail']),
-            mock.MagicMock(f_frsize=1, f_bavail=2,
-                           spec_set=['f_frsize', 'f_bavail']),
-            mock.MagicMock(f_frsize=1, f_bavail=1024,
-                           spec_set=['f_frsize', 'f_bavail'])
+            mock.Mock(f_frsize=1, f_bavail=1),
+            mock.Mock(f_frsize=1, f_bavail=2),
+            mock.Mock(f_frsize=1, f_bavail=1024)
         ]
 
         cache_cleanup_list_mock.__iter__.return_value = self.cache_cleanup_list
@@ -632,15 +435,14 @@ class CleanupImageCacheTestCase(base.TestCase):
         self.assertEqual(mock_stat_calls_expected, mock_stat.mock_calls)
         self.assertEqual(mock_statvfs_calls_expected, mock_statvfs.mock_calls)
 
-    @mock.patch.object(os, 'stat', autospec=True)
+    @mock.patch.object(os, 'stat')
     def test_clean_up_fail(self, mock_stat, mock_image_service, mock_statvfs,
                            cache_cleanup_list_mock):
         # Not enough space even after cleaning both caches - failure
         mock_stat.return_value.st_dev = 1
         mock_show = mock_image_service.return_value.show
         mock_show.return_value = dict(size=42)
-        mock_statvfs.return_value = mock.MagicMock(
-            f_frsize=1, f_bavail=1, spec_set=['f_frsize', 'f_bavail'])
+        mock_statvfs.return_value = mock.Mock(f_frsize=1, f_bavail=1)
 
         cache_cleanup_list_mock.__iter__.return_value = self.cache_cleanup_list
         self.assertRaises(exception.InsufficientDiskSpace,
@@ -667,15 +469,18 @@ class CleanupImageCacheTestCase(base.TestCase):
 
 class TestFetchCleanup(base.TestCase):
 
-    @mock.patch.object(images, 'converted_size', autospec=True)
-    @mock.patch.object(images, 'fetch', autospec=True)
-    @mock.patch.object(images, 'image_to_raw', autospec=True)
-    @mock.patch.object(image_cache, '_clean_up_caches', autospec=True)
-    def test__fetch(self, mock_clean, mock_raw, mock_fetch, mock_size):
+    def setUp(self):
+        super(TestFetchCleanup, self).setUp()
+
+    @mock.patch.object(images, 'converted_size')
+    @mock.patch.object(images, 'fetch')
+    @mock.patch.object(images, 'image_to_raw')
+    @mock.patch.object(image_cache, '_clean_up_caches')
+    def test__fetch_to_raw(self, mock_clean, mock_raw, mock_fetch, mock_size):
         mock_size.return_value = 100
-        image_cache._fetch('fake', 'fake-uuid', '/foo/bar', force_raw=True)
+        image_cache._fetch_to_raw('fake', 'fake-uuid', '/foo/bar')
         mock_fetch.assert_called_once_with('fake', 'fake-uuid',
-                                           '/foo/bar.part', force_raw=False)
+                                           '/foo/bar.part', None)
         mock_clean.assert_called_once_with('/foo', 100)
         mock_raw.assert_called_once_with('fake-uuid', '/foo/bar',
                                          '/foo/bar.part')
