@@ -21,13 +21,15 @@
 """Test class for SNMP power driver module."""
 
 import mock
-from oslo_config import cfg
+
+from oslo.config import cfg
 from pysnmp.entity.rfc3413.oneliner import cmdgen
 from pysnmp import error as snmp_error
 
 from ironic.common import exception
 from ironic.common import states
 from ironic.conductor import task_manager
+from ironic.db import api as db_api
 from ironic.drivers.modules import snmp as snmp
 from ironic.tests import base
 from ironic.tests.conductor import utils as mgr_utils
@@ -39,7 +41,7 @@ CONF = cfg.CONF
 INFO_DICT = db_utils.get_test_snmp_info()
 
 
-@mock.patch.object(cmdgen, 'CommandGenerator', autospec=True)
+@mock.patch.object(cmdgen, 'CommandGenerator')
 class SNMPClientTestCase(base.TestCase):
     def setUp(self):
         super(SNMPClientTestCase, self).setUp()
@@ -58,28 +60,28 @@ class SNMPClientTestCase(base.TestCase):
         self.assertFalse('security' in client.__dict__)
         self.assertEqual(mock_cmdgen.return_value, client.cmd_gen)
 
-    @mock.patch.object(cmdgen, 'CommunityData', autospec=True)
+    @mock.patch.object(cmdgen, 'CommunityData')
     def test__get_auth_v1(self, mock_community, mock_cmdgen):
         client = snmp.SNMPClient(self.address, self.port, snmp.SNMP_V1)
         client._get_auth()
         mock_cmdgen.assert_called_once_with()
         mock_community.assert_called_once_with(client.community, mpModel=0)
 
-    @mock.patch.object(cmdgen, 'UsmUserData', autospec=True)
+    @mock.patch.object(cmdgen, 'UsmUserData')
     def test__get_auth_v3(self, mock_user, mock_cmdgen):
         client = snmp.SNMPClient(self.address, self.port, snmp.SNMP_V3)
         client._get_auth()
         mock_cmdgen.assert_called_once_with()
         mock_user.assert_called_once_with(client.security)
 
-    @mock.patch.object(cmdgen, 'UdpTransportTarget', autospec=True)
+    @mock.patch.object(cmdgen, 'UdpTransportTarget')
     def test__get_transport(self, mock_transport, mock_cmdgen):
         client = snmp.SNMPClient(self.address, self.port, snmp.SNMP_V3)
         client._get_transport()
         mock_cmdgen.assert_called_once_with()
         mock_transport.assert_called_once_with((client.address, client.port))
 
-    @mock.patch.object(cmdgen, 'UdpTransportTarget', autospec=True)
+    @mock.patch.object(cmdgen, 'UdpTransportTarget')
     def test__get_transport_err(self, mock_transport, mock_cmdgen):
         mock_transport.side_effect = snmp_error.PySnmpError
         client = snmp.SNMPClient(self.address, self.port, snmp.SNMP_V3)
@@ -87,8 +89,8 @@ class SNMPClientTestCase(base.TestCase):
         mock_cmdgen.assert_called_once_with()
         mock_transport.assert_called_once_with((client.address, client.port))
 
-    @mock.patch.object(snmp.SNMPClient, '_get_transport', autospec=True)
-    @mock.patch.object(snmp.SNMPClient, '_get_auth', autospec=True)
+    @mock.patch.object(snmp.SNMPClient, '_get_transport')
+    @mock.patch.object(snmp.SNMPClient, '_get_auth')
     def test_get(self, mock_auth, mock_transport, mock_cmdgen):
         var_bind = (self.oid, self.value)
         mock_cmdgenerator = mock_cmdgen.return_value
@@ -99,8 +101,8 @@ class SNMPClientTestCase(base.TestCase):
         mock_cmdgenerator.getCmd.assert_called_once_with(mock.ANY, mock.ANY,
                                                          self.oid)
 
-    @mock.patch.object(snmp.SNMPClient, '_get_transport', autospec=True)
-    @mock.patch.object(snmp.SNMPClient, '_get_auth', autospec=True)
+    @mock.patch.object(snmp.SNMPClient, '_get_transport')
+    @mock.patch.object(snmp.SNMPClient, '_get_auth')
     def test_get_err_transport(self, mock_auth, mock_transport, mock_cmdgen):
         mock_transport.side_effect = snmp_error.PySnmpError
         var_bind = (self.oid, self.value)
@@ -111,8 +113,8 @@ class SNMPClientTestCase(base.TestCase):
         self.assertRaises(exception.SNMPFailure, client.get, self.oid)
         self.assertFalse(mock_cmdgenerator.getCmd.called)
 
-    @mock.patch.object(snmp.SNMPClient, '_get_transport', autospec=True)
-    @mock.patch.object(snmp.SNMPClient, '_get_auth', autospec=True)
+    @mock.patch.object(snmp.SNMPClient, '_get_transport')
+    @mock.patch.object(snmp.SNMPClient, '_get_auth')
     def test_get_err_engine(self, mock_auth, mock_transport, mock_cmdgen):
         var_bind = (self.oid, self.value)
         mock_cmdgenerator = mock_cmdgen.return_value
@@ -123,8 +125,8 @@ class SNMPClientTestCase(base.TestCase):
         mock_cmdgenerator.getCmd.assert_called_once_with(mock.ANY, mock.ANY,
                                                          self.oid)
 
-    @mock.patch.object(snmp.SNMPClient, '_get_transport', autospec=True)
-    @mock.patch.object(snmp.SNMPClient, '_get_auth', autospec=True)
+    @mock.patch.object(snmp.SNMPClient, '_get_transport')
+    @mock.patch.object(snmp.SNMPClient, '_get_auth')
     def test_set(self, mock_auth, mock_transport, mock_cmdgen):
         var_bind = (self.oid, self.value)
         mock_cmdgenerator = mock_cmdgen.return_value
@@ -134,8 +136,8 @@ class SNMPClientTestCase(base.TestCase):
         mock_cmdgenerator.setCmd.assert_called_once_with(mock.ANY, mock.ANY,
                                                          var_bind)
 
-    @mock.patch.object(snmp.SNMPClient, '_get_transport', autospec=True)
-    @mock.patch.object(snmp.SNMPClient, '_get_auth', autospec=True)
+    @mock.patch.object(snmp.SNMPClient, '_get_transport')
+    @mock.patch.object(snmp.SNMPClient, '_get_auth')
     def test_set_err_transport(self, mock_auth, mock_transport, mock_cmdgen):
         mock_transport.side_effect = snmp_error.PySnmpError
         var_bind = (self.oid, self.value)
@@ -147,8 +149,8 @@ class SNMPClientTestCase(base.TestCase):
                           client.set, self.oid, self.value)
         self.assertFalse(mock_cmdgenerator.setCmd.called)
 
-    @mock.patch.object(snmp.SNMPClient, '_get_transport', autospec=True)
-    @mock.patch.object(snmp.SNMPClient, '_get_auth', autospec=True)
+    @mock.patch.object(snmp.SNMPClient, '_get_transport')
+    @mock.patch.object(snmp.SNMPClient, '_get_auth')
     def test_set_err_engine(self, mock_auth, mock_transport, mock_cmdgen):
         var_bind = (self.oid, self.value)
         mock_cmdgenerator = mock_cmdgen.return_value
@@ -165,8 +167,8 @@ class SNMPValidateParametersTestCase(db_base.DbTestCase):
 
     def _get_test_node(self, driver_info):
         return obj_utils.get_test_node(
-            self.context,
-            driver_info=driver_info)
+                self.context,
+                driver_info=driver_info)
 
     def test__parse_driver_info_default(self):
         # Make sure we get back the expected things.
@@ -189,34 +191,6 @@ class SNMPValidateParametersTestCase(db_base.DbTestCase):
         info = snmp._parse_driver_info(node)
         self.assertEqual('apc', info.get('driver'))
 
-    def test__parse_driver_info_apc_masterswitch(self):
-        # Make sure the APC driver type is parsed.
-        info = db_utils.get_test_snmp_info(snmp_driver='apc_masterswitch')
-        node = self._get_test_node(info)
-        info = snmp._parse_driver_info(node)
-        self.assertEqual('apc_masterswitch', info.get('driver'))
-
-    def test__parse_driver_info_apc_masterswitchplus(self):
-        # Make sure the APC driver type is parsed.
-        info = db_utils.get_test_snmp_info(snmp_driver='apc_masterswitchplus')
-        node = self._get_test_node(info)
-        info = snmp._parse_driver_info(node)
-        self.assertEqual('apc_masterswitchplus', info.get('driver'))
-
-    def test__parse_driver_info_apc_rackpdu(self):
-        # Make sure the APC driver type is parsed.
-        info = db_utils.get_test_snmp_info(snmp_driver='apc_rackpdu')
-        node = self._get_test_node(info)
-        info = snmp._parse_driver_info(node)
-        self.assertEqual('apc_rackpdu', info.get('driver'))
-
-    def test__parse_driver_info_aten(self):
-        # Make sure the Aten driver type is parsed.
-        info = db_utils.get_test_snmp_info(snmp_driver='aten')
-        node = self._get_test_node(info)
-        info = snmp._parse_driver_info(node)
-        self.assertEqual('aten', info.get('driver'))
-
     def test__parse_driver_info_cyberpower(self):
         # Make sure the CyberPower driver type is parsed.
         info = db_utils.get_test_snmp_info(snmp_driver='cyberpower')
@@ -372,7 +346,7 @@ class SNMPValidateParametersTestCase(db_base.DbTestCase):
                           node)
 
 
-@mock.patch.object(snmp, '_get_client', autospec=True)
+@mock.patch.object(snmp, '_get_client')
 class SNMPDeviceDriverTestCase(db_base.DbTestCase):
     """Tests for the SNMP device-specific driver classes.
 
@@ -454,7 +428,7 @@ class SNMPDeviceDriverTestCase(db_base.DbTestCase):
         mock_client.get.assert_called_once_with(driver._snmp_oid())
         self.assertEqual(states.POWER_OFF, pstate)
 
-    @mock.patch("eventlet.greenthread.sleep", autospec=True)
+    @mock.patch("eventlet.greenthread.sleep")
     def test_power_on_delay(self, mock_sleep, mock_get_client):
         # Ensure driver waits for the state to change following a power on
         mock_client = mock_get_client.return_value
@@ -468,7 +442,7 @@ class SNMPDeviceDriverTestCase(db_base.DbTestCase):
         mock_client.get.assert_has_calls(calls)
         self.assertEqual(states.POWER_ON, pstate)
 
-    @mock.patch("eventlet.greenthread.sleep", autospec=True)
+    @mock.patch("eventlet.greenthread.sleep")
     def test_power_off_delay(self, mock_sleep, mock_get_client):
         # Ensure driver waits for the state to change following a power off
         mock_client = mock_get_client.return_value
@@ -482,7 +456,7 @@ class SNMPDeviceDriverTestCase(db_base.DbTestCase):
         mock_client.get.assert_has_calls(calls)
         self.assertEqual(states.POWER_OFF, pstate)
 
-    @mock.patch("eventlet.greenthread.sleep", autospec=True)
+    @mock.patch("eventlet.greenthread.sleep")
     def test_power_on_invalid_state(self, mock_sleep, mock_get_client):
         # Ensure driver retries when querying unexpected states following a
         # power on
@@ -497,7 +471,7 @@ class SNMPDeviceDriverTestCase(db_base.DbTestCase):
         mock_client.get.assert_has_calls(calls)
         self.assertEqual(states.ERROR, pstate)
 
-    @mock.patch("eventlet.greenthread.sleep", autospec=True)
+    @mock.patch("eventlet.greenthread.sleep")
     def test_power_off_invalid_state(self, mock_sleep, mock_get_client):
         # Ensure driver retries when querying unexpected states following a
         # power off
@@ -558,7 +532,7 @@ class SNMPDeviceDriverTestCase(db_base.DbTestCase):
                                                 driver.value_power_off)
         mock_client.get.assert_called_once_with(driver._snmp_oid())
 
-    @mock.patch("eventlet.greenthread.sleep", autospec=True)
+    @mock.patch("eventlet.greenthread.sleep")
     def test_power_on_timeout(self, mock_sleep, mock_get_client):
         # Ensure that a power on consistency poll timeout causes an error
         mock_client = mock_get_client.return_value
@@ -572,7 +546,7 @@ class SNMPDeviceDriverTestCase(db_base.DbTestCase):
         mock_client.get.assert_has_calls(calls)
         self.assertEqual(states.ERROR, pstate)
 
-    @mock.patch("eventlet.greenthread.sleep", autospec=True)
+    @mock.patch("eventlet.greenthread.sleep")
     def test_power_off_timeout(self, mock_sleep, mock_get_client):
         # Ensure that a power off consistency poll timeout causes an error
         mock_client = mock_get_client.return_value
@@ -601,7 +575,7 @@ class SNMPDeviceDriverTestCase(db_base.DbTestCase):
         mock_client.get.assert_has_calls(calls)
         self.assertEqual(states.POWER_ON, pstate)
 
-    @mock.patch("eventlet.greenthread.sleep", autospec=True)
+    @mock.patch("eventlet.greenthread.sleep")
     def test_power_reset_off_delay(self, mock_sleep, mock_get_client):
         # Ensure driver waits for the power off state change following a power
         # reset
@@ -618,7 +592,7 @@ class SNMPDeviceDriverTestCase(db_base.DbTestCase):
         mock_client.get.assert_has_calls(calls)
         self.assertEqual(states.POWER_ON, pstate)
 
-    @mock.patch("eventlet.greenthread.sleep", autospec=True)
+    @mock.patch("eventlet.greenthread.sleep")
     def test_power_reset_on_delay(self, mock_sleep, mock_get_client):
         # Ensure driver waits for the power on state change following a power
         # reset
@@ -635,7 +609,7 @@ class SNMPDeviceDriverTestCase(db_base.DbTestCase):
         mock_client.get.assert_has_calls(calls)
         self.assertEqual(states.POWER_ON, pstate)
 
-    @mock.patch("eventlet.greenthread.sleep", autospec=True)
+    @mock.patch("eventlet.greenthread.sleep")
     def test_power_reset_off_delay_on_delay(self, mock_sleep, mock_get_client):
         # Ensure driver waits for both state changes following a power reset
         mock_client = mock_get_client.return_value
@@ -652,7 +626,7 @@ class SNMPDeviceDriverTestCase(db_base.DbTestCase):
         mock_client.get.assert_has_calls(calls)
         self.assertEqual(states.POWER_ON, pstate)
 
-    @mock.patch("eventlet.greenthread.sleep", autospec=True)
+    @mock.patch("eventlet.greenthread.sleep")
     def test_power_reset_off_invalid_state(self, mock_sleep, mock_get_client):
         # Ensure driver retries when querying unexpected states following a
         # power off during a reset
@@ -667,7 +641,7 @@ class SNMPDeviceDriverTestCase(db_base.DbTestCase):
         mock_client.get.assert_has_calls(calls)
         self.assertEqual(states.ERROR, pstate)
 
-    @mock.patch("eventlet.greenthread.sleep", autospec=True)
+    @mock.patch("eventlet.greenthread.sleep")
     def test_power_reset_on_invalid_state(self, mock_sleep, mock_get_client):
         # Ensure driver retries when querying unexpected states following a
         # power on during a reset
@@ -684,7 +658,7 @@ class SNMPDeviceDriverTestCase(db_base.DbTestCase):
         mock_client.get.assert_has_calls(calls)
         self.assertEqual(states.ERROR, pstate)
 
-    @mock.patch("eventlet.greenthread.sleep", autospec=True)
+    @mock.patch("eventlet.greenthread.sleep")
     def test_power_reset_off_timeout(self, mock_sleep, mock_get_client):
         # Ensure that a power off consistency poll timeout during a reset
         # causes an error
@@ -699,7 +673,7 @@ class SNMPDeviceDriverTestCase(db_base.DbTestCase):
         mock_client.get.assert_has_calls(calls)
         self.assertEqual(states.ERROR, pstate)
 
-    @mock.patch("eventlet.greenthread.sleep", autospec=True)
+    @mock.patch("eventlet.greenthread.sleep")
     def test_power_reset_on_timeout(self, mock_sleep, mock_get_client):
         # Ensure that a power on consistency poll timeout during a reset
         # causes an error
@@ -855,120 +829,6 @@ class SNMPDeviceDriverTestCase(db_base.DbTestCase):
     def test_apc_power_reset(self, mock_get_client):
         self._test_simple_device_power_reset('apc', mock_get_client)
 
-    def test_apc_masterswitch_snmp_objects(self, mock_get_client):
-        # Ensure the correct SNMP object OIDs and values are used by the APC
-        # masterswitch driver
-        self._update_driver_info(snmp_driver="apc_masterswitch",
-                                 snmp_outlet="6")
-        driver = snmp._get_driver(self.node)
-        oid = (1, 3, 6, 1, 4, 1, 318, 1, 1, 4, 4, 2, 1, 3, 6)
-        self.assertEqual(oid, driver._snmp_oid())
-        self.assertEqual(1, driver.value_power_on)
-        self.assertEqual(2, driver.value_power_off)
-
-    def test_apc_masterswitch_power_state_on(self, mock_get_client):
-        self._test_simple_device_power_state_on('apc_masterswitch',
-                                                mock_get_client)
-
-    def test_apc_masterswitch_power_state_off(self, mock_get_client):
-        self._test_simple_device_power_state_off('apc_masterswitch',
-                                                 mock_get_client)
-
-    def test_apc_masterswitch_power_on(self, mock_get_client):
-        self._test_simple_device_power_on('apc_masterswitch', mock_get_client)
-
-    def test_apc_masterswitch_power_off(self, mock_get_client):
-        self._test_simple_device_power_off('apc_masterswitch', mock_get_client)
-
-    def test_apc_masterswitch_power_reset(self, mock_get_client):
-        self._test_simple_device_power_reset('apc_masterswitch',
-                                             mock_get_client)
-
-    def test_apc_masterswitchplus_snmp_objects(self, mock_get_client):
-        # Ensure the correct SNMP object OIDs and values are used by the APC
-        # masterswitchplus driver
-        self._update_driver_info(snmp_driver="apc_masterswitchplus",
-                                 snmp_outlet="6")
-        driver = snmp._get_driver(self.node)
-        oid = (1, 3, 6, 1, 4, 1, 318, 1, 1, 6, 5, 1, 1, 5, 6)
-        self.assertEqual(oid, driver._snmp_oid())
-        self.assertEqual(1, driver.value_power_on)
-        self.assertEqual(3, driver.value_power_off)
-
-    def test_apc_masterswitchplus_power_state_on(self, mock_get_client):
-        self._test_simple_device_power_state_on('apc_masterswitchplus',
-                                                mock_get_client)
-
-    def test_apc_masterswitchplus_power_state_off(self, mock_get_client):
-        self._test_simple_device_power_state_off('apc_masterswitchplus',
-                                                 mock_get_client)
-
-    def test_apc_masterswitchplus_power_on(self, mock_get_client):
-        self._test_simple_device_power_on('apc_masterswitchplus',
-                                          mock_get_client)
-
-    def test_apc_masterswitchplus_power_off(self, mock_get_client):
-        self._test_simple_device_power_off('apc_masterswitchplus',
-                                           mock_get_client)
-
-    def test_apc_masterswitchplus_power_reset(self, mock_get_client):
-        self._test_simple_device_power_reset('apc_masterswitchplus',
-                                             mock_get_client)
-
-    def test_apc_rackpdu_snmp_objects(self, mock_get_client):
-        # Ensure the correct SNMP object OIDs and values are used by the APC
-        # rackpdu driver
-        self._update_driver_info(snmp_driver="apc_rackpdu",
-                                 snmp_outlet="6")
-        driver = snmp._get_driver(self.node)
-        oid = (1, 3, 6, 1, 4, 1, 318, 1, 1, 12, 3, 3, 1, 1, 4, 6)
-
-        self.assertEqual(oid, driver._snmp_oid())
-        self.assertEqual(1, driver.value_power_on)
-        self.assertEqual(2, driver.value_power_off)
-
-    def test_apc_rackpdu_power_state_on(self, mock_get_client):
-        self._test_simple_device_power_state_on('apc_rackpdu', mock_get_client)
-
-    def test_apc_rackpdu_power_state_off(self, mock_get_client):
-        self._test_simple_device_power_state_off('apc_rackpdu',
-                                                 mock_get_client)
-
-    def test_apc_rackpdu_power_on(self, mock_get_client):
-        self._test_simple_device_power_on('apc_rackpdu', mock_get_client)
-
-    def test_apc_rackpdu_power_off(self, mock_get_client):
-        self._test_simple_device_power_off('apc_rackpdu', mock_get_client)
-
-    def test_apc_rackpdu_power_reset(self, mock_get_client):
-        self._test_simple_device_power_reset('apc_rackpdu', mock_get_client)
-
-    def test_aten_snmp_objects(self, mock_get_client):
-        # Ensure the correct SNMP object OIDs and values are used by the
-        # Aten driver
-        self._update_driver_info(snmp_driver="aten",
-                                 snmp_outlet="3")
-        driver = snmp._get_driver(self.node)
-        oid = (1, 3, 6, 1, 4, 1, 21317, 1, 3, 2, 2, 2, 2, 3, 0)
-        self.assertEqual(oid, driver._snmp_oid())
-        self.assertEqual(2, driver.value_power_on)
-        self.assertEqual(1, driver.value_power_off)
-
-    def test_aten_power_state_on(self, mock_get_client):
-        self._test_simple_device_power_state_on('aten', mock_get_client)
-
-    def test_aten_power_state_off(self, mock_get_client):
-        self._test_simple_device_power_state_off('aten', mock_get_client)
-
-    def test_aten_power_on(self, mock_get_client):
-        self._test_simple_device_power_on('aten', mock_get_client)
-
-    def test_aten_power_off(self, mock_get_client):
-        self._test_simple_device_power_off('aten', mock_get_client)
-
-    def test_aten_power_reset(self, mock_get_client):
-        self._test_simple_device_power_reset('aten', mock_get_client)
-
     def test_cyberpower_snmp_objects(self, mock_get_client):
         # Ensure the correct SNMP object OIDs and values are used by the
         # CyberPower driver
@@ -1046,7 +906,7 @@ class SNMPDeviceDriverTestCase(db_base.DbTestCase):
         mock_client.get.return_value = driver.status_on
         pstate = driver.power_state()
         mock_client.get.assert_called_once_with(
-            driver._snmp_oid(driver.oid_status))
+                driver._snmp_oid(driver.oid_status))
         self.assertEqual(states.POWER_ON, pstate)
 
     def test_eaton_power_power_state_off(self, mock_get_client):
@@ -1057,7 +917,7 @@ class SNMPDeviceDriverTestCase(db_base.DbTestCase):
         mock_client.get.return_value = driver.status_off
         pstate = driver.power_state()
         mock_client.get.assert_called_once_with(
-            driver._snmp_oid(driver.oid_status))
+                driver._snmp_oid(driver.oid_status))
         self.assertEqual(states.POWER_OFF, pstate)
 
     def test_eaton_power_power_state_pending_off(self, mock_get_client):
@@ -1068,7 +928,7 @@ class SNMPDeviceDriverTestCase(db_base.DbTestCase):
         mock_client.get.return_value = driver.status_pending_off
         pstate = driver.power_state()
         mock_client.get.assert_called_once_with(
-            driver._snmp_oid(driver.oid_status))
+                driver._snmp_oid(driver.oid_status))
         self.assertEqual(states.POWER_ON, pstate)
 
     def test_eaton_power_power_state_pending_on(self, mock_get_client):
@@ -1079,7 +939,7 @@ class SNMPDeviceDriverTestCase(db_base.DbTestCase):
         mock_client.get.return_value = driver.status_pending_on
         pstate = driver.power_state()
         mock_client.get.assert_called_once_with(
-            driver._snmp_oid(driver.oid_status))
+                driver._snmp_oid(driver.oid_status))
         self.assertEqual(states.POWER_OFF, pstate)
 
     def test_eaton_power_power_on(self, mock_get_client):
@@ -1090,9 +950,9 @@ class SNMPDeviceDriverTestCase(db_base.DbTestCase):
         mock_client.get.return_value = driver.status_on
         pstate = driver.power_on()
         mock_client.set.assert_called_once_with(
-            driver._snmp_oid(driver.oid_poweron), driver.value_power_on)
+                driver._snmp_oid(driver.oid_poweron), driver.value_power_on)
         mock_client.get.assert_called_once_with(
-            driver._snmp_oid(driver.oid_status))
+                driver._snmp_oid(driver.oid_status))
         self.assertEqual(states.POWER_ON, pstate)
 
     def test_eaton_power_power_off(self, mock_get_client):
@@ -1103,9 +963,9 @@ class SNMPDeviceDriverTestCase(db_base.DbTestCase):
         mock_client.get.return_value = driver.status_off
         pstate = driver.power_off()
         mock_client.set.assert_called_once_with(
-            driver._snmp_oid(driver.oid_poweroff), driver.value_power_off)
+                driver._snmp_oid(driver.oid_poweroff), driver.value_power_off)
         mock_client.get.assert_called_once_with(
-            driver._snmp_oid(driver.oid_status))
+                driver._snmp_oid(driver.oid_status))
         self.assertEqual(states.POWER_OFF, pstate)
 
     def test_eaton_power_power_reset(self, mock_get_client):
@@ -1125,7 +985,7 @@ class SNMPDeviceDriverTestCase(db_base.DbTestCase):
         self.assertEqual(states.POWER_ON, pstate)
 
 
-@mock.patch.object(snmp, '_get_driver', autospec=True)
+@mock.patch.object(snmp, '_get_driver')
 class SNMPDriverTestCase(db_base.DbTestCase):
     """SNMP power driver interface tests.
 
@@ -1136,6 +996,7 @@ class SNMPDriverTestCase(db_base.DbTestCase):
 
     def setUp(self):
         super(SNMPDriverTestCase, self).setUp()
+        self.dbapi = db_api.get_instance()
         mgr_utils.mock_the_extension_manager(driver='fake_snmp')
 
         self.node = obj_utils.create_test_node(self.context,
