@@ -13,13 +13,14 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import datetime
 import mock
-from oslo_utils import uuidutils
 from testtools.matchers import HasLength
 
 from ironic.common import exception
+from ironic.common import utils as ironic_utils
+from ironic.db import api as db_api
 from ironic import objects
+
 from ironic.tests.db import base
 from ironic.tests.db import utils
 
@@ -29,6 +30,7 @@ class TestChassisObject(base.DbTestCase):
     def setUp(self):
         super(TestChassisObject, self).setUp()
         self.fake_chassis = utils.get_test_chassis()
+        self.dbapi = db_api.get_instance()
 
     def test_get_by_id(self):
         chassis_id = self.fake_chassis['id']
@@ -58,35 +60,30 @@ class TestChassisObject(base.DbTestCase):
 
     def test_save(self):
         uuid = self.fake_chassis['uuid']
-        extra = {"test": 123}
-        test_time = datetime.datetime(2000, 1, 1, 0, 0)
         with mock.patch.object(self.dbapi, 'get_chassis_by_uuid',
                                autospec=True) as mock_get_chassis:
             mock_get_chassis.return_value = self.fake_chassis
             with mock.patch.object(self.dbapi, 'update_chassis',
                                    autospec=True) as mock_update_chassis:
-                mock_update_chassis.return_value = (
-                    utils.get_test_chassis(extra=extra, updated_at=test_time))
+
                 c = objects.Chassis.get_by_uuid(self.context, uuid)
-                c.extra = extra
+                c.extra = {"test": 123}
                 c.save()
 
                 mock_get_chassis.assert_called_once_with(uuid)
                 mock_update_chassis.assert_called_once_with(
-                    uuid, {'extra': {"test": 123}})
+                        uuid, {'extra': {"test": 123}})
                 self.assertEqual(self.context, c._context)
-                res_updated_at = (c.updated_at).replace(tzinfo=None)
-                self.assertEqual(test_time, res_updated_at)
 
     def test_refresh(self):
         uuid = self.fake_chassis['uuid']
-        new_uuid = uuidutils.generate_uuid()
+        new_uuid = ironic_utils.generate_uuid()
         returns = [dict(self.fake_chassis, uuid=uuid),
                    dict(self.fake_chassis, uuid=new_uuid)]
         expected = [mock.call(uuid), mock.call(uuid)]
         with mock.patch.object(self.dbapi, 'get_chassis_by_uuid',
-                               side_effect=returns,
-                               autospec=True) as mock_get_chassis:
+                               side_effect=returns, autospec=True) \
+                as mock_get_chassis:
             c = objects.Chassis.get_by_uuid(self.context, uuid)
             self.assertEqual(uuid, c.uuid)
             c.refresh()
