@@ -17,6 +17,7 @@ import mock
 from testtools.matchers import HasLength
 
 from ironic.common import exception
+from ironic.db import api as db_api
 from ironic import objects
 from ironic.tests.db import base
 from ironic.tests.db import utils
@@ -27,6 +28,7 @@ class TestNodeObject(base.DbTestCase):
     def setUp(self):
         super(TestNodeObject, self).setUp()
         self.fake_node = utils.get_test_node()
+        self.dbapi = db_api.get_instance()
 
     def test_get_by_id(self):
         node_id = self.fake_node['id']
@@ -63,19 +65,13 @@ class TestNodeObject(base.DbTestCase):
                                    autospec=True) as mock_update_node:
 
                 n = objects.Node.get(self.context, uuid)
-                self.assertEqual({"foo": "bar", "fake_password": "fakepass"},
-                                 n.driver_internal_info)
                 n.properties = {"fake": "property"}
-                n.driver = "fake-driver"
                 n.save()
 
                 mock_get_node.assert_called_once_with(uuid)
                 mock_update_node.assert_called_once_with(
-                    uuid, {'properties': {"fake": "property"},
-                           'driver': 'fake-driver',
-                           'driver_internal_info': {}})
+                        uuid, {'properties': {"fake": "property"}})
                 self.assertEqual(self.context, n._context)
-                self.assertEqual({}, n.driver_internal_info)
 
     def test_refresh(self):
         uuid = self.fake_node['uuid']
@@ -116,8 +112,7 @@ class TestNodeObject(base.DbTestCase):
         with mock.patch.object(self.dbapi, 'reserve_node',
                                autospec=True) as mock_reserve:
             node_id = 'non-existent'
-            mock_reserve.side_effect = iter(
-                [exception.NodeNotFound(node=node_id)])
+            mock_reserve.side_effect = exception.NodeNotFound(node=node_id)
             self.assertRaises(exception.NodeNotFound,
                               objects.Node.reserve, self.context, 'fake-tag',
                               node_id)
@@ -134,18 +129,7 @@ class TestNodeObject(base.DbTestCase):
         with mock.patch.object(self.dbapi, 'release_node',
                                autospec=True) as mock_release:
             node_id = 'non-existent'
-            mock_release.side_effect = iter(
-                [exception.NodeNotFound(node=node_id)])
+            mock_release.side_effect = exception.NodeNotFound(node=node_id)
             self.assertRaises(exception.NodeNotFound,
                               objects.Node.release, self.context,
                               'fake-tag', node_id)
-
-    def test_touch_provisioning(self):
-        with mock.patch.object(self.dbapi, 'get_node_by_uuid',
-                               autospec=True) as mock_get_node:
-            mock_get_node.return_value = self.fake_node
-            with mock.patch.object(self.dbapi, 'touch_node_provisioning',
-                                   autospec=True) as mock_touch:
-                node = objects.Node.get(self.context, self.fake_node['uuid'])
-                node.touch_provisioning()
-                mock_touch.assert_called_once_with(node.id)
